@@ -15,12 +15,13 @@
 
 import abc
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 import six
 
 from neutron.common import constants as n_const
 from neutron.common import log
-from neutron.openstack.common import log as logging
+from neutron.plugins.ml2.drivers.l2pop import rpc as l2pop_rpc
 
 LOG = logging.getLogger(__name__)
 
@@ -31,24 +32,50 @@ class L2populationRpcCallBackMixin(object):
 
     The following methods are called through RPC.
         add_fdb_entries(), remove_fdb_entries(), update_fdb_entries()
-    The following methods are used in a agent as an internal method.
+    The following methods are used in an agent as internal methods.
         fdb_add(), fdb_remove(), fdb_update()
     '''
 
     @log.log
     def add_fdb_entries(self, context, fdb_entries, host=None):
         if not host or host == cfg.CONF.host:
-            self.fdb_add(context, fdb_entries)
+            self.fdb_add(context, self._unmarshall_fdb_entries(fdb_entries))
 
     @log.log
     def remove_fdb_entries(self, context, fdb_entries, host=None):
         if not host or host == cfg.CONF.host:
-            self.fdb_remove(context, fdb_entries)
+            self.fdb_remove(context, self._unmarshall_fdb_entries(fdb_entries))
 
     @log.log
     def update_fdb_entries(self, context, fdb_entries, host=None):
         if not host or host == cfg.CONF.host:
-            self.fdb_update(context, fdb_entries)
+            self.fdb_update(context, self._unmarshall_fdb_entries(fdb_entries))
+
+    @staticmethod
+    def _unmarshall_fdb_entries(fdb_entries):
+        """Prepares fdb_entries from JSON.
+
+        All methods in this class that receive messages should call this to
+        unmarshall fdb_entries from the wire.
+
+        :param fdb_entries: Original fdb_entries data-structure.  Looks like:
+            {
+                <uuid>: {
+                    ...,
+                    'ports': {
+                        <ip address>: [ [<mac>, <ip>], ...  ],
+                        ...
+
+        :returns: Deep copy with [<mac>, <ip>] converted to PortInfo
+        """
+        unmarshalled = dict(fdb_entries)
+        for value in unmarshalled.values():
+            if 'ports' in value:
+                value['ports'] = dict(
+                    (address, [l2pop_rpc.PortInfo(*pi) for pi in port_infos])
+                    for address, port_infos in value['ports'].items()
+                )
+        return unmarshalled
 
     @abc.abstractmethod
     def fdb_add(self, context, fdb_entries):
@@ -66,23 +93,41 @@ class L2populationRpcCallBackMixin(object):
 class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
     '''Mixin class of L2-population call back for Tunnel.
 
-    The following all methods are used in a agent as an internal method.
+    The following methods are all used in agents as internal methods.
+
+    Some of the methods in this class use Local VLAN Mapping, aka lvm.
+    It's a python object with at least the following attributes:
+
+    ============ =========================================================
+    Attribute    Description
+    ============ =========================================================
+    vlan         An identifier used by the agent to identify a neutron
+                 network.
+    network_type A network type found in neutron.plugins.common.constants.
+    ============ =========================================================
+
+    NOTE(yamamoto): "Local VLAN" is an OVS-agent term.  OVS-agent internally
+    uses 802.1q VLAN tagging to isolate networks.  While this class inherited
+    the terms from OVS-agent, it does not assume the specific underlying
+    technologies.  E.g. this class is also used by ofagent, where a different
+    mechanism is used.
     '''
 
     @abc.abstractmethod
     def add_fdb_flow(self, br, port_info, remote_ip, lvm, ofport):
         '''Add flow for fdb
 
-        This method assumes to be used by method fdb_add_tun.
+        This method is assumed to be used by method fdb_add_tun.
         We expect to add a flow entry to send a packet to specified port
         on bridge.
-        And you may edit some information for local arp respond.
+        And you may edit some information for local arp response.
 
         :param br: represent the bridge on which add_fdb_flow should be
         applied.
-        :param port_info: list to include mac and ip.
+        :param port_info: PortInfo instance to include mac and ip.
+            .mac_address
+            .ip_address
 
-            [mac, ip]
         :remote_ip: remote ip address.
         :param lvm: a local VLAN map of network.
         :param ofport: a port to add.
@@ -93,17 +138,20 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
     def del_fdb_flow(self, br, port_info, remote_ip, lvm, ofport):
         '''Delete flow for fdb
 
-        This method assumes to be used by method fdb_remove_tun.
+        This method is assumed to be used by method fdb_remove_tun.
         We expect to delete a flow entry to send a packet to specified port
         from bridge.
-        And you may delete some information for local arp respond.
+        And you may delete some information for local arp response.
 
         :param br: represent the bridge on which del_fdb_flow should be
         applied.
-        :param port_info: a list to contain mac and ip.
-            [mac, ip]
+        :param port_info: PortInfo instance to include mac and ip.
+            .mac_address
+            .ip_address
+
         :remote_ip: remote ip address.
-        :param lvm: local VLAN map of network.
+        :param lvm: local VLAN map of a network. See add_fdb_flow for
+            more explanation.
         :param ofport: a port to delete.
         '''
         pass
@@ -112,16 +160,16 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
     def setup_tunnel_port(self, br, remote_ip, network_type):
         '''Setup an added tunnel port.
 
-        This method assumes to be used by method fdb_add_tun.
+        This method is assumed to be used by method fdb_add_tun.
         We expect to prepare to call add_fdb_flow. It will be mainly adding
         a port to a bridge.
-        If you need, you may do some preparation for a bridge.
+        If you need, you may do some preparations for a bridge.
 
         :param br: represent the bridge on which setup_tunnel_port should be
         applied.
-        :param remote_ip: an ip for port to setup.
-        :param network_type: a type of network.
-        :returns: a ofport value. the value 0 means to be unavailable port.
+        :param remote_ip: an ip for a port to setup.
+        :param network_type: a type of a network.
+        :returns: an ofport value. value 0 means the port is unavailable.
         '''
         pass
 
@@ -129,7 +177,7 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
     def cleanup_tunnel_port(self, br, tun_ofport, tunnel_type):
         '''Clean up a deleted tunnel port.
 
-        This method assumes to be used by method fdb_remove_tun.
+        This method is assumed to be used by method fdb_remove_tun.
         We expect to clean up after calling del_fdb_flow. It will be mainly
         deleting a port from a bridge.
         If you need, you may do some cleanup for a bridge.
@@ -137,7 +185,7 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
         :param br: represent the bridge on which cleanup_tunnel_port should be
         applied.
         :param tun_ofport: a port value to cleanup.
-        :param tunnel_type: a type of tunnel.
+        :param tunnel_type: a type of a tunnel.
         '''
         pass
 
@@ -146,13 +194,13 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
                                   ip_address):
         '''Operate the ARP respond information.
 
-        Do operation of arp respond information for an action
-        In ovs do adding or removing flow entry to edit an arp reply.
+        Update MAC/IPv4 associations, which is typically used by
+        the local ARP responder.  For example, OVS-agent sets up
+        flow entries to perform ARP responses.
 
         :param br: represent the bridge on which setup_entry_for_arp_reply
         should be applied.
-        :param action: an action to operate for arp respond infomation.
-            "add" or "remove"
+        :param action: add/remove flow for arp response information.
         :param local_vid: id in local VLAN map of network's ARP entry.
         :param mac_address: MAC string value.
         :param ip_address: IP string value.
@@ -160,6 +208,15 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
         pass
 
     def get_agent_ports(self, fdb_entries, local_vlan_map):
+        """Generator to yield port info.
+
+        For each known (i.e found in local_vlan_map) network in
+        fdb_entries, yield (lvm, fdb_entries[network_id]['ports']) pair.
+
+        :param fdb_entries: l2pop fdb entries
+        :param local_vlan_map: A dict to map network_id to
+            the corresponding lvm entry.
+        """
         for network_id, values in fdb_entries.items():
             lvm = local_vlan_map.get(network_id)
             if lvm is None:
@@ -168,10 +225,10 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
             yield (lvm, agent_ports)
 
     @log.log
-    def fdb_add_tun(self, context, br, lvm, agent_ports, ofports):
+    def fdb_add_tun(self, context, br, lvm, agent_ports, lookup_port):
         for remote_ip, ports in agent_ports.items():
             # Ensure we have a tunnel port with this remote agent
-            ofport = ofports[lvm.network_type].get(remote_ip)
+            ofport = lookup_port(lvm.network_type, remote_ip)
             if not ofport:
                 ofport = self.setup_tunnel_port(br, remote_ip,
                                                 lvm.network_type)
@@ -181,9 +238,9 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
                 self.add_fdb_flow(br, port, remote_ip, lvm, ofport)
 
     @log.log
-    def fdb_remove_tun(self, context, br, lvm, agent_ports, ofports):
+    def fdb_remove_tun(self, context, br, lvm, agent_ports, lookup_port):
         for remote_ip, ports in agent_ports.items():
-            ofport = ofports[lvm.network_type].get(remote_ip)
+            ofport = lookup_port(lvm.network_type, remote_ip)
             if not ofport:
                 continue
             for port in ports:
@@ -218,19 +275,23 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
         :param context: RPC context.
         :param br: represent the bridge on which fdb_chg_ip_tun should be
         applied.
-        :param fdb_entries: fdb dicts that contain all mac/IP informations per
+        :param fdb_entries: fdb dicts that contain all mac/IP information per
                             agent and network.
                                {'net1':
                                 {'agent_ip':
-                                 {'before': [[mac, ip]],
-                                  'after': [[mac, ip]]
+                                 {'before': PortInfo,
+                                  'after': PortInfo
                                  }
                                 }
                                 'net2':
                                 ...
                                }
+
+                             PortInfo has .mac_address and .ip_address attrs.
+
         :param local_ip: local IP address of this agent.
-        :local_vlan_map: local VLAN map of network.
+        :param local_vlan_map: A dict to map network_id to
+            the corresponding lvm entry.
         '''
 
         for network_id, agent_ports in fdb_entries.items():
@@ -242,12 +303,14 @@ class L2populationRpcCallBackTunnelMixin(L2populationRpcCallBackMixin):
                 if agent_ip == local_ip:
                     continue
 
-                after = state.get('after')
-                for mac, ip in after:
-                    self.setup_entry_for_arp_reply(br, 'add', lvm.vlan, mac,
-                                                   ip)
+                after = state.get('after', [])
+                for mac_ip in after:
+                    self.setup_entry_for_arp_reply(br, 'add', lvm.vlan,
+                                                   mac_ip.mac_address,
+                                                   mac_ip.ip_address)
 
-                before = state.get('before')
-                for mac, ip in before:
-                    self.setup_entry_for_arp_reply(br, 'remove', lvm.vlan, mac,
-                                                   ip)
+                before = state.get('before', [])
+                for mac_ip in before:
+                    self.setup_entry_for_arp_reply(br, 'remove', lvm.vlan,
+                                                   mac_ip.mac_address,
+                                                   mac_ip.ip_address)
