@@ -10,7 +10,6 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_lib import constants
 from oslo_log import log as logging
 
 from neutron.agent.l3 import namespaces
@@ -18,6 +17,7 @@ from neutron.agent.linux import ip_lib
 
 LOG = logging.getLogger(__name__)
 SNAT_NS_PREFIX = 'snat-'
+SNAT_INT_DEV_PREFIX = 'sg-'
 
 
 class SnatNamespace(namespaces.Namespace):
@@ -28,33 +28,17 @@ class SnatNamespace(namespaces.Namespace):
         super(SnatNamespace, self).__init__(
             name, agent_conf, driver, use_ipv6)
 
-    def create(self):
-        super(SnatNamespace, self).create()
-        # Set nonlocal_bind to 1 to allow setup applications in HA mode
-        # for example ipsec from VPNaaS
-        ip_lib.set_ip_nonlocal_bind_for_namespace(self.name, 1)
-        # Set nf_conntrack_tcp_loose to 0 to ensure mid-stream
-        # TCP conversations aren't taken over by SNAT
-        cmd = ['net.netfilter.nf_conntrack_tcp_loose=0']
-        ip_lib.sysctl(cmd, namespace=self.name)
-
     @classmethod
     def get_snat_ns_name(cls, router_id):
-        return namespaces.build_ns_name(SNAT_NS_PREFIX, router_id)
+        return (SNAT_NS_PREFIX + router_id)
 
-    @namespaces.check_ns_existence
     def delete(self):
         ns_ip = ip_lib.IPWrapper(namespace=self.name)
-        for d in ns_ip.get_devices():
-            if d.name.startswith(constants.SNAT_INT_DEV_PREFIX):
+        for d in ns_ip.get_devices(exclude_loopback=True):
+            if d.name.startswith(SNAT_INT_DEV_PREFIX):
                 LOG.debug('Unplugging DVR device %s', d.name)
                 self.driver.unplug(d.name, namespace=self.name,
-                                   prefix=constants.SNAT_INT_DEV_PREFIX)
-            elif d.name.startswith(namespaces.EXTERNAL_DEV_PREFIX):
-                self.driver.unplug(
-                    d.name,
-                    namespace=self.name,
-                    prefix=namespaces.EXTERNAL_DEV_PREFIX)
+                                   prefix=SNAT_INT_DEV_PREFIX)
 
         # TODO(mrsmith): delete ext-gw-port
         LOG.debug('DVR: destroy snat ns: %s', self.name)
