@@ -295,10 +295,10 @@ class RouterInfo(object):
         ip_cidrs = common_utils.fixed_ip_cidrs(fixed_ips)
         self.driver.init_l3(interface_name, ip_cidrs, namespace=ns_name)
         for fixed_ip in fixed_ips:
-            ip_lib.send_gratuitous_arp(ns_name,
-                                       interface_name,
-                                       fixed_ip['ip_address'],
-                                       self.agent_conf.send_arp_for_ha)
+            ip_lib.send_ip_addr_adv_notif(ns_name,
+                                          interface_name,
+                                          fixed_ip['ip_address'],
+                                          self.agent_conf)
 
     def internal_network_added(self, port):
         network_id = port['network_id']
@@ -434,7 +434,6 @@ class RouterInfo(object):
 
     def _get_external_gw_ips(self, ex_gw_port):
         gateway_ips = []
-        enable_ra_on_gw = False
         if 'subnets' in ex_gw_port:
             gateway_ips = [subnet['gateway_ip']
                            for subnet in ex_gw_port['subnets']
@@ -444,11 +443,7 @@ class RouterInfo(object):
             if self.agent_conf.ipv6_gateway:
                 # ipv6_gateway configured, use address for default route.
                 gateway_ips.append(self.agent_conf.ipv6_gateway)
-            else:
-                # ipv6_gateway is also not configured.
-                # Use RA for default route.
-                enable_ra_on_gw = True
-        return gateway_ips, enable_ra_on_gw
+        return gateway_ips
 
     def _external_gateway_added(self, ex_gw_port, interface_name,
                                 ns_name, preserve_ips):
@@ -458,7 +453,11 @@ class RouterInfo(object):
         # will be added to the interface.
         ip_cidrs = common_utils.fixed_ip_cidrs(ex_gw_port['fixed_ips'])
 
-        gateway_ips, enable_ra_on_gw = self._get_external_gw_ips(ex_gw_port)
+        gateway_ips = self._get_external_gw_ips(ex_gw_port)
+        enable_ra_on_gw = False
+        if self.use_ipv6 and not self.is_v6_gateway_set(gateway_ips):
+            # There is no IPv6 gw_ip, use RouterAdvt for default route.
+            enable_ra_on_gw = True
         self.driver.init_l3(interface_name,
                             ip_cidrs,
                             namespace=ns_name,
@@ -467,10 +466,10 @@ class RouterInfo(object):
                             preserve_ips=preserve_ips,
                             enable_ra_on_gw=enable_ra_on_gw)
         for fixed_ip in ex_gw_port['fixed_ips']:
-            ip_lib.send_gratuitous_arp(ns_name,
-                                       interface_name,
-                                       fixed_ip['ip_address'],
-                                       self.agent_conf.send_arp_for_ha)
+            ip_lib.send_ip_addr_adv_notif(ns_name,
+                                          interface_name,
+                                          fixed_ip['ip_address'],
+                                          self.agent_conf)
 
     def is_v6_gateway_set(self, gateway_ips):
         """Check to see if list of gateway_ips has an IPv6 gateway.
