@@ -16,19 +16,18 @@
 import abc
 
 import netaddr
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import importutils
 import six
 
-from neutron.agent.common import config
+from neutron.agent.common import ovs_lib
 from neutron.agent.linux import ip_lib
-from neutron.agent.linux import ovs_lib
 from neutron.agent.linux import utils
 from neutron.common import constants as n_const
 from neutron.common import exceptions
 from neutron.extensions import flavor
-from neutron.openstack.common.gettextutils import _LE
-from neutron.openstack.common import importutils
-from neutron.openstack.common import log as logging
+from neutron.i18n import _LE, _LI
 
 
 LOG = logging.getLogger(__name__)
@@ -77,22 +76,22 @@ class LinuxInterfaceDriver(object):
 
     def __init__(self, conf):
         self.conf = conf
-        self.root_helper = config.get_root_helper(conf)
 
     def init_l3(self, device_name, ip_cidrs, namespace=None,
-                preserve_ips=[], gateway=None, extra_subnets=[]):
+                preserve_ips=[], gateway_ips=None, extra_subnets=[],
+                enable_ra_on_gw=False):
         """Set the L3 settings for the interface using data from the port.
 
         ip_cidrs: list of 'X.X.X.X/YY' strings
         preserve_ips: list of ip cidrs that should not be removed from device
+        gateway_ips: For gateway ports, list of external gateway ip addresses
+        enable_ra_on_gw: Boolean to indicate configuring acceptance of IPv6 RA
         """
-        device = ip_lib.IPDevice(device_name,
-                                 self.root_helper,
-                                 namespace=namespace)
+        device = ip_lib.IPDevice(device_name, namespace=namespace)
 
-        previous = {}
+        previous = set()
         for address in device.addr.list(scope='global', filters=['permanent']):
-            previous[address['cidr']] = address['ip_version']
+            previous.add(address['cidr'])
 
         # add new addresses
         for ip_cidr in ip_cidrs:
@@ -103,50 +102,46 @@ class LinuxInterfaceDriver(object):
             if net.version == 6:
                 ip_cidr = str(net)
             if ip_cidr in previous:
-                del previous[ip_cidr]
+                previous.remove(ip_cidr)
                 continue
 
-            # Make sure the format of this network, if IPv6, is zero-filled.
-            # The Linux netaddr library seems to do this by default (bug?),
-            # and the test verifies it, but we should force it just in case
-            # the behavior changes.  It also makes sure that non-Linux-based
-            # libraries also work correctly (e.g. OSX).
-            device.addr.add(net.version, ip_cidr,
-                            str(net.broadcast.format(netaddr.ipv6_full)))
+            device.addr.add(ip_cidr)
 
         # clean up any old addresses
-        for ip_cidr, ip_version in previous.items():
+        for ip_cidr in previous:
             if ip_cidr not in preserve_ips:
-                device.addr.delete(ip_version, ip_cidr)
-                self.delete_conntrack_state(root_helper=self.root_helper,
-                                            namespace=namespace,
-                                            ip=ip_cidr)
+                device.addr.delete(ip_cidr)
+                self.delete_conntrack_state(namespace=namespace, ip=ip_cidr)
 
-        if gateway:
-            device.route.add_gateway(gateway)
+        for gateway_ip in gateway_ips or []:
+            device.route.add_gateway(gateway_ip)
+
+        if enable_ra_on_gw:
+            self.configure_ipv6_ra(namespace, device_name)
 
         new_onlink_routes = set(s['cidr'] for s in extra_subnets)
-        existing_onlink_routes = set(device.route.list_onlink_routes())
+        existing_onlink_routes = set(
+            device.route.list_onlink_routes(n_const.IP_VERSION_4) +
+            device.route.list_onlink_routes(n_const.IP_VERSION_6))
         for route in new_onlink_routes - existing_onlink_routes:
             device.route.add_onlink_route(route)
         for route in existing_onlink_routes - new_onlink_routes:
             device.route.delete_onlink_route(route)
 
-    def delete_conntrack_state(self, root_helper, namespace, ip):
+    def delete_conntrack_state(self, namespace, ip):
         """Delete conntrack state associated with an IP address.
 
         This terminates any active connections through an IP.  Call this soon
         after removing the IP address from an interface so that new connections
         cannot be created before the IP address is gone.
 
-        root_helper: root_helper to gain root access to call conntrack
         namespace: the name of the namespace where the IP has been configured
         ip: the IP address for which state should be removed.  This can be
             passed as a string with or without /NN.  A netaddr.IPAddress or
             netaddr.Network representing the IP address can also be passed.
         """
         ip_str = str(netaddr.IPNetwork(ip).ip)
-        ip_wrapper = ip_lib.IPWrapper(root_helper, namespace=namespace)
+        ip_wrapper = ip_lib.IPWrapper(namespace=namespace)
 
         # Delete conntrack state for ingress traffic
         # If 0 flow entries have been deleted
@@ -176,6 +171,13 @@ class LinuxInterfaceDriver(object):
     def get_device_name(self, port):
         return (self.DEV_NAME_PREFIX + port.id)[:self.DEV_NAME_LEN]
 
+    @staticmethod
+    def configure_ipv6_ra(namespace, dev_name):
+        """Configure acceptance of IPv6 route advertisements on an intf."""
+        # Learn the default router's IP address via RAs
+        ip_lib.IPWrapper(namespace=namespace).netns.execute(
+            ['sysctl', '-w', 'net.ipv6.conf.%s.accept_ra=2' % dev_name])
+
     @abc.abstractmethod
     def plug(self, network_id, port_id, device_name, mac_address,
              bridge=None, namespace=None, prefix=None):
@@ -213,17 +215,14 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
 
     def _ovs_add_port(self, bridge, device_name, port_id, mac_address,
                       internal=True):
-        cmd = ['ovs-vsctl', '--', '--if-exists', 'del-port', device_name, '--',
-               'add-port', bridge, device_name]
+        attrs = [('external_ids', {'iface-id': port_id,
+                                   'iface-status': 'active',
+                                   'attached-mac': mac_address})]
         if internal:
-            cmd += ['--', 'set', 'Interface', device_name, 'type=internal']
-        cmd += ['--', 'set', 'Interface', device_name,
-                'external-ids:iface-id=%s' % port_id,
-                '--', 'set', 'Interface', device_name,
-                'external-ids:iface-status=active',
-                '--', 'set', 'Interface', device_name,
-                'external-ids:attached-mac=%s' % mac_address]
-        utils.execute(cmd, self.root_helper)
+            attrs.insert(0, ('type', 'internal'))
+
+        ovs = ovs_lib.OVSBridge(bridge)
+        ovs.replace_port(device_name, *attrs)
 
     def plug(self, network_id, port_id, device_name, mac_address,
              bridge=None, namespace=None, prefix=None):
@@ -231,13 +230,11 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
         if not bridge:
             bridge = self.conf.ovs_integration_bridge
 
-        if not ip_lib.device_exists(device_name,
-                                    self.root_helper,
-                                    namespace=namespace):
+        if not ip_lib.device_exists(device_name, namespace=namespace):
 
             self.check_bridge_exists(bridge)
 
-            ip = ip_lib.IPWrapper(self.root_helper)
+            ip = ip_lib.IPWrapper()
             tap_name = self._get_tap_name(device_name, prefix)
 
             if self.conf.ovs_use_veth:
@@ -268,7 +265,7 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
             if self.conf.ovs_use_veth:
                 root_dev.link.set_up()
         else:
-            LOG.info(_("Device %s already exists"), device_name)
+            LOG.info(_LI("Device %s already exists"), device_name)
 
     def unplug(self, device_name, bridge=None, namespace=None, prefix=None):
         """Unplug the interface."""
@@ -277,18 +274,16 @@ class OVSInterfaceDriver(LinuxInterfaceDriver):
 
         tap_name = self._get_tap_name(device_name, prefix)
         self.check_bridge_exists(bridge)
-        ovs = ovs_lib.OVSBridge(bridge, self.root_helper)
+        ovs = ovs_lib.OVSBridge(bridge)
 
         try:
             ovs.delete_port(tap_name)
             if self.conf.ovs_use_veth:
-                device = ip_lib.IPDevice(device_name,
-                                         self.root_helper,
-                                         namespace)
+                device = ip_lib.IPDevice(device_name, namespace=namespace)
                 device.link.delete()
-                LOG.debug(_("Unplugged interface '%s'"), device_name)
+                LOG.debug("Unplugged interface '%s'", device_name)
         except RuntimeError:
-            LOG.error(_("Failed unplugging interface '%s'"),
+            LOG.error(_LE("Failed unplugging interface '%s'"),
                       device_name)
 
 
@@ -299,10 +294,8 @@ class MidonetInterfaceDriver(LinuxInterfaceDriver):
         """This method is called by the Dhcp agent or by the L3 agent
         when a new network is created
         """
-        if not ip_lib.device_exists(device_name,
-                                    self.root_helper,
-                                    namespace=namespace):
-            ip = ip_lib.IPWrapper(self.root_helper)
+        if not ip_lib.device_exists(device_name, namespace=namespace):
+            ip = ip_lib.IPWrapper()
             tap_name = device_name.replace(prefix or n_const.TAP_DEVICE_PREFIX,
                                            n_const.TAP_DEVICE_PREFIX)
 
@@ -320,24 +313,21 @@ class MidonetInterfaceDriver(LinuxInterfaceDriver):
             root_dev.link.set_up()
 
             cmd = ['mm-ctl', '--bind-port', port_id, device_name]
-            utils.execute(cmd, self.root_helper)
+            utils.execute(cmd, run_as_root=True)
 
         else:
-            LOG.info(_("Device %s already exists"), device_name)
+            LOG.info(_LI("Device %s already exists"), device_name)
 
     def unplug(self, device_name, bridge=None, namespace=None, prefix=None):
         # the port will be deleted by the dhcp agent that will call the plugin
-        device = ip_lib.IPDevice(device_name,
-                                 self.root_helper,
-                                 namespace)
+        device = ip_lib.IPDevice(device_name, namespace=namespace)
         try:
             device.link.delete()
         except RuntimeError:
-            LOG.error(_("Failed unplugging interface '%s'"), device_name)
-        LOG.debug(_("Unplugged interface '%s'"), device_name)
+            LOG.error(_LE("Failed unplugging interface '%s'"), device_name)
+        LOG.debug("Unplugged interface '%s'", device_name)
 
-        ip_lib.IPWrapper(
-            self.root_helper, namespace).garbage_collect_namespace()
+        ip_lib.IPWrapper(namespace=namespace).garbage_collect_namespace()
 
 
 class IVSInterfaceDriver(LinuxInterfaceDriver):
@@ -356,16 +346,14 @@ class IVSInterfaceDriver(LinuxInterfaceDriver):
 
     def _ivs_add_port(self, device_name, port_id, mac_address):
         cmd = ['ivs-ctl', 'add-port', device_name]
-        utils.execute(cmd, self.root_helper)
+        utils.execute(cmd, run_as_root=True)
 
     def plug(self, network_id, port_id, device_name, mac_address,
              bridge=None, namespace=None, prefix=None):
         """Plug in the interface."""
-        if not ip_lib.device_exists(device_name,
-                                    self.root_helper,
-                                    namespace=namespace):
+        if not ip_lib.device_exists(device_name, namespace=namespace):
 
-            ip = ip_lib.IPWrapper(self.root_helper)
+            ip = ip_lib.IPWrapper()
             tap_name = self._get_tap_name(device_name, prefix)
 
             root_dev, ns_dev = ip.add_veth(tap_name, device_name)
@@ -386,21 +374,19 @@ class IVSInterfaceDriver(LinuxInterfaceDriver):
             ns_dev.link.set_up()
             root_dev.link.set_up()
         else:
-            LOG.info(_("Device %s already exists"), device_name)
+            LOG.info(_LI("Device %s already exists"), device_name)
 
     def unplug(self, device_name, bridge=None, namespace=None, prefix=None):
         """Unplug the interface."""
         tap_name = self._get_tap_name(device_name, prefix)
         try:
             cmd = ['ivs-ctl', 'del-port', tap_name]
-            utils.execute(cmd, self.root_helper)
-            device = ip_lib.IPDevice(device_name,
-                                     self.root_helper,
-                                     namespace)
+            utils.execute(cmd, run_as_root=True)
+            device = ip_lib.IPDevice(device_name, namespace=namespace)
             device.link.delete()
-            LOG.debug(_("Unplugged interface '%s'"), device_name)
+            LOG.debug("Unplugged interface '%s'", device_name)
         except RuntimeError:
-            LOG.error(_("Failed unplugging interface '%s'"),
+            LOG.error(_LE("Failed unplugging interface '%s'"),
                       device_name)
 
 
@@ -412,10 +398,8 @@ class BridgeInterfaceDriver(LinuxInterfaceDriver):
     def plug(self, network_id, port_id, device_name, mac_address,
              bridge=None, namespace=None, prefix=None):
         """Plugin the interface."""
-        if not ip_lib.device_exists(device_name,
-                                    self.root_helper,
-                                    namespace=namespace):
-            ip = ip_lib.IPWrapper(self.root_helper)
+        if not ip_lib.device_exists(device_name, namespace=namespace):
+            ip = ip_lib.IPWrapper()
 
             # Enable agent to define the prefix
             tap_name = device_name.replace(prefix or self.DEV_NAME_PREFIX,
@@ -433,16 +417,16 @@ class BridgeInterfaceDriver(LinuxInterfaceDriver):
             ns_veth.link.set_up()
 
         else:
-            LOG.info(_("Device %s already exists"), device_name)
+            LOG.info(_LI("Device %s already exists"), device_name)
 
     def unplug(self, device_name, bridge=None, namespace=None, prefix=None):
         """Unplug the interface."""
-        device = ip_lib.IPDevice(device_name, self.root_helper, namespace)
+        device = ip_lib.IPDevice(device_name, namespace=namespace)
         try:
             device.link.delete()
-            LOG.debug(_("Unplugged interface '%s'"), device_name)
+            LOG.debug("Unplugged interface '%s'", device_name)
         except RuntimeError:
-            LOG.error(_("Failed unplugging interface '%s'"),
+            LOG.error(_LE("Failed unplugging interface '%s'"),
                       device_name)
 
 
@@ -476,11 +460,11 @@ class MetaInterfaceDriver(LinuxInterfaceDriver):
 
     def _set_device_plugin_tag(self, network_id, device_name, namespace=None):
         plugin_tag = self._get_flavor_by_network_id(network_id)
-        device = ip_lib.IPDevice(device_name, self.conf.root_helper, namespace)
+        device = ip_lib.IPDevice(device_name, namespace=namespace)
         device.link.set_alias(plugin_tag)
 
     def _get_device_plugin_tag(self, device_name, namespace=None):
-        device = ip_lib.IPDevice(device_name, self.conf.root_helper, namespace)
+        device = ip_lib.IPDevice(device_name, namespace=namespace)
         return device.link.alias
 
     def get_device_name(self, port):
@@ -501,6 +485,6 @@ class MetaInterfaceDriver(LinuxInterfaceDriver):
         return driver.unplug(device_name, bridge, namespace, prefix)
 
     def _load_driver(self, driver_provider):
-        LOG.debug(_("Driver location: %s"), driver_provider)
+        LOG.debug("Driver location: %s", driver_provider)
         plugin_klass = importutils.import_class(driver_provider)
         return plugin_klass(self.conf)
