@@ -16,8 +16,8 @@
 from oslo_log import log as logging
 from oslo_utils import excutils
 
-from neutron.agent.common import async_process
-from neutron.agent.linux import ip_lib
+from neutron.agent.linux import async_process
+from neutron.i18n import _LE
 
 LOG = logging.getLogger(__name__)
 
@@ -40,18 +40,18 @@ class IPMonitorEvent(object):
             first_word = route[0]
         except IndexError:
             with excutils.save_and_reraise_exception():
-                LOG.error('Unable to parse route "%s"', line)
+                LOG.error(_LE('Unable to parse route "%s"'), line)
 
         added = (first_word != 'Deleted')
         if not added:
             route = route[1:]
 
         try:
-            interface = ip_lib.remove_interface_suffix(route[1])
+            interface = route[1]
             cidr = route[3]
         except IndexError:
             with excutils.save_and_reraise_exception():
-                LOG.error('Unable to parse route "%s"', line)
+                LOG.error(_LE('Unable to parse route "%s"'), line)
 
         return cls(line, added, interface, cidr)
 
@@ -64,7 +64,7 @@ class IPMonitor(async_process.AsyncProcess):
         m.start()
         for iterable in m:
             event = IPMonitorEvent.from_text(iterable)
-            print(event, event.added, event.interface, event.cidr)
+            print event, event.added, event.interface, event.cidr
     """
 
     def __init__(self,
