@@ -17,28 +17,27 @@ import sys
 from oslo_config import cfg
 from oslo_log import log as logging
 
+from neutron.agent.common import config as agent_conf
 from neutron.agent.metadata import agent
-from neutron.common import cache_utils as cache
+from neutron.agent.metadata import config as metadata_conf
 from neutron.common import config
 from neutron.common import utils
-from neutron.conf.agent import common as agent_conf
-from neutron.conf.agent.metadata import config as meta
-from neutron.conf import service as service_conf
+from neutron.openstack.common.cache import cache
 
 LOG = logging.getLogger(__name__)
 
 
 def main():
-    config.register_common_config_options()
-    meta.register_meta_conf_opts(meta.SHARED_OPTS)
-    meta.register_meta_conf_opts(meta.UNIX_DOMAIN_METADATA_PROXY_OPTS)
-    meta.register_meta_conf_opts(meta.METADATA_PROXY_HANDLER_OPTS)
+    cfg.CONF.register_opts(metadata_conf.SHARED_OPTS)
+    cfg.CONF.register_opts(metadata_conf.UNIX_DOMAIN_METADATA_PROXY_OPTS)
+    cfg.CONF.register_opts(metadata_conf.METADATA_PROXY_HANDLER_OPTS)
     cache.register_oslo_configs(cfg.CONF)
+    cfg.CONF.set_default(name='cache_url', default='memory://?default_ttl=5')
     agent_conf.register_agent_state_opts_helper(cfg.CONF)
-    service_conf.register_service_opts(service_conf.RPC_EXTRA_OPTS, cfg.CONF)
-
     config.init(sys.argv[1:])
     config.setup_logging()
     utils.log_opt_values(LOG)
+    # metadata agent need not connect DB
+    cfg.CONF.set_override("connection", "", "database")
     proxy = agent.UnixDomainMetadataProxy(cfg.CONF)
     proxy.run()
