@@ -16,14 +16,16 @@
 
 import functools
 
-from oslo.config import cfg
-from oslo import messaging
+from oslo_config import cfg
+from oslo_log import log as logging
+import oslo_messaging
+from oslo_utils import importutils
 
 from neutron.agent import firewall
+from neutron.common import constants
+from neutron.common import rpc as n_rpc
 from neutron.common import topics
-from neutron.openstack.common.gettextutils import _LI, _LW
-from neutron.openstack.common import importutils
-from neutron.openstack.common import log as logging
+from neutron.i18n import _LI, _LW
 
 LOG = logging.getLogger(__name__)
 # history
@@ -64,8 +66,8 @@ def _is_valid_driver_combination():
 
 def is_firewall_enabled():
     if not _is_valid_driver_combination():
-        LOG.warn(_("Driver configuration doesn't match with "
-                   "enable_security_group"))
+        LOG.warn(_LW("Driver configuration doesn't match with "
+                     "enable_security_group"))
 
     return cfg.CONF.SECURITYGROUP.enable_security_group
 
@@ -83,24 +85,35 @@ def disable_security_group_extension_by_config(aliases):
         _disable_extension('allowed-address-pairs', aliases)
 
 
-class SecurityGroupServerRpcApiMixin(object):
-    """A mix-in that enable SecurityGroup support in plugin rpc."""
+class SecurityGroupServerRpcApi(object):
+    """RPC client for security group methods in the plugin.
+
+    This class implements the client side of an rpc interface.  This interface
+    is used by agents to call security group related methods implemented on the
+    plugin side.  The other side of this interface can be found in
+    neutron.api.rpc.handlers.SecurityGroupServerRpcCallback.  For more
+    information about changing rpc interfaces, see
+    doc/source/devref/rpc_api.rst.
+    """
+    def __init__(self, topic):
+        target = oslo_messaging.Target(
+            topic=topic, version='1.0',
+            namespace=constants.RPC_NAMESPACE_SECGROUP)
+        self.client = n_rpc.get_client(target)
 
     def security_group_rules_for_devices(self, context, devices):
-        LOG.debug(_("Get security group rules "
-                    "for devices via rpc %r"), devices)
-        return self.call(context,
-                         self.make_msg('security_group_rules_for_devices',
-                                       devices=devices),
-                         version='1.1')
+        LOG.debug("Get security group rules "
+                  "for devices via rpc %r", devices)
+        cctxt = self.client.prepare(version='1.1')
+        return cctxt.call(context, 'security_group_rules_for_devices',
+                          devices=devices)
 
     def security_group_info_for_devices(self, context, devices):
         LOG.debug("Get security group information for devices via rpc %r",
                   devices)
-        return self.call(context,
-                         self.make_msg('security_group_info_for_devices',
-                                       devices=devices),
-                         version='1.2')
+        cctxt = self.client.prepare(version='1.2')
+        return cctxt.call(context, 'security_group_info_for_devices',
+                          devices=devices)
 
 
 class SecurityGroupAgentRpcCallbackMixin(object):
@@ -111,9 +124,9 @@ class SecurityGroupAgentRpcCallbackMixin(object):
     sg_agent = None
 
     def _security_groups_agent_not_set(self):
-        LOG.warning(_("Security group agent binding currently not set. "
-                      "This should be set by the end of the init "
-                      "process."))
+        LOG.warning(_LW("Security group agent binding currently not set. "
+                        "This should be set by the end of the init "
+                        "process."))
 
     def security_groups_rule_updated(self, context, **kwargs):
         """Callback for security group rule update.
@@ -121,8 +134,8 @@ class SecurityGroupAgentRpcCallbackMixin(object):
         :param security_groups: list of updated security_groups
         """
         security_groups = kwargs.get('security_groups', [])
-        LOG.debug(
-            _("Security group rule updated on remote: %s"), security_groups)
+        LOG.debug("Security group rule updated on remote: %s",
+                  security_groups)
         if not self.sg_agent:
             return self._security_groups_agent_not_set()
         self.sg_agent.security_groups_rule_updated(security_groups)
@@ -133,31 +146,34 @@ class SecurityGroupAgentRpcCallbackMixin(object):
         :param security_groups: list of updated security_groups
         """
         security_groups = kwargs.get('security_groups', [])
-        LOG.debug(
-            _("Security group member updated on remote: %s"), security_groups)
+        LOG.debug("Security group member updated on remote: %s",
+                  security_groups)
         if not self.sg_agent:
             return self._security_groups_agent_not_set()
         self.sg_agent.security_groups_member_updated(security_groups)
 
     def security_groups_provider_updated(self, context, **kwargs):
         """Callback for security group provider update."""
-        LOG.debug(_("Provider rule updated"))
+        LOG.debug("Provider rule updated")
         if not self.sg_agent:
             return self._security_groups_agent_not_set()
         self.sg_agent.security_groups_provider_updated()
 
 
-class SecurityGroupAgentRpcMixin(object):
-    """A mix-in that enable SecurityGroup agent
-    support in agent implementations.
-    """
+class SecurityGroupAgentRpc(object):
+    """Enables SecurityGroup agent support in agent implementations."""
+
+    def __init__(self, context, plugin_rpc, defer_refresh_firewall=False):
+        self.context = context
+        self.plugin_rpc = plugin_rpc
+        self.init_firewall(defer_refresh_firewall)
 
     def init_firewall(self, defer_refresh_firewall=False):
         firewall_driver = cfg.CONF.SECURITYGROUP.firewall_driver
-        LOG.debug(_("Init firewall settings (driver=%s)"), firewall_driver)
+        LOG.debug("Init firewall settings (driver=%s)", firewall_driver)
         if not _is_valid_driver_combination():
-            LOG.warn(_("Driver configuration doesn't match "
-                       "with enable_security_group"))
+            LOG.warn(_LW("Driver configuration doesn't match "
+                         "with enable_security_group"))
         if not firewall_driver:
             firewall_driver = 'neutron.agent.firewall.NoopFirewallDriver'
         self.firewall = importutils.import_object(firewall_driver)
@@ -182,7 +198,7 @@ class SecurityGroupAgentRpcMixin(object):
         try:
             self.plugin_rpc.security_group_info_for_devices(
                 self.context, devices=[])
-        except messaging.UnsupportedVersion:
+        except oslo_messaging.UnsupportedVersion:
             LOG.warning(_LW('security_group_info_for_devices rpc call not '
                             'supported by the server, falling back to old '
                             'security_group_rules_for_devices which scales '
@@ -199,7 +215,8 @@ class SecurityGroupAgentRpcMixin(object):
                          "or configured as NoopFirewallDriver."),
                          func.__name__)
             else:
-                return func(self, *args, **kwargs)
+                return func(self,  # pylint: disable=not-callable
+                            *args, **kwargs)
         return decorated_function
 
     @skip_if_noopfirewall_or_firewall_disabled
@@ -257,8 +274,8 @@ class SecurityGroupAgentRpcMixin(object):
                 devices.append(device['device'])
         if devices:
             if self.defer_refresh_firewall:
-                LOG.debug(_("Adding %s devices to the list of devices "
-                            "for which firewall needs to be refreshed"),
+                LOG.debug("Adding %s devices to the list of devices "
+                          "for which firewall needs to be refreshed",
                           devices)
                 self.devices_to_refilter |= set(devices)
             else:
@@ -305,7 +322,7 @@ class SecurityGroupAgentRpcMixin(object):
 
         with self.firewall.defer_apply():
             for device in devices.values():
-                LOG.debug(_("Update port filter for %s"), device['device'])
+                LOG.debug("Update port filter for %s", device['device'])
                 self.firewall.update_port_filter(device)
             if self.use_enhanced_rpc:
                 LOG.debug("Update security group information for ports %s",
@@ -345,7 +362,7 @@ class SecurityGroupAgentRpcMixin(object):
         # refresh providing a precise list of devices for which firewall
         # should be refreshed
         if global_refresh_firewall:
-            LOG.debug(_("Refreshing firewall for all filtered devices"))
+            LOG.debug("Refreshing firewall for all filtered devices")
             self.refresh_firewall()
         else:
             # If a device is both in new and updated devices
@@ -353,7 +370,7 @@ class SecurityGroupAgentRpcMixin(object):
             updated_devices = ((updated_devices | devices_to_refilter) -
                                new_devices)
             if updated_devices:
-                LOG.debug(_("Refreshing firewall for %d devices"),
+                LOG.debug("Refreshing firewall for %d devices",
                           len(updated_devices))
                 self.refresh_firewall(updated_devices)
 
@@ -369,25 +386,25 @@ class SecurityGroupAgentRpcApiMixin(object):
         """Notify rule updated security groups."""
         if not security_groups:
             return
-        self.fanout_cast(context,
-                         self.make_msg('security_groups_rule_updated',
-                                       security_groups=security_groups),
-                         version=SG_RPC_VERSION,
-                         topic=self._get_security_group_topic())
+        cctxt = self.client.prepare(version=SG_RPC_VERSION,
+                                    topic=self._get_security_group_topic(),
+                                    fanout=True)
+        cctxt.cast(context, 'security_groups_rule_updated',
+                   security_groups=security_groups)
 
     def security_groups_member_updated(self, context, security_groups):
         """Notify member updated security groups."""
         if not security_groups:
             return
-        self.fanout_cast(context,
-                         self.make_msg('security_groups_member_updated',
-                                       security_groups=security_groups),
-                         version=SG_RPC_VERSION,
-                         topic=self._get_security_group_topic())
+        cctxt = self.client.prepare(version=SG_RPC_VERSION,
+                                    topic=self._get_security_group_topic(),
+                                    fanout=True)
+        cctxt.cast(context, 'security_groups_member_updated',
+                   security_groups=security_groups)
 
     def security_groups_provider_updated(self, context):
         """Notify provider updated security groups."""
-        self.fanout_cast(context,
-                         self.make_msg('security_groups_provider_updated'),
-                         version=SG_RPC_VERSION,
-                         topic=self._get_security_group_topic())
+        cctxt = self.client.prepare(version=SG_RPC_VERSION,
+                                    topic=self._get_security_group_topic(),
+                                    fanout=True)
+        cctxt.cast(context, 'security_groups_provider_updated')
