@@ -15,21 +15,23 @@
 #    under the License.
 
 import abc
+import collections
 import imp
 import itertools
 import os
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 import routes
 import six
 import webob.dec
 import webob.exc
 
-from neutron.api.v2 import attributes
 from neutron.common import exceptions
+from neutron.common import repos
 import neutron.extensions
+from neutron.i18n import _LE, _LI, _LW
 from neutron import manager
-from neutron.openstack.common import log as logging
 from neutron import wsgi
 
 
@@ -279,7 +281,7 @@ class ExtensionMiddleware(wsgi.Middleware):
                                (resource.parent["collection_name"],
                                 resource.parent["member_name"]))
 
-            LOG.debug(_('Extended resource: %s'),
+            LOG.debug('Extended resource: %s',
                       resource.collection)
             for action, method in resource.collection_actions.iteritems():
                 conditions = dict(method=[method])
@@ -301,7 +303,7 @@ class ExtensionMiddleware(wsgi.Middleware):
         action_controllers = self._action_ext_controllers(application,
                                                           self.ext_mgr, mapper)
         for action in self.ext_mgr.get_actions():
-            LOG.debug(_('Extended action: %s'), action.action_name)
+            LOG.debug('Extended action: %s', action.action_name)
             controller = action_controllers[action.collection]
             controller.add_action(action.action_name, action.handler)
 
@@ -309,7 +311,7 @@ class ExtensionMiddleware(wsgi.Middleware):
         req_controllers = self._request_ext_controllers(application,
                                                         self.ext_mgr, mapper)
         for request_ext in self.ext_mgr.get_request_extensions():
-            LOG.debug(_('Extended request: %s'), request_ext.key)
+            LOG.debug('Extended request: %s', request_ext.key)
             controller = req_controllers[request_ext.key]
             controller.add_handler(request_ext.handler)
 
@@ -399,7 +401,7 @@ class ExtensionManager(object):
     """
 
     def __init__(self, path):
-        LOG.info(_('Initializing extension manager.'))
+        LOG.info(_LI('Initializing extension manager.'))
         self.path = path
         self.extensions = {}
         self._load_all_extensions()
@@ -477,19 +479,9 @@ class ExtensionManager(object):
                             attr_map[resource].update(resource_attrs)
                         else:
                             attr_map[resource] = resource_attrs
-                    if extended_attrs:
-                        attributes.EXT_NSES[ext.get_alias()] = (
-                            ext.get_namespace())
                 except AttributeError:
-                    LOG.exception(_("Error fetching extended attributes for "
-                                    "extension '%s'"), ext.get_name())
-                try:
-                    comp_map = ext.get_alias_namespace_compatibility_map()
-                    attributes.EXT_NSES_BC.update(comp_map)
-                except AttributeError:
-                    LOG.info(_("Extension '%s' provides no backward "
-                               "compatibility map for extended attributes"),
-                             ext.get_name())
+                    LOG.exception(_LE("Error fetching extended attributes for "
+                                      "extension '%s'"), ext.get_name())
                 processed_exts.add(ext_name)
                 del exts_to_process[ext_name]
             if len(processed_exts) == processed_ext_count:
@@ -497,8 +489,8 @@ class ExtensionManager(object):
                 break
         if exts_to_process:
             # NOTE(salv-orlando): Consider whether this error should be fatal
-            LOG.error(_("It was impossible to process the following "
-                        "extensions: %s because of missing requirements."),
+            LOG.error(_LE("It was impossible to process the following "
+                          "extensions: %s because of missing requirements."),
                       ','.join(exts_to_process.keys()))
 
         # Extending extensions' attributes map.
@@ -508,13 +500,13 @@ class ExtensionManager(object):
     def _check_extension(self, extension):
         """Checks for required methods in extension objects."""
         try:
-            LOG.debug(_('Ext name: %s'), extension.get_name())
-            LOG.debug(_('Ext alias: %s'), extension.get_alias())
-            LOG.debug(_('Ext description: %s'), extension.get_description())
-            LOG.debug(_('Ext namespace: %s'), extension.get_namespace())
-            LOG.debug(_('Ext updated: %s'), extension.get_updated())
+            LOG.debug('Ext name: %s', extension.get_name())
+            LOG.debug('Ext alias: %s', extension.get_alias())
+            LOG.debug('Ext description: %s', extension.get_description())
+            LOG.debug('Ext namespace: %s', extension.get_namespace())
+            LOG.debug('Ext updated: %s', extension.get_updated())
         except AttributeError as ex:
-            LOG.exception(_("Exception loading extension: %s"), unicode(ex))
+            LOG.exception(_LE("Exception loading extension: %s"), unicode(ex))
             return False
         return True
 
@@ -528,11 +520,12 @@ class ExtensionManager(object):
         See tests/unit/extensions/foxinsocks.py for an example extension
         implementation.
         """
+
         for path in self.path.split(':'):
             if os.path.exists(path):
                 self._load_all_extensions_from_path(path)
             else:
-                LOG.error(_("Extension path '%s' doesn't exist!"), path)
+                LOG.error(_LE("Extension path '%s' doesn't exist!"), path)
 
     def _load_all_extensions_from_path(self, path):
         # Sorting the extension list makes the order in which they
@@ -540,7 +533,7 @@ class ExtensionManager(object):
         # Neutron Servers
         for f in sorted(os.listdir(path)):
             try:
-                LOG.debug(_('Loading extension file: %s'), f)
+                LOG.debug('Loading extension file: %s', f)
                 mod_name, file_ext = os.path.splitext(os.path.split(f)[-1])
                 ext_path = os.path.join(path, f)
                 if file_ext.lower() == '.py' and not mod_name.startswith('_'):
@@ -548,16 +541,17 @@ class ExtensionManager(object):
                     ext_name = mod_name[0].upper() + mod_name[1:]
                     new_ext_class = getattr(mod, ext_name, None)
                     if not new_ext_class:
-                        LOG.warn(_('Did not find expected name '
-                                   '"%(ext_name)s" in %(file)s'),
+                        LOG.warn(_LW('Did not find expected name '
+                                     '"%(ext_name)s" in %(file)s'),
                                  {'ext_name': ext_name,
                                   'file': ext_path})
                         continue
                     new_ext = new_ext_class()
                     self.add_extension(new_ext)
             except Exception as exception:
-                LOG.warn(_("Extension file %(f)s wasn't loaded due to "
-                           "%(exception)s"), {'f': f, 'exception': exception})
+                LOG.warn(_LW("Extension file %(f)s wasn't loaded due to "
+                             "%(exception)s"),
+                         {'f': f, 'exception': exception})
 
     def add_extension(self, ext):
         # Do nothing if the extension doesn't check out
@@ -565,7 +559,7 @@ class ExtensionManager(object):
             return
 
         alias = ext.get_alias()
-        LOG.info(_('Loaded extension: %s'), alias)
+        LOG.info(_LI('Loaded extension: %s'), alias)
 
         if alias in self.extensions:
             raise exceptions.DuplicatedExtension(alias=alias)
@@ -596,7 +590,8 @@ class PluginAwareExtensionManager(ExtensionManager):
                                   alias in plugin.supported_extension_aliases)
                                  for plugin in self.plugins.values())
         if not supports_extension:
-            LOG.warn(_("Extension %s not supported by any of loaded plugins"),
+            LOG.warn(_LW("Extension %s not supported by any of loaded "
+                         "plugins"),
                      alias)
         return supports_extension
 
@@ -607,7 +602,7 @@ class PluginAwareExtensionManager(ExtensionManager):
         for plugin in self.plugins.values():
             if isinstance(plugin, extension.get_plugin_interface()):
                 return True
-        LOG.warn(_("Loaded plugins do not implement extension %s interface"),
+        LOG.warn(_LW("Loaded plugins do not implement extension %s interface"),
                  extension.get_alias())
         return False
 
@@ -669,11 +664,32 @@ class ResourceExtension(object):
 # Returns the extension paths from a config entry and the __path__
 # of neutron.extensions
 def get_extensions_path():
-    paths = ':'.join(neutron.extensions.__path__)
-    if cfg.CONF.api_extensions_path:
-        paths = ':'.join([cfg.CONF.api_extensions_path, paths])
+    paths = neutron.extensions.__path__
 
-    return paths
+    neutron_mods = repos.NeutronModules()
+    for x in neutron_mods.installed_list():
+        try:
+            paths += neutron_mods.module(x).extensions.__path__
+        except AttributeError:
+            # Occurs normally if module has no extensions sub-module
+            pass
+
+    if cfg.CONF.api_extensions_path:
+        paths.append(cfg.CONF.api_extensions_path)
+
+    # If the path has dups in it, from discovery + conf file, the duplicate
+    # import of the same module and super() do not play nicely, so weed
+    # out the duplicates, preserving search order.
+
+    z = collections.OrderedDict()
+    for x in paths:
+        z[x] = 1
+    paths = z.keys()
+
+    LOG.debug("get_extension_paths = %s", paths)
+
+    path = ':'.join(paths)
+    return path
 
 
 def append_api_extensions_path(paths):
