@@ -13,31 +13,43 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo.config import cfg
-from oslo.db import exception as db_exc
+import itertools
+import operator
+
+from oslo_config import cfg
+from oslo_db import exception as db_exc
+from oslo_log import log as logging
+import oslo_messaging
+from oslo_utils import excutils
 
 from neutron.api.v2 import attributes
 from neutron.common import constants
 from neutron.common import exceptions as n_exc
-from neutron.common import rpc as n_rpc
 from neutron.common import utils
 from neutron.extensions import portbindings
+from neutron.i18n import _LW
 from neutron import manager
-from neutron.openstack.common import excutils
-from neutron.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
 
 
-class DhcpRpcCallback(n_rpc.RpcCallback):
-    """DHCP agent RPC callback in plugin implementations."""
+class DhcpRpcCallback(object):
+    """DHCP agent RPC callback in plugin implementations.
+
+    This class implements the server side of an rpc interface.  The client
+    side of this interface can be found in
+    neutron.agent.dhcp.agent.DhcpPluginApi.  For more information about
+    changing rpc interfaces, see doc/source/devref/rpc_api.rst.
+    """
 
     # API version history:
     #     1.0 - Initial version.
     #     1.1 - Added get_active_networks_info, create_dhcp_port,
     #           and update_dhcp_port methods.
-    RPC_API_VERSION = '1.1'
+    target = oslo_messaging.Target(
+        namespace=constants.RPC_NAMESPACE_DHCP_PLUGIN,
+        version='1.1')
 
     def _get_active_networks(self, context, **kwargs):
         """Retrieve and return a list of the active networks."""
@@ -79,9 +91,9 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
                     else:
                         ctxt.reraise = True
                 net_id = port['port']['network_id']
-                LOG.warn(_("Action %(action)s for network %(net_id)s "
-                           "could not complete successfully: %(reason)s")
-                         % {"action": action, "net_id": net_id, 'reason': e})
+                LOG.warn(_LW("Action %(action)s for network %(net_id)s "
+                             "could not complete successfully: %(reason)s"),
+                         {"action": action, "net_id": net_id, 'reason': e})
 
     def get_active_networks(self, context, **kwargs):
         """Retrieve and return a list of the active network ids."""
@@ -89,14 +101,22 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         # left so that neutron-dhcp-agents will still continue to work if
         # neutron-server is upgraded and not the agent.
         host = kwargs.get('host')
-        LOG.debug(_('get_active_networks requested from %s'), host)
+        LOG.debug('get_active_networks requested from %s', host)
         nets = self._get_active_networks(context, **kwargs)
         return [net['id'] for net in nets]
 
+    def _group_by_network_id(self, res):
+        grouped = {}
+        keyfunc = operator.itemgetter('network_id')
+        for net_id, values in itertools.groupby(sorted(res, key=keyfunc),
+                                                keyfunc):
+            grouped[net_id] = list(values)
+        return grouped
+
     def get_active_networks_info(self, context, **kwargs):
         """Returns all the networks/subnets/ports in system."""
         host = kwargs.get('host')
-        LOG.debug(_('get_active_networks_info from %s'), host)
+        LOG.debug('get_active_networks_info from %s', host)
         networks = self._get_active_networks(context, **kwargs)
         plugin = manager.NeutronManager.get_plugin()
         filters = {'network_id': [network['id'] for network in networks]}
@@ -104,11 +124,11 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         filters['enable_dhcp'] = [True]
         subnets = plugin.get_subnets(context, filters=filters)
 
+        grouped_subnets = self._group_by_network_id(subnets)
+        grouped_ports = self._group_by_network_id(ports)
         for network in networks:
-            network['subnets'] = [subnet for subnet in subnets
-                                  if subnet['network_id'] == network['id']]
-            network['ports'] = [port for port in ports
-                                if port['network_id'] == network['id']]
+            network['subnets'] = grouped_subnets.get(network['id'], [])
+            network['ports'] = grouped_ports.get(network['id'], [])
 
         return networks
 
@@ -116,15 +136,15 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         """Retrieve and return a extended information about a network."""
         network_id = kwargs.get('network_id')
         host = kwargs.get('host')
-        LOG.debug(_('Network %(network_id)s requested from '
-                    '%(host)s'), {'network_id': network_id,
-                                  'host': host})
+        LOG.debug('Network %(network_id)s requested from '
+                  '%(host)s', {'network_id': network_id,
+                               'host': host})
         plugin = manager.NeutronManager.get_plugin()
         try:
             network = plugin.get_network(context, network_id)
         except n_exc.NetworkNotFound:
-            LOG.warn(_("Network %s could not be found, it might have "
-                       "been deleted concurrently."), network_id)
+            LOG.warn(_LW("Network %s could not be found, it might have "
+                         "been deleted concurrently."), network_id)
             return
         filters = dict(network_id=[network_id])
         network['subnets'] = plugin.get_subnets(context, filters=filters)
@@ -145,10 +165,10 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         # There could be more than one dhcp server per network, so create
         # a device id that combines host and network ids
 
-        LOG.debug(_('Port %(device_id)s for %(network_id)s requested from '
-                    '%(host)s'), {'device_id': device_id,
-                                  'network_id': network_id,
-                                  'host': host})
+        LOG.debug('Port %(device_id)s for %(network_id)s requested from '
+                  '%(host)s', {'device_id': device_id,
+                               'network_id': network_id,
+                               'host': host})
         plugin = manager.NeutronManager.get_plugin()
         retval = None
 
@@ -179,16 +199,16 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
 
         if retval is None:
             # No previous port exists, so create a new one.
-            LOG.debug(_('DHCP port %(device_id)s on network %(network_id)s '
-                        'does not exist on %(host)s'),
+            LOG.debug('DHCP port %(device_id)s on network %(network_id)s '
+                      'does not exist on %(host)s',
                       {'device_id': device_id,
                        'network_id': network_id,
                        'host': host})
             try:
                 network = plugin.get_network(context, network_id)
             except n_exc.NetworkNotFound:
-                LOG.warn(_("Network %s could not be found, it might have "
-                           "been deleted concurrently."), network_id)
+                LOG.warn(_LW("Network %s could not be found, it might have "
+                             "been deleted concurrently."), network_id)
                 return
 
             port_dict = dict(
@@ -219,8 +239,8 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         network_id = kwargs.get('network_id')
         device_id = kwargs.get('device_id')
 
-        LOG.debug(_('DHCP port deletion for %(network_id)s request from '
-                    '%(host)s'),
+        LOG.debug('DHCP port deletion for %(network_id)s request from '
+                  '%(host)s',
                   {'network_id': network_id, 'host': host})
         plugin = manager.NeutronManager.get_plugin()
         plugin.delete_ports_by_device_id(context, device_id, network_id)
@@ -232,8 +252,8 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         device_id = kwargs.get('device_id')
         subnet_id = kwargs.get('subnet_id')
 
-        LOG.debug(_('DHCP port remove fixed_ip for %(subnet_id)s request '
-                    'from %(host)s'),
+        LOG.debug('DHCP port remove fixed_ip for %(subnet_id)s request '
+                  'from %(host)s',
                   {'subnet_id': subnet_id, 'host': host})
         plugin = manager.NeutronManager.get_plugin()
         filters = dict(network_id=[network_id], device_id=[device_id])
@@ -256,8 +276,8 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         # neutron-server is upgraded and not the agent.
         host = kwargs.get('host')
 
-        LOG.warning(_('Updating lease expiration is now deprecated. Issued  '
-                      'from host %s.'), host)
+        LOG.warning(_LW('Updating lease expiration is now deprecated. Issued  '
+                        'from host %s.'), host)
 
     def create_dhcp_port(self, context, **kwargs):
         """Create and return dhcp port information.
@@ -267,8 +287,8 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         """
         host = kwargs.get('host')
         port = kwargs.get('port')
-        LOG.debug(_('Create dhcp port %(port)s '
-                    'from %(host)s.'),
+        LOG.debug('Create dhcp port %(port)s '
+                  'from %(host)s.',
                   {'port': port,
                    'host': host})
 
@@ -284,9 +304,10 @@ class DhcpRpcCallback(n_rpc.RpcCallback):
         host = kwargs.get('host')
         port = kwargs.get('port')
         port['id'] = kwargs.get('port_id')
-        LOG.debug(_('Update dhcp port %(port)s '
-                    'from %(host)s.'),
+        LOG.debug('Update dhcp port %(port)s '
+                  'from %(host)s.',
                   {'port': port,
                    'host': host})
+        port['port'][portbindings.HOST_ID] = host
         plugin = manager.NeutronManager.get_plugin()
         return self._port_action(plugin, context, port, 'update_port')
