@@ -103,33 +103,70 @@ class L3RpcCallback(object):
                                                   router.get('gw_port_host'),
                                                   p, router['id'])
             else:
-                self._ensure_host_set_on_port(context, host,
-                                              router.get('gw_port'),
-                                              router['id'])
+                self._ensure_host_set_on_port(
+                    context, host,
+                    router.get('gw_port'),
+                    router['id'],
+                    ha_router_port=router.get('ha'))
             for interface in router.get(constants.INTERFACE_KEY, []):
-                self._ensure_host_set_on_port(context, host,
-                                              interface, router['id'])
+                self._ensure_host_set_on_port(
+                    context,
+                    host,
+                    interface,
+                    router['id'],
+                    ha_router_port=router.get('ha'))
             interface = router.get(constants.HA_INTERFACE_KEY)
             if interface:
                 self._ensure_host_set_on_port(context, host, interface,
                                               router['id'])
 
-    def _ensure_host_set_on_port(self, context, host, port, router_id=None):
+    def _ensure_host_set_on_port(self, context, host, port, router_id=None,
+                                 ha_router_port=False):
         if (port and
             (port.get('device_owner') !=
              constants.DEVICE_OWNER_DVR_INTERFACE and
              port.get(portbindings.HOST_ID) != host or
              port.get(portbindings.VIF_TYPE) ==
              portbindings.VIF_TYPE_BINDING_FAILED)):
-            # All ports, including ports created for SNAT'ing for
-            # DVR are handled here
-            try:
-                self.plugin.update_port(context, port['id'],
-                                        {'port': {portbindings.HOST_ID: host}})
-            except exceptions.PortNotFound:
-                LOG.debug("Port %(port)s not found while updating "
-                          "agent binding for router %(router)s.",
-                          {"port": port['id'], "router": router_id})
+
+            # Ports owned by non-HA routers are bound again if they're
+            # already bound but the router moved to another host.
+            if not ha_router_port:
+                # All ports, including ports created for SNAT'ing for
+                # DVR are handled here
+                try:
+                    self.plugin.update_port(
+                        context,
+                        port['id'],
+                        {'port': {portbindings.HOST_ID: host}})
+                except exceptions.PortNotFound:
+                    LOG.debug("Port %(port)s not found while updating "
+                              "agent binding for router %(router)s.",
+                              {"port": port['id'], "router": router_id})
+            # Ports owned by HA routers should only be bound once, if
+            # they are unbound. These ports are moved when an agent reports
+            # that one of its routers moved to the active state.
+            else:
+                if not port.get(portbindings.HOST_ID):
+                    active_host = (
+                        self.l3plugin.get_active_host_for_ha_router(
+                            context, router_id))
+                    if active_host:
+                        host = active_host
+                    # If there is currently no active router instance (For
+                    # example it's a new router), the host that requested
+                    # the routers (Essentially a random host) will do. The
+                    # port binding will be corrected when an active is
+                    # elected.
+                    try:
+                        self.plugin.update_port(
+                            context,
+                            port['id'],
+                            {'port': {portbindings.HOST_ID: host}})
+                    except exceptions.PortNotFound:
+                        LOG.debug("Port %(port)s not found while updating "
+                                  "agent binding for router %(router)s.",
+                                  {"port": port['id'], "router": router_id})
         elif (port and
               port.get('device_owner') ==
               constants.DEVICE_OWNER_DVR_INTERFACE):
