@@ -14,10 +14,12 @@
 #    under the License.
 
 import copy
-import netaddr
-import webob.exc
 
-from oslo.config import cfg
+import netaddr
+from oslo_config import cfg
+from oslo_log import log as logging
+from oslo_utils import excutils
+import webob.exc
 
 from neutron.api import api_common
 from neutron.api.rpc.agentnotifiers import dhcp_rpc_agent_api
@@ -26,8 +28,8 @@ from neutron.api.v2 import resource as wsgi_resource
 from neutron.common import constants as const
 from neutron.common import exceptions
 from neutron.common import rpc as n_rpc
-from neutron.openstack.common import excutils
-from neutron.openstack.common import log as logging
+from neutron.i18n import _LE, _LI
+from neutron.openstack.common import policy as common_policy
 from neutron import policy
 from neutron import quota
 
@@ -41,6 +43,7 @@ FAULT_MAP = {exceptions.NotFound: webob.exc.HTTPNotFound,
              exceptions.ServiceUnavailable: webob.exc.HTTPServiceUnavailable,
              exceptions.NotAuthorized: webob.exc.HTTPForbidden,
              netaddr.AddrFormatError: webob.exc.HTTPBadRequest,
+             common_policy.PolicyNotAuthorized: webob.exc.HTTPForbidden
              }
 
 
@@ -87,8 +90,8 @@ class Controller(object):
                     _("Native pagination depend on native sorting")
                 )
             if not self._allow_sorting:
-                LOG.info(_("Allow sorting is enabled because native "
-                           "pagination requires native sorting"))
+                LOG.info(_LI("Allow sorting is enabled because native "
+                             "pagination requires native sorting"))
                 self._allow_sorting = True
 
         if parent:
@@ -141,7 +144,8 @@ class Controller(object):
                     context,
                     '%s:%s' % (self._plugin_handlers[self.SHOW], attr_name),
                     data,
-                    might_not_exist=True):
+                    might_not_exist=True,
+                    pluralized=self._collection):
                     # this attribute is visible, check next one
                     continue
             # if the code reaches this point then either the policy check
@@ -187,7 +191,7 @@ class Controller(object):
                 # Fetch the resource and verify if the user can access it
                 try:
                     resource = self._item(request, id, True)
-                except exceptions.PolicyNotAuthorized:
+                except common_policy.PolicyNotAuthorized:
                     msg = _('The resource could not be found.')
                     raise webob.exc.HTTPNotFound(msg)
                 body = kwargs.pop('body', None)
@@ -196,7 +200,10 @@ class Controller(object):
                     arg_list.append(body)
                 # It is ok to raise a 403 because accessibility to the
                 # object was checked earlier in this method
-                policy.enforce(request.context, name, resource)
+                policy.enforce(request.context,
+                               name,
+                               resource,
+                               pluralized=self._collection)
                 return getattr(self._plugin, name)(*arg_list, **kwargs)
             return _handle_action
         else:
@@ -251,7 +258,8 @@ class Controller(object):
                         if policy.check(request.context,
                                         self._plugin_handlers[self.SHOW],
                                         obj,
-                                        plugin=self._plugin)]
+                                        plugin=self._plugin,
+                                        pluralized=self._collection)]
         # Use the first element in the list for discriminating which attributes
         # should be filtered out because of authZ policies
         # fields_to_add contains a list of attributes added for request policy
@@ -284,7 +292,10 @@ class Controller(object):
         # FIXME(salvatore-orlando): obj_getter might return references to
         # other resources. Must check authZ on them too.
         if do_authz:
-            policy.enforce(request.context, action, obj)
+            policy.enforce(request.context,
+                           action,
+                           obj,
+                           pluralized=self._collection)
         return obj
 
     def _send_dhcp_notification(self, context, data, methodname):
@@ -326,7 +337,7 @@ class Controller(object):
                                           field_list=field_list,
                                           parent_id=parent_id),
                                fields_to_strip=added_fields)}
-        except exceptions.PolicyNotAuthorized:
+        except common_policy.PolicyNotAuthorized:
             # To avoid giving away information, pretend that it
             # doesn't exist
             msg = _('The resource could not be found.')
@@ -348,25 +359,26 @@ class Controller(object):
             return objs
         # Note(salvatore-orlando): broad catch as in theory a plugin
         # could raise any kind of exception
-        except Exception as ex:
-            for obj in objs:
-                obj_deleter = getattr(self._plugin,
-                                      self._plugin_handlers[self.DELETE])
-                try:
-                    kwargs = ({self._parent_id_name: parent_id} if parent_id
-                              else {})
-                    obj_deleter(request.context, obj['id'], **kwargs)
-                except Exception:
-                    # broad catch as our only purpose is to log the exception
-                    LOG.exception(_("Unable to undo add for "
-                                    "%(resource)s %(id)s"),
-                                  {'resource': self._resource,
-                                   'id': obj['id']})
-            # TODO(salvatore-orlando): The object being processed when the
-            # plugin raised might have been created or not in the db.
-            # We need a way for ensuring that if it has been created,
-            # it is then deleted
-            raise ex
+        except Exception:
+            with excutils.save_and_reraise_exception():
+                for obj in objs:
+                    obj_deleter = getattr(self._plugin,
+                                          self._plugin_handlers[self.DELETE])
+                    try:
+                        kwargs = ({self._parent_id_name: parent_id}
+                                  if parent_id else {})
+                        obj_deleter(request.context, obj['id'], **kwargs)
+                    except Exception:
+                        # broad catch as our only purpose is to log the
+                        # exception
+                        LOG.exception(_LE("Unable to undo add for "
+                                          "%(resource)s %(id)s"),
+                                      {'resource': self._resource,
+                                       'id': obj['id']})
+                # TODO(salvatore-orlando): The object being processed when the
+                # plugin raised might have been created or not in the db.
+                # We need a way for ensuring that if it has been created,
+                # it is then deleted
 
     def create(self, request, body=None, **kwargs):
         """Creates a new instance of the requested entity."""
@@ -394,7 +406,8 @@ class Controller(object):
                                                     item[self._resource])
             policy.enforce(request.context,
                            action,
-                           item[self._resource])
+                           item[self._resource],
+                           pluralized=self._collection)
             try:
                 tenant_id = item[self._resource]['tenant_id']
                 count = quota.QUOTAS.count(request.context, self._resource,
@@ -465,8 +478,9 @@ class Controller(object):
         try:
             policy.enforce(request.context,
                            action,
-                           obj)
-        except exceptions.PolicyNotAuthorized:
+                           obj,
+                           pluralized=self._collection)
+        except common_policy.PolicyNotAuthorized:
             # To avoid giving away information, pretend that it
             # doesn't exist
             msg = _('The resource could not be found.')
@@ -520,8 +534,9 @@ class Controller(object):
         try:
             policy.enforce(request.context,
                            action,
-                           orig_obj)
-        except exceptions.PolicyNotAuthorized:
+                           orig_obj,
+                           pluralized=self._collection)
+        except common_policy.PolicyNotAuthorized:
             with excutils.save_and_reraise_exception() as ctxt:
                 # If a tenant is modifying it's own object, it's safe to return
                 # a 403. Otherwise, pretend that it doesn't exist to avoid
@@ -579,7 +594,7 @@ class Controller(object):
         if not body:
             raise webob.exc.HTTPBadRequest(_("Resource body required"))
 
-        LOG.debug(_("Request body: %(body)s"), {'body': body})
+        LOG.debug("Request body: %(body)s", {'body': body})
         if collection in body:
             if not allow_bulk:
                 raise webob.exc.HTTPBadRequest(_("Bulk operation "
@@ -652,7 +667,7 @@ class Controller(object):
     def _validate_network_tenant_ownership(self, request, resource_item):
         # TODO(salvatore-orlando): consider whether this check can be folded
         # in the policy engine
-        if (request.context.is_admin or
+        if (request.context.is_admin or request.context.is_advsvc or
                 self._resource not in ('port', 'subnet')):
             return
         network = self._plugin.get_network(
