@@ -10,24 +10,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-# String literals representing core resources.
-AGENT = 'agent'
-EXTERNAL_NETWORK = 'external_network'
-FLOATING_IP = 'floatingip'
-NETWORK = 'network'
-NETWORKS = 'networks'
 PORT = 'port'
-PORTS = 'ports'
-PORT_DEVICE = 'port_device'
-PROCESS = 'process'
 ROUTER = 'router'
 ROUTER_GATEWAY = 'router_gateway'
 ROUTER_INTERFACE = 'router_interface'
 SECURITY_GROUP = 'security_group'
 SECURITY_GROUP_RULE = 'security_group_rule'
-SEGMENT = 'segment'
-SEGMENT_HOST_MAPPING = 'segment_host_mapping'
-SUBNET = 'subnet'
-SUBNETS = 'subnets'
-SUBNET_GATEWAY = 'subnet_gateway'
-SUBNETPOOL_ADDRESS_SCOPE = 'subnetpool_address_scope'
+
+VALID = (
+    PORT,
+    ROUTER,
+    ROUTER_GATEWAY,
+    ROUTER_INTERFACE,
+    SECURITY_GROUP,
+    SECURITY_GROUP_RULE,
+)
