@@ -511,6 +511,10 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase):
                                       port_id=port['id'],
                                       device_id=port['device_id'])
 
+            if not port['fixed_ips']:
+                msg = _LE('Router port must have at least one fixed IP')
+                raise n_exc.BadRequest(resource='router', msg=msg)
+
             # Only allow one router port with IPv6 subnets per network id
             if self._port_has_ipv6_address(port):
                 for existing_port in (rp.port for rp in router.attached_ports):
@@ -1150,7 +1154,7 @@ class L3_NAT_dbonly_mixin(l3.RouterPluginBase):
             return []
         qry = context.session.query(RouterPort)
         qry = qry.filter(
-            Router.id.in_(router_ids),
+            RouterPort.router_id.in_(router_ids),
             RouterPort.port_type.in_(device_owners)
         )
 
