@@ -34,8 +34,3 @@ def upgrade():
     op.add_column('ml2_network_segments',
                   sa.Column('is_dynamic', sa.Boolean(), nullable=False,
                             server_default=sa.sql.false()))
-
-
-def downgrade():
-
-    op.drop_column('ml2_network_segments', 'is_dynamic')
