@@ -32,12 +32,11 @@ revision = '2b801560a332'
 down_revision = '2d2a8a565438'
 
 from alembic import op
-from oslo_utils import uuidutils
-import sqlalchemy as sa
 from sqlalchemy.sql import expression as sa_expr
 
+from neutron.extensions import portbindings
+from neutron.openstack.common import uuidutils
 from neutron.plugins.common import constants as p_const
-from neutron.plugins.ml2.drivers.hyperv import constants
 
 FLAT_VLAN_ID = -1
 LOCAL_VLAN_ID = -2
@@ -114,15 +113,14 @@ def _migrate_port_bindings(engine):
         sa_expr.select(['*'], from_obj=port_binding_ports))
     ml2_bindings = [dict(x) for x in source_bindings]
     for binding in ml2_bindings:
-        binding['vif_type'] = constants.VIF_TYPE_HYPERV
+        binding['vif_type'] = portbindings.VIF_TYPE_HYPERV
         binding['driver'] = HYPERV
         segment = port_segment_map.get(binding['port_id'])
         if segment:
             binding['segment'] = segment
     if ml2_bindings:
-        md = sa.MetaData()
-        sa.Table('ml2_port_bindings', md, autoload=True, autoload_with=engine)
-        op.bulk_insert(md.tables['ml2_port_bindings'], ml2_bindings)
+        ml2_port_bindings = sa_expr.table('ml2_port_bindings')
+        op.execute(ml2_port_bindings.insert(), ml2_bindings)
 
 
 def upgrade():
