@@ -13,16 +13,23 @@
 #    under the License.
 
 import os
+import six
 
 from alembic import command as alembic_command
 from alembic import config as alembic_config
+from alembic import environment
 from alembic import script as alembic_script
 from alembic import util as alembic_util
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_utils import importutils
 
+from neutron.common import repos
 
 HEAD_FILENAME = 'HEAD'
 
+mods = repos.NeutronModules()
+VALID_SERVICES = map(mods.alembic_name, mods.installed_list())
+
 
 _core_opts = [
     cfg.StrOpt('core_plugin',
@@ -31,6 +38,10 @@ _core_opts = [
     cfg.ListOpt('service_plugins',
                 default=[],
                 help=_("The service plugins Neutron will use")),
+    cfg.StrOpt('service',
+               choices=VALID_SERVICES,
+               help=_("The advanced service to execute the command against. "
+                      "Can be one of '%s'.") % "', '".join(VALID_SERVICES))
 ]
 
 _quota_opts = [
@@ -60,7 +71,7 @@ def do_alembic_command(config, cmd, *args, **kwargs):
     try:
         getattr(alembic_command, cmd)(config, *args, **kwargs)
     except alembic_util.CommandError as e:
-        alembic_util.err(str(e))
+        alembic_util.err(six.text_type(e))
 
 
 def do_check_migration(config, cmd):
@@ -68,21 +79,37 @@ def do_check_migration(config, cmd):
     validate_head_file(config)
 
 
-def do_upgrade_downgrade(config, cmd):
+def add_alembic_subparser(sub, cmd):
+    return sub.add_parser(cmd, help=getattr(alembic_command, cmd).__doc__)
+
+
+def do_upgrade(config, cmd):
     if not CONF.command.revision and not CONF.command.delta:
         raise SystemExit(_('You must provide a revision or relative delta'))
 
-    revision = CONF.command.revision
+    revision = CONF.command.revision or ''
+    if '-' in revision:
+        raise SystemExit(_('Negative relative revision (downgrade) not '
+                           'supported'))
 
-    if CONF.command.delta:
-        sign = '+' if CONF.command.name == 'upgrade' else '-'
-        revision = sign + str(CONF.command.delta)
-    else:
-        revision = CONF.command.revision
+    delta = CONF.command.delta
+    if delta:
+        if '+' in revision:
+            raise SystemExit(_('Use either --delta or relative revision, '
+                               'not both'))
+        if delta < 0:
+            raise SystemExit(_('Negative delta (downgrade) not supported'))
+        revision = '%s+%d' % (revision, delta)
 
+    if not CONF.command.sql:
+        run_sanity_checks(config, revision)
     do_alembic_command(config, cmd, revision, sql=CONF.command.sql)
 
 
+def no_downgrade(config, cmd):
+    raise SystemExit(_("Downgrade no longer supported"))
+
+
 def do_stamp(config, cmd):
     do_alembic_command(config, cmd,
                        CONF.command.revision,
@@ -122,29 +149,34 @@ def update_head_file(config):
 
 def add_command_parsers(subparsers):
     for name in ['current', 'history', 'branches']:
-        parser = subparsers.add_parser(name)
+        parser = add_alembic_subparser(subparsers, name)
         parser.set_defaults(func=do_alembic_command)
 
-    parser = subparsers.add_parser('check_migration')
+    help_text = (getattr(alembic_command, 'branches').__doc__ +
+                 ' and validate head file')
+    parser = subparsers.add_parser('check_migration', help=help_text)
     parser.set_defaults(func=do_check_migration)
 
-    for name in ['upgrade', 'downgrade']:
-        parser = subparsers.add_parser(name)
-        parser.add_argument('--delta', type=int)
-        parser.add_argument('--sql', action='store_true')
-        parser.add_argument('revision', nargs='?')
-        parser.add_argument('--mysql-engine',
-                            default='',
-                            help='Change MySQL storage engine of current '
-                                 'existing tables')
-        parser.set_defaults(func=do_upgrade_downgrade)
+    parser = add_alembic_subparser(subparsers, 'upgrade')
+    parser.add_argument('--delta', type=int)
+    parser.add_argument('--sql', action='store_true')
+    parser.add_argument('revision', nargs='?')
+    parser.add_argument('--mysql-engine',
+                        default='',
+                        help='Change MySQL storage engine of current '
+                             'existing tables')
+    parser.set_defaults(func=do_upgrade)
 
-    parser = subparsers.add_parser('stamp')
+    parser = subparsers.add_parser('downgrade', help="(No longer supported)")
+    parser.add_argument('None', nargs='?', help="Downgrade not supported")
+    parser.set_defaults(func=no_downgrade)
+
+    parser = add_alembic_subparser(subparsers, 'stamp')
     parser.add_argument('--sql', action='store_true')
     parser.add_argument('revision')
     parser.set_defaults(func=do_stamp)
 
-    parser = subparsers.add_parser('revision')
+    parser = add_alembic_subparser(subparsers, 'revision')
     parser.add_argument('-m', '--message')
     parser.add_argument('--autogenerate', action='store_true')
     parser.add_argument('--sql', action='store_true')
@@ -159,15 +191,48 @@ command_opt = cfg.SubCommandOpt('command',
 CONF.register_cli_opt(command_opt)
 
 
+def validate_service_installed(service):
+    if not importutils.try_import('neutron_%s' % service):
+        alembic_util.err(_('Package neutron-%s not installed') % service)
+
+
+def get_script_location(neutron_config):
+    location = '%s.db.migration:alembic_migrations'
+    if neutron_config.service:
+        validate_service_installed(neutron_config.service)
+        base = "neutron_%s" % neutron_config.service
+    else:
+        base = "neutron"
+    return location % base
+
+
+def get_alembic_config():
+    config = alembic_config.Config(os.path.join(os.path.dirname(__file__),
+                                                'alembic.ini'))
+    config.set_main_option('script_location', get_script_location(CONF))
+    return config
+
+
+def run_sanity_checks(config, revision):
+    script_dir = alembic_script.ScriptDirectory.from_config(config)
+
+    def check_sanity(rev, context):
+        for script in script_dir.iterate_revisions(revision, rev):
+            if hasattr(script.module, 'check_sanity'):
+                script.module.check_sanity(context.connection)
+        return []
+
+    with environment.EnvironmentContext(config, script_dir,
+                                        fn=check_sanity,
+                                        starting_rev=None,
+                                        destination_rev=revision):
+        script_dir.run_env()
+
+
 def main():
-    config = alembic_config.Config(
-        os.path.join(os.path.dirname(__file__), 'alembic.ini')
-    )
-    config.set_main_option('script_location',
-                           'neutron.db.migration:alembic_migrations')
-    # attach the Neutron conf to the Alembic conf
+    CONF(project='neutron')
+    config = get_alembic_config()
     config.neutron_config = CONF
 
-    CONF()
     #TODO(gongysh) enable logging
     CONF.command.func(config, CONF.command.name)
