@@ -1,5 +1,3 @@
-# vim: tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2011 OpenStack Foundation.
 # All Rights Reserved.
 #
@@ -15,12 +13,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from six.moves import xrange
+from oslo_log import log as logging
+from six import moves
 import sqlalchemy
-from sqlalchemy.orm.properties import RelationshipProperty
+from sqlalchemy.orm import properties
 
 from neutron.common import exceptions as n_exc
-from neutron.openstack.common import log as logging
 
 
 LOG = logging.getLogger(__name__)
@@ -74,7 +72,7 @@ def paginate_query(query, model, limit, sorts, marker_obj=None):
             # existed in attr_info, it will be catched at here
             msg = _("%s is invalid attribute for sort_key") % sort_key
             raise n_exc.BadRequest(resource=model.__tablename__, msg=msg)
-        if isinstance(sort_key_attr.property, RelationshipProperty):
+        if isinstance(sort_key_attr.property, properties.RelationshipProperty):
             msg = _("The attribute '%(attr)s' is reference to other "
                     "resource, can't used by sort "
                     "'%(resource)s'") % {'attr': sort_key,
@@ -90,7 +88,7 @@ def paginate_query(query, model, limit, sorts, marker_obj=None):
         criteria_list = []
         for i, sort in enumerate(sorts):
             crit_attrs = [(getattr(model, sorts[j][0]) == marker_values[j])
-                          for j in xrange(i)]
+                          for j in moves.xrange(i)]
             model_attr = getattr(model, sort[0])
             if sort[1]:
                 crit_attrs.append((model_attr > marker_values[i]))
