@@ -14,32 +14,32 @@
 
 import abc
 
+from oslo_log import log as logging
 import six
 
 from neutron.api import extensions
 from neutron.api.v2 import attributes as attr
 from neutron.api.v2 import resource_helper
-from neutron.common import exceptions as qexception
-from neutron.openstack.common import log as logging
+from neutron.common import exceptions as nexception
 from neutron.plugins.common import constants
 from neutron.services import service_base
 
 LOG = logging.getLogger(__name__)
 
 
-class MeteringLabelNotFound(qexception.NotFound):
+class MeteringLabelNotFound(nexception.NotFound):
     message = _("Metering label %(label_id)s does not exist")
 
 
-class DuplicateMeteringRuleInPost(qexception.InUse):
+class DuplicateMeteringRuleInPost(nexception.InUse):
     message = _("Duplicate Metering Rule in POST.")
 
 
-class MeteringLabelRuleNotFound(qexception.NotFound):
+class MeteringLabelRuleNotFound(nexception.NotFound):
     message = _("Metering label rule %(rule_id)s does not exist")
 
 
-class MeteringLabelRuleOverlaps(qexception.NotFound):
+class MeteringLabelRuleOverlaps(nexception.Conflict):
     message = _("Metering label rule with remote_ip_prefix "
                 "%(remote_ip_prefix)s overlaps another")
 
