@@ -12,12 +12,12 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_log import log as logging
 import sqlalchemy as sa
 from sqlalchemy import sql
 
 from neutron.db import model_base
 from neutron.db import models_v2
-from neutron.openstack.common import log as logging
 from neutron.plugins.cisco.common import cisco_constants
 
 
