@@ -1,5 +1,3 @@
-# vim:  tabstop=4 shiftwidth=4 softtabstop=4
-
 # Copyright 2013 Embrane, Inc.
 # All Rights Reserved.
 #
@@ -14,30 +12,27 @@
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
 #    License for the specific language governing permissions and limitations
 #    under the License.
-#
-# @author:  Ivar Lazzaro, Embrane, Inc.
 
-from oslo.config import cfg
+from oslo_config import cfg
 
 
 heleos_opts = [
     cfg.StrOpt('esm_mgmt',
-               default=None,
                help=_('ESM management root address')),
     cfg.StrOpt('admin_username', default='admin',
                help=_('ESM admin username.')),
-    cfg.StrOpt('admin_password', default=None,
+    cfg.StrOpt('admin_password',
                secret=True,
                help=_('ESM admin password.')),
-    cfg.StrOpt('router_image', default=None,
+    cfg.StrOpt('router_image',
                help=_('Router image id (Embrane FW/VPN)')),
-    cfg.StrOpt('inband_id', default=None,
+    cfg.StrOpt('inband_id',
                help=_('In band Security Zone id')),
-    cfg.StrOpt('oob_id', default=None,
+    cfg.StrOpt('oob_id',
                help=_('Out of band Security Zone id')),
-    cfg.StrOpt('mgmt_id', default=None,
+    cfg.StrOpt('mgmt_id',
                help=_('Management Security Zone id')),
-    cfg.StrOpt('dummy_utif_id', default=None,
+    cfg.StrOpt('dummy_utif_id',
                help=_('Dummy user traffic Security Zone id')),
     cfg.StrOpt('resource_pool_id', default='default',
                help=_('Shared resource pool id')),
