@@ -20,7 +20,6 @@ from hyperv.neutron import hyperv_neutron_agent
 from oslo_config import cfg
 from oslo_log import log as logging
 import oslo_messaging
-from oslo_service import loopingcall
 
 from neutron.agent import rpc as agent_rpc
 from neutron.agent import securitygroups_rpc as sg_rpc
@@ -29,7 +28,7 @@ from neutron.common import rpc as n_rpc
 from neutron.common import topics
 from neutron import context
 from neutron.i18n import _LE
-from neutron.plugins.ml2.drivers.hyperv import constants as h_const
+from neutron.openstack.common import loopingcall
 
 LOG = logging.getLogger(__name__)
 CONF = cfg.CONF
@@ -83,7 +82,7 @@ class HyperVNeutronAgent(hyperv_neutron_agent.HyperVNeutronAgentMixin):
             'host': CONF.host,
             'topic': n_const.L2_AGENT_TOPIC,
             'configurations': configurations,
-            'agent_type': h_const.AGENT_TYPE_HYPERV,
+            'agent_type': n_const.AGENT_TYPE_HYPERV,
             'start_flag': True}
 
     def _report_state(self):
