@@ -17,7 +17,10 @@
 
 import functools
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
+import oslo_messaging
+from oslo_utils import excutils
 
 from neutron.common import constants as n_const
 from neutron.common import exceptions as n_exc
@@ -30,8 +33,7 @@ from neutron.db import l3_gwmode_db
 from neutron.db import portbindings_db
 from neutron.db import quota_db  # noqa
 from neutron.extensions import portbindings
-from neutron.openstack.common import excutils
-from neutron.openstack.common import log as logging
+from neutron.i18n import _LE, _LI, _LW
 from neutron.plugins.ibm.common import config  # noqa
 from neutron.plugins.ibm.common import constants
 from neutron.plugins.ibm.common import exceptions as sdnve_exc
@@ -41,7 +43,7 @@ from neutron.plugins.ibm import sdnve_api_fake as sdnve_fake
 LOG = logging.getLogger(__name__)
 
 
-class SdnveRpcCallbacks():
+class SdnveRpcCallbacks(object):
 
     def __init__(self, notifier):
         self.notifier = notifier  # used to notify the agent
@@ -54,24 +56,19 @@ class SdnveRpcCallbacks():
         return info
 
 
-class AgentNotifierApi(n_rpc.RpcProxy):
+class AgentNotifierApi(object):
     '''Agent side of the SDN-VE rpc API.'''
 
-    BASE_RPC_API_VERSION = '1.0'
-
     def __init__(self, topic):
-        super(AgentNotifierApi, self).__init__(
-            topic=topic, default_version=self.BASE_RPC_API_VERSION)
-
+        target = oslo_messaging.Target(topic=topic, version='1.0')
+        self.client = n_rpc.get_client(target)
         self.topic_info_update = topics.get_topic_name(topic,
                                                        constants.INFO,
                                                        topics.UPDATE)
 
     def info_update(self, context, info):
-        self.fanout_cast(context,
-                         self.make_msg('info_update',
-                                       info=info),
-                         topic=self.topic_info_update)
+        cctxt = self.client.prepare(topic=self.topic_info_update, fanout=True)
+        cctxt.cast(context, 'info_update', info=info)
 
 
 def _ha(func):
@@ -147,13 +144,13 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
                 portbindings.VIF_TYPE] = portbindings.VIF_TYPE_OVS
 
     def set_controller(self, context):
-        LOG.info(_("Set a new controller if needed."))
+        LOG.info(_LI("Set a new controller if needed."))
         new_controller = self.sdnve_client.sdnve_get_controller()
         if new_controller:
             self.notifier.info_update(
                 context,
                 {'new_controller': new_controller})
-            LOG.info(_("Set the controller to a new controller: %s"),
+            LOG.info(_LI("Set the controller to a new controller: %s"),
                      new_controller)
 
     def _process_request(self, request, current):
@@ -171,7 +168,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def create_network(self, context, network):
-        LOG.debug(_("Create network in progress: %r"), network)
+        LOG.debug("Create network in progress: %r", network)
         session = context.session
 
         tenant_id = self._get_tenant_id_for_create(context, network['network'])
@@ -193,12 +190,12 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             raise sdnve_exc.SdnveException(
                 msg=(_('Create net failed in SDN-VE: %s') % res))
 
-        LOG.debug(_("Created network: %s"), net['id'])
+        LOG.debug("Created network: %s", net['id'])
         return net
 
     @_ha
     def update_network(self, context, id, network):
-        LOG.debug(_("Update network in progress: %r"), network)
+        LOG.debug("Update network in progress: %r", network)
         session = context.session
 
         processed_request = {}
@@ -224,7 +221,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def delete_network(self, context, id):
-        LOG.debug(_("Delete network in progress: %s"), id)
+        LOG.debug("Delete network in progress: %s", id)
         session = context.session
 
         with session.begin(subtransactions=True):
@@ -234,18 +231,18 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
         (res, data) = self.sdnve_client.sdnve_delete('network', id)
         if res not in constants.HTTP_ACCEPTABLE:
             LOG.error(
-                _("Delete net failed after deleting the network in DB: %s"),
+                _LE("Delete net failed after deleting the network in DB: %s"),
                 res)
 
     @_ha
     def get_network(self, context, id, fields=None):
-        LOG.debug(_("Get network in progress: %s"), id)
+        LOG.debug("Get network in progress: %s", id)
         return super(SdnvePluginV2, self).get_network(context, id, fields)
 
     @_ha
     def get_networks(self, context, filters=None, fields=None, sorts=None,
                      limit=None, marker=None, page_reverse=False):
-        LOG.debug(_("Get networks in progress"))
+        LOG.debug("Get networks in progress")
         return super(SdnvePluginV2, self).get_networks(
             context, filters, fields, sorts, limit, marker, page_reverse)
 
@@ -255,7 +252,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def create_port(self, context, port):
-        LOG.debug(_("Create port in progress: %r"), port)
+        LOG.debug("Create port in progress: %r", port)
         session = context.session
 
         # Set port status as 'ACTIVE' to avoid needing the agent
@@ -271,14 +268,14 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             # requires a tenant id
             tenant_id = port.get('tenant_id')
             if not tenant_id:
-                LOG.debug(_("Create port does not have tenant id info"))
+                LOG.debug("Create port does not have tenant id info")
                 original_network = super(SdnvePluginV2, self).get_network(
                     context, port['network_id'])
                 original_tenant_id = original_network['tenant_id']
                 port['tenant_id'] = original_tenant_id
                 LOG.debug(
-                    _("Create port does not have tenant id info; "
-                      "obtained is: %s"),
+                    "Create port does not have tenant id info; "
+                    "obtained is: %s",
                     port['tenant_id'])
 
             os_tenant_id = tenant_id
@@ -300,12 +297,12 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             raise sdnve_exc.SdnveException(
                 msg=(_('Create port failed in SDN-VE: %s') % res))
 
-        LOG.debug(_("Created port: %s"), port.get('id', 'id not found'))
+        LOG.debug("Created port: %s", port.get('id', 'id not found'))
         return port
 
     @_ha
     def update_port(self, context, id, port):
-        LOG.debug(_("Update port in progress: %r"), port)
+        LOG.debug("Update port in progress: %r", port)
         session = context.session
 
         processed_request = {}
@@ -338,7 +335,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def delete_port(self, context, id, l3_port_check=True):
-        LOG.debug(_("Delete port in progress: %s"), id)
+        LOG.debug("Delete port in progress: %s", id)
 
         # if needed, check to see if this is a port owned by
         # an l3-router.  If so, we should prevent deletion.
@@ -351,8 +348,8 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
         (res, data) = self.sdnve_client.sdnve_delete('port', id)
         if res not in constants.HTTP_ACCEPTABLE:
             LOG.error(
-                _("Delete port operation failed in SDN-VE "
-                  "after deleting the port from DB: %s"), res)
+                _LE("Delete port operation failed in SDN-VE "
+                    "after deleting the port from DB: %s"), res)
 
     #
     # Subnet
@@ -360,7 +357,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def create_subnet(self, context, subnet):
-        LOG.debug(_("Create subnet in progress: %r"), subnet)
+        LOG.debug("Create subnet in progress: %r", subnet)
         new_subnet = super(SdnvePluginV2, self).create_subnet(context, subnet)
 
         # Note(mb): Use of null string currently required by controller
@@ -374,13 +371,13 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             raise sdnve_exc.SdnveException(
                 msg=(_('Create subnet failed in SDN-VE: %s') % res))
 
-        LOG.debug(_("Subnet created: %s"), new_subnet['id'])
+        LOG.debug("Subnet created: %s", new_subnet['id'])
 
         return new_subnet
 
     @_ha
     def update_subnet(self, context, id, subnet):
-        LOG.debug(_("Update subnet in progress: %r"), subnet)
+        LOG.debug("Update subnet in progress: %r", subnet)
         session = context.session
 
         processed_request = {}
@@ -411,13 +408,13 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def delete_subnet(self, context, id):
-        LOG.debug(_("Delete subnet in progress: %s"), id)
+        LOG.debug("Delete subnet in progress: %s", id)
         super(SdnvePluginV2, self).delete_subnet(context, id)
 
         (res, data) = self.sdnve_client.sdnve_delete('subnet', id)
         if res not in constants.HTTP_ACCEPTABLE:
-            LOG.error(_("Delete subnet operation failed in SDN-VE after "
-                        "deleting the subnet from DB: %s"), res)
+            LOG.error(_LE("Delete subnet operation failed in SDN-VE after "
+                          "deleting the subnet from DB: %s"), res)
 
     #
     # Router
@@ -425,11 +422,11 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def create_router(self, context, router):
-        LOG.debug(_("Create router in progress: %r"), router)
+        LOG.debug("Create router in progress: %r", router)
 
         if router['router']['admin_state_up'] is False:
-            LOG.warning(_('Ignoring admin_state_up=False for router=%r.  '
-                          'Overriding with True'), router)
+            LOG.warning(_LW('Ignoring admin_state_up=False for router=%r.  '
+                            'Overriding with True'), router)
             router['router']['admin_state_up'] = True
 
         tenant_id = self._get_tenant_id_for_create(context, router['router'])
@@ -448,13 +445,13 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             raise sdnve_exc.SdnveException(
                 msg=(_('Create router failed in SDN-VE: %s') % res))
 
-        LOG.debug(_("Router created: %r"), new_router)
+        LOG.debug("Router created: %r", new_router)
         return new_router
 
     @_ha
     def update_router(self, context, id, router):
-        LOG.debug(_("Update router in progress: id=%(id)s "
-                    "router=%(router)r"),
+        LOG.debug("Update router in progress: id=%(id)s "
+                  "router=%(router)r",
                   {'id': id, 'router': router})
         session = context.session
 
@@ -490,27 +487,27 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def delete_router(self, context, id):
-        LOG.debug(_("Delete router in progress: %s"), id)
+        LOG.debug("Delete router in progress: %s", id)
 
         super(SdnvePluginV2, self).delete_router(context, id)
 
         (res, data) = self.sdnve_client.sdnve_delete('router', id)
         if res not in constants.HTTP_ACCEPTABLE:
             LOG.error(
-                _("Delete router operation failed in SDN-VE after "
-                  "deleting the router in DB: %s"), res)
+                _LE("Delete router operation failed in SDN-VE after "
+                    "deleting the router in DB: %s"), res)
 
     @_ha
     def add_router_interface(self, context, router_id, interface_info):
-        LOG.debug(_("Add router interface in progress: "
-                    "router_id=%(router_id)s "
-                    "interface_info=%(interface_info)r"),
+        LOG.debug("Add router interface in progress: "
+                  "router_id=%(router_id)s "
+                  "interface_info=%(interface_info)r",
                   {'router_id': router_id, 'interface_info': interface_info})
 
         new_interface = super(SdnvePluginV2, self).add_router_interface(
             context, router_id, interface_info)
         LOG.debug(
-            _("SdnvePluginV2.add_router_interface called. Port info: %s"),
+            "SdnvePluginV2.add_router_interface called. Port info: %s",
             new_interface)
         request_info = interface_info.copy()
         request_info['port_id'] = new_interface['port_id']
@@ -527,13 +524,13 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
                 msg=(_('Update router-add-interface failed in SDN-VE: %s') %
                      res))
 
-        LOG.debug(_("Added router interface: %r"), new_interface)
+        LOG.debug("Added router interface: %r", new_interface)
         return new_interface
 
     def _add_router_interface_only(self, context, router_id, interface_info):
-        LOG.debug(_("Add router interface only called: "
-                    "router_id=%(router_id)s "
-                    "interface_info=%(interface_info)r"),
+        LOG.debug("Add router interface only called: "
+                  "router_id=%(router_id)s "
+                  "interface_info=%(interface_info)r",
                   {'router_id': router_id, 'interface_info': interface_info})
 
         port_id = interface_info.get('port_id')
@@ -541,15 +538,21 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             (res, data) = self.sdnve_client.sdnve_update(
                 'router', router_id + '/add_router_interface', interface_info)
             if res not in constants.HTTP_ACCEPTABLE:
-                LOG.error(_("SdnvePluginV2._add_router_interface_only: "
-                            "failed to add the interface in the roll back."
-                            " of a remove_router_interface operation"))
+                LOG.error(_LE("SdnvePluginV2._add_router_interface_only: "
+                              "failed to add the interface in the roll back."
+                              " of a remove_router_interface operation"))
+
+    def _find_router_port_by_subnet_id(self, ports, subnet_id):
+        for p in ports:
+            subnet_ids = [fip['subnet_id'] for fip in p['fixed_ips']]
+            if subnet_id in subnet_ids:
+                return p['id']
 
     @_ha
     def remove_router_interface(self, context, router_id, interface_info):
-        LOG.debug(_("Remove router interface in progress: "
-                    "router_id=%(router_id)s "
-                    "interface_info=%(interface_info)r"),
+        LOG.debug("Remove router interface in progress: "
+                  "router_id=%(router_id)s "
+                  "interface_info=%(interface_info)r",
                   {'router_id': router_id, 'interface_info': interface_info})
 
         subnet_id = interface_info.get('subnet_id')
@@ -558,7 +561,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             if not port_id:
                 raise sdnve_exc.BadInputException(msg=_('No port ID'))
             myport = super(SdnvePluginV2, self).get_port(context, port_id)
-            LOG.debug(_("SdnvePluginV2.remove_router_interface port: %s"),
+            LOG.debug("SdnvePluginV2.remove_router_interface port: %s",
                       myport)
             myfixed_ips = myport.get('fixed_ips')
             if not myfixed_ips:
@@ -567,7 +570,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
             if subnet_id:
                 interface_info['subnet_id'] = subnet_id
                 LOG.debug(
-                    _("SdnvePluginV2.remove_router_interface subnet_id: %s"),
+                    "SdnvePluginV2.remove_router_interface subnet_id: %s",
                     subnet_id)
         else:
             if not port_id:
@@ -579,7 +582,14 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
                       'network_id': [subnet['network_id']]}
                 ports = self.get_ports(context, filters=df)
                 if ports:
-                    pid = ports[0]['id']
+                    pid = self._find_router_port_by_subnet_id(ports, subnet_id)
+                    if not pid:
+                        raise sdnve_exc.SdnveException(
+                                msg=(_('Update router-remove-interface '
+                                       'failed SDN-VE: subnet %(sid) is not '
+                                       'associated with any ports on router '
+                                       '%(rid)'), {'sid': subnet_id,
+                                     'rid': router_id}))
                     interface_info['port_id'] = pid
                     msg = ("SdnvePluginV2.remove_router_interface "
                            "subnet_id: %(sid)s  port_id: %(pid)s")
@@ -596,6 +606,11 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
         session = context.session
         with session.begin(subtransactions=True):
             try:
+                if not port_id:
+                    # port_id was not originally given in interface_info,
+                    # so we want to remove the interface by subnet instead
+                    # of port
+                    del interface_info['port_id']
                 info = super(SdnvePluginV2, self).remove_router_interface(
                     context, router_id, interface_info)
             except Exception:
@@ -611,7 +626,7 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def create_floatingip(self, context, floatingip):
-        LOG.debug(_("Create floatingip in progress: %r"),
+        LOG.debug("Create floatingip in progress: %r",
                   floatingip)
         new_floatingip = super(SdnvePluginV2, self).create_floatingip(
             context, floatingip)
@@ -625,12 +640,12 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
                 msg=(_('Creating floating ip operation failed '
                        'in SDN-VE controller: %s') % res))
 
-        LOG.debug(_("Created floatingip : %r"), new_floatingip)
+        LOG.debug("Created floatingip : %r", new_floatingip)
         return new_floatingip
 
     @_ha
     def update_floatingip(self, context, id, floatingip):
-        LOG.debug(_("Update floatingip in progress: %r"), floatingip)
+        LOG.debug("Update floatingip in progress: %r", floatingip)
         session = context.session
 
         processed_request = {}
@@ -656,9 +671,9 @@ class SdnvePluginV2(db_base_plugin_v2.NeutronDbPluginV2,
 
     @_ha
     def delete_floatingip(self, context, id):
-        LOG.debug(_("Delete floatingip in progress: %s"), id)
+        LOG.debug("Delete floatingip in progress: %s", id)
         super(SdnvePluginV2, self).delete_floatingip(context, id)
 
         (res, data) = self.sdnve_client.sdnve_delete('floatingip', id)
         if res not in constants.HTTP_ACCEPTABLE:
-            LOG.error(_("Delete floatingip failed in SDN-VE: %s"), res)
+            LOG.error(_LE("Delete floatingip failed in SDN-VE: %s"), res)
