@@ -12,7 +12,7 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
 
 from neutron.agent.common import config
 
@@ -32,7 +32,7 @@ vlan_opts = [
 ]
 
 vxlan_opts = [
-    cfg.BoolOpt('enable_vxlan', default=False,
+    cfg.BoolOpt('enable_vxlan', default=True,
                 help=_("Enable VXLAN on the agent. Can be enabled when "
                        "agent is managed by ml2 plugin using linuxbridge "
                        "mechanism driver")),
@@ -42,8 +42,8 @@ vxlan_opts = [
                help=_("TOS for vxlan interface protocol packets.")),
     cfg.StrOpt('vxlan_group', default=DEFAULT_VXLAN_GROUP,
                help=_("Multicast group for vxlan interface.")),
-    cfg.StrOpt('local_ip', default='',
-               help=_("Local IP address of the VXLAN endpoints.")),
+    cfg.IPOpt('local_ip', version=4,
+              help=_("Local IP address of the VXLAN endpoints.")),
     cfg.BoolOpt('l2_population', default=False,
                 help=_("Extension to use alongside ml2 plugin's l2population "
                        "mechanism driver. It enables the plugin to populate "
@@ -62,6 +62,10 @@ agent_opts = [
                       "polling for local device changes.")),
     cfg.BoolOpt('rpc_support_old_agents', default=False,
                 help=_("Enable server RPC compatibility with old agents")),
+    # TODO(kevinbenton): The following opt is duplicated between the OVS agent
+    # and the Linuxbridge agent to make it easy to back-port. These shared opts
+    # should be moved into a common agent config options location as part of
+    # the deduplication work.
     cfg.BoolOpt('prevent_arp_spoofing', default=False,
                 help=_("Enable suppression of ARP responses that don't match "
                        "an IP address that belongs to the port from which "
@@ -71,7 +75,9 @@ agent_opts = [
                        "(e.g. bare metal or VMs attached to agents without "
                        "this flag set to True). Spoofing rules will not be "
                        "added to any ports that have port security disabled. "
-                       "For LinuxBridge, this requires ebtables.")),
+                       "For LinuxBridge, this requires ebtables. For OVS, it "
+                       "requires a version that supports matching ARP "
+                       "headers."))
 ]
 
 
@@ -80,4 +86,3 @@ cfg.CONF.register_opts(vxlan_opts, "VXLAN")
 cfg.CONF.register_opts(bridge_opts, "LINUX_BRIDGE")
 cfg.CONF.register_opts(agent_opts, "AGENT")
 config.register_agent_state_opts_helper(cfg.CONF)
-config.register_root_helper(cfg.CONF)
