@@ -13,18 +13,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_db import exception as db_exc
+from oslo_log import log
 from sqlalchemy import or_
 from sqlalchemy.orm import exc
 
-from oslo.db import exception as db_exc
-
 from neutron.common import constants as n_const
 from neutron.db import api as db_api
 from neutron.db import models_v2
 from neutron.db import securitygroups_db as sg_db
 from neutron.extensions import portbindings
+from neutron.i18n import _LE, _LI
 from neutron import manager
-from neutron.openstack.common import log
 from neutron.openstack.common import uuidutils
 from neutron.plugins.ml2 import driver_api as api
 from neutron.plugins.ml2 import models
@@ -43,7 +43,8 @@ def _make_segment_dict(record):
             api.SEGMENTATION_ID: record.segmentation_id}
 
 
-def add_network_segment(session, network_id, segment, is_dynamic=False):
+def add_network_segment(session, network_id, segment, segment_index=0,
+                        is_dynamic=False):
     with session.begin(subtransactions=True):
         record = models.NetworkSegment(
             id=uuidutils.generate_uuid(),
@@ -51,12 +52,13 @@ def add_network_segment(session, network_id, segment, is_dynamic=False):
             network_type=segment.get(api.NETWORK_TYPE),
             physical_network=segment.get(api.PHYSICAL_NETWORK),
             segmentation_id=segment.get(api.SEGMENTATION_ID),
+            segment_index=segment_index,
             is_dynamic=is_dynamic
         )
         session.add(record)
         segment[api.ID] = record.id
-    LOG.info(_("Added segment %(id)s of type %(network_type)s for network"
-               " %(network_id)s"),
+    LOG.info(_LI("Added segment %(id)s of type %(network_type)s for network"
+                 " %(network_id)s"),
              {'id': record.id,
               'network_type': record.network_type,
               'network_id': record.network_id})
@@ -65,7 +67,8 @@ def add_network_segment(session, network_id, segment, is_dynamic=False):
 def get_network_segments(session, network_id, filter_dynamic=False):
     with session.begin(subtransactions=True):
         query = (session.query(models.NetworkSegment).
-                 filter_by(network_id=network_id))
+                 filter_by(network_id=network_id).
+                 order_by(models.NetworkSegment.segment_index))
         if filter_dynamic is not None:
             query = query.filter_by(is_dynamic=filter_dynamic)
         records = query.all()
@@ -99,7 +102,7 @@ def get_dynamic_segment(session, network_id, physical_network=None,
         if record:
             return _make_segment_dict(record)
         else:
-            LOG.debug("No dynamic segment %s found for "
+            LOG.debug("No dynamic segment found for "
                       "Network:%(network_id)s, "
                       "Physical network:%(physnet)s, "
                       "segmentation_id:%(segmentation_id)s",
@@ -148,6 +151,44 @@ def get_locked_port_and_binding(session, port_id):
         return None, None
 
 
+def set_binding_levels(session, levels):
+    if levels:
+        for level in levels:
+            session.add(level)
+        LOG.debug("For port %(port_id)s, host %(host)s, "
+                  "set binding levels %(levels)s",
+                  {'port_id': levels[0].port_id,
+                   'host': levels[0].host,
+                   'levels': levels})
+    else:
+        LOG.debug("Attempted to set empty binding levels")
+
+
+def get_binding_levels(session, port_id, host):
+    if host:
+        result = (session.query(models.PortBindingLevel).
+                  filter_by(port_id=port_id, host=host).
+                  order_by(models.PortBindingLevel.level).
+                  all())
+        LOG.debug("For port %(port_id)s, host %(host)s, "
+                  "got binding levels %(levels)s",
+                  {'port_id': port_id,
+                   'host': host,
+                   'levels': result})
+        return result
+
+
+def clear_binding_levels(session, port_id, host):
+    if host:
+        (session.query(models.PortBindingLevel).
+         filter_by(port_id=port_id, host=host).
+         delete())
+        LOG.debug("For port %(port_id)s, host %(host)s, "
+                  "cleared binding levels",
+                  {'port_id': port_id,
+                   'host': host})
+
+
 def ensure_dvr_port_binding(session, port_id, host, router_id=None):
     record = (session.query(models.DVRPortBinding).
               filter_by(port_id=port_id, host=host).first())
@@ -162,7 +203,6 @@ def ensure_dvr_port_binding(session, port_id, host, router_id=None):
                 router_id=router_id,
                 vif_type=portbindings.VIF_TYPE_UNBOUND,
                 vnic_type=portbindings.VNIC_NORMAL,
-                cap_port_filter=False,
                 status=n_const.PORT_STATUS_DOWN)
             session.add(record)
             return record
@@ -192,19 +232,20 @@ def get_port(session, port_id):
     with session.begin(subtransactions=True):
         try:
             record = (session.query(models_v2.Port).
+                      enable_eagerloads(False).
                       filter(models_v2.Port.id.startswith(port_id)).
                       one())
             return record
         except exc.NoResultFound:
             return
         except exc.MultipleResultsFound:
-            LOG.error(_("Multiple ports have port_id starting with %s"),
+            LOG.error(_LE("Multiple ports have port_id starting with %s"),
                       port_id)
             return
 
 
 def get_port_from_device_mac(device_mac):
-    LOG.debug(_("get_port_from_device_mac() called for mac %s"), device_mac)
+    LOG.debug("get_port_from_device_mac() called for mac %s", device_mac)
     session = db_api.get_session()
     qry = session.query(models_v2.Port).filter_by(mac_address=device_mac)
     return qry.first()
@@ -272,21 +313,20 @@ def make_port_dict_with_security_groups(port, sec_groups):
     return port_dict
 
 
-def get_port_binding_host(port_id):
-    session = db_api.get_session()
-    with session.begin(subtransactions=True):
-        try:
+def get_port_binding_host(session, port_id):
+    try:
+        with session.begin(subtransactions=True):
             query = (session.query(models.PortBinding).
                      filter(models.PortBinding.port_id.startswith(port_id)).
                      one())
-        except exc.NoResultFound:
-            LOG.debug(_("No binding found for port %(port_id)s"),
-                      {'port_id': port_id})
-            return
-        except exc.MultipleResultsFound:
-            LOG.error(_("Multiple ports have port_id starting with %s"),
-                      port_id)
-            return
+    except exc.NoResultFound:
+        LOG.debug("No binding found for port %(port_id)s",
+                  {'port_id': port_id})
+        return
+    except exc.MultipleResultsFound:
+        LOG.error(_LE("Multiple ports have port_id starting with %s"),
+                  port_id)
+        return
     return query.host
 
 
