@@ -13,12 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_log import log
+from oslo_serialization import jsonutils
+
 from neutron.common import constants
 from neutron.extensions import portbindings
-from neutron.openstack.common import jsonutils
+from neutron.i18n import _LW
 from neutron.plugins.ml2 import db
 from neutron.plugins.ml2 import driver_api as api
 
+LOG = log.getLogger(__name__)
+
 
 class MechanismDriverContext(object):
     """MechanismDriver context base class."""
@@ -72,21 +77,43 @@ class SubnetContext(MechanismDriverContext, api.SubnetContext):
 class PortContext(MechanismDriverContext, api.PortContext):
 
     def __init__(self, plugin, plugin_context, port, network, binding,
-                 original_port=None):
+                 binding_levels, original_port=None):
         super(PortContext, self).__init__(plugin, plugin_context)
         self._port = port
         self._original_port = original_port
         self._network_context = NetworkContext(plugin, plugin_context,
                                                network)
         self._binding = binding
+        self._binding_levels = binding_levels
+        self._segments_to_bind = None
+        self._new_bound_segment = None
+        self._next_segments_to_bind = None
         if original_port:
-            self._original_bound_segment_id = self._binding.segment
-            self._original_bound_driver = self._binding.driver
+            self._original_binding_levels = self._binding_levels
         else:
-            self._original_bound_segment_id = None
-            self._original_bound_driver = None
+            self._original_binding_levels = None
         self._new_port_status = None
 
+    # The following methods are for use by the ML2 plugin and are not
+    # part of the driver API.
+
+    def _prepare_to_bind(self, segments_to_bind):
+        self._segments_to_bind = segments_to_bind
+        self._new_bound_segment = None
+        self._next_segments_to_bind = None
+
+    def _clear_binding_levels(self):
+        self._binding_levels = []
+
+    def _push_binding_level(self, binding_level):
+        self._binding_levels.append(binding_level)
+
+    def _pop_binding_level(self):
+        return self._binding_levels.pop()
+
+    # The following implement the abstract methods and properties of
+    # the driver API.
+
     @property
     def current(self):
         return self._port
@@ -97,6 +124,11 @@ class PortContext(MechanismDriverContext, api.PortContext):
 
     @property
     def status(self):
+        # REVISIT(rkukura): Eliminate special DVR case as part of
+        # resolving bug 1367391?
+        if self._port['device_owner'] == constants.DEVICE_OWNER_DVR_INTERFACE:
+            return self._binding.status
+
         return self._port['status']
 
     @property
@@ -108,22 +140,57 @@ class PortContext(MechanismDriverContext, api.PortContext):
         return self._network_context
 
     @property
-    def bound_segment(self):
-        id = self._binding.segment
-        if id:
-            for segment in self._network_context.network_segments:
-                if segment[api.ID] == id:
-                    return segment
+    def binding_levels(self):
+        if self._binding_levels:
+            return [{
+                api.BOUND_DRIVER: level.driver,
+                api.BOUND_SEGMENT: self._expand_segment(level.segment_id)
+            } for level in self._binding_levels]
 
     @property
-    def original_bound_segment(self):
-        if self._original_bound_segment_id:
-            for segment in self._network_context.network_segments:
-                if segment[api.ID] == self._original_bound_segment_id:
-                    return segment
+    def original_binding_levels(self):
+        if self._original_binding_levels:
+            return [{
+                api.BOUND_DRIVER: level.driver,
+                api.BOUND_SEGMENT: self._expand_segment(level.segment_id)
+            } for level in self._original_binding_levels]
+
+    @property
+    def top_bound_segment(self):
+        if self._binding_levels:
+            return self._expand_segment(self._binding_levels[0].segment_id)
+
+    @property
+    def original_top_bound_segment(self):
+        if self._original_binding_levels:
+            return self._expand_segment(
+                self._original_binding_levels[0].segment_id)
+
+    @property
+    def bottom_bound_segment(self):
+        if self._binding_levels:
+            return self._expand_segment(self._binding_levels[-1].segment_id)
+
+    @property
+    def original_bottom_bound_segment(self):
+        if self._original_binding_levels:
+            return self._expand_segment(
+                self._original_binding_levels[-1].segment_id)
+
+    def _expand_segment(self, segment_id):
+        segment = db.get_segment_by_id(self._plugin_context.session,
+                                       segment_id)
+        if not segment:
+            LOG.warning(_LW("Could not expand segment %s"), segment_id)
+        return segment
 
     @property
     def host(self):
+        # REVISIT(rkukura): Eliminate special DVR case as part of
+        # resolving bug 1367391?
+        if self._port['device_owner'] == constants.DEVICE_OWNER_DVR_INTERFACE:
+            return self._binding.host
+
         return self._port.get(portbindings.HOST_ID)
 
     @property
@@ -131,12 +198,8 @@ class PortContext(MechanismDriverContext, api.PortContext):
         return self._original_port.get(portbindings.HOST_ID)
 
     @property
-    def bound_driver(self):
-        return self._binding.driver
-
-    @property
-    def original_bound_driver(self):
-        return self._original_bound_driver
+    def segments_to_bind(self):
+        return self._segments_to_bind
 
     def host_agents(self, agent_type):
         return self._plugin.get_agents(self._plugin_context,
@@ -146,11 +209,16 @@ class PortContext(MechanismDriverContext, api.PortContext):
     def set_binding(self, segment_id, vif_type, vif_details,
                     status=None):
         # TODO(rkukura) Verify binding allowed, segment in network
-        self._binding.segment = segment_id
+        self._new_bound_segment = segment_id
         self._binding.vif_type = vif_type
         self._binding.vif_details = jsonutils.dumps(vif_details)
         self._new_port_status = status
 
+    def continue_binding(self, segment_id, next_segments_to_bind):
+        # TODO(rkukura) Verify binding allowed, segment in network
+        self._new_bound_segment = segment_id
+        self._next_segments_to_bind = next_segments_to_bind
+
     def allocate_dynamic_segment(self, segment):
         network_id = self._network_context.current['id']
 
@@ -160,26 +228,3 @@ class PortContext(MechanismDriverContext, api.PortContext):
     def release_dynamic_segment(self, segment_id):
         return self._plugin.type_manager.release_dynamic_segment(
                 self._plugin_context.session, segment_id)
-
-
-class DvrPortContext(PortContext):
-
-    def __init__(self, plugin, plugin_context, port, network, binding,
-                 original_port=None):
-        super(DvrPortContext, self).__init__(
-            plugin, plugin_context, port, network, binding,
-            original_port=original_port)
-
-    @property
-    def host(self):
-        if self._port['device_owner'] == constants.DEVICE_OWNER_DVR_INTERFACE:
-            return self._binding.host
-
-        return super(DvrPortContext, self).host
-
-    @property
-    def status(self):
-        if self._port['device_owner'] == constants.DEVICE_OWNER_DVR_INTERFACE:
-            return self._binding.status
-
-        return super(DvrPortContext, self).status
