@@ -13,16 +13,17 @@
 #    under the License.
 
 import netaddr
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log
 
 from neutron.common import constants as n_consts
 from neutron.extensions import portbindings
-from neutron.openstack.common import log
+from neutron.i18n import _LE
 from neutron.plugins.common import constants
 from neutron.plugins.ml2 import driver_api as api
-from neutron.plugins.nuage.common import config
-from neutron.plugins.nuage.common import constants as nuage_const
-from neutron.plugins.nuage import plugin
+from nuage_neutron.plugins.nuage.common import config
+from nuage_neutron.plugins.nuage.common import constants as nuage_const
+from nuage_neutron.plugins.nuage import plugin
 
 LOG = log.getLogger(__name__)
 
@@ -61,8 +62,8 @@ class NuageMechanismDriver(plugin.NuagePlugin,
         # talking to backend.
         # 1) binding has happened successfully.
         # 2) Its a VM port.
-        if ((not context.original_bound_segment and
-            context.bound_segment) and
+        if ((not context.original_top_bound_segment and
+             context.top_bound_segment) and
             port['device_owner'].startswith(port_prefix)):
                 np_name = cfg.CONF.RESTPROXY.default_net_partition_name
                 self._create_update_port(context._plugin_context,
@@ -79,7 +80,7 @@ class NuageMechanismDriver(plugin.NuagePlugin,
                   "network %(network)s",
                   {'port': context.current['id'],
                    'network': context.network.current['id']})
-        for segment in context.network.network_segments:
+        for segment in context.segments_to_bind:
             if self._check_segment(segment):
                 context.set_binding(segment[api.ID],
                                     self.vif_type,
@@ -88,9 +89,9 @@ class NuageMechanismDriver(plugin.NuagePlugin,
                 LOG.debug("Bound using segment: %s", segment)
                 return
             else:
-                LOG.error(_("Refusing to bind port for segment ID %(id)s, "
-                          "segment %(seg)s, phys net %(physnet)s, and "
-                          "network type %(nettype)s"),
+                LOG.error(_LE("Refusing to bind port for segment ID %(id)s, "
+                              "segment %(seg)s, phys net %(physnet)s, and "
+                              "network type %(nettype)s"),
                           {'id': segment[api.ID],
                            'seg': segment[api.SEGMENTATION_ID],
                            'physnet': segment[api.PHYSICAL_NETWORK],
