@@ -14,20 +14,23 @@
 # limitations under the License.
 
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log
 
 from neutron.common import constants
 from neutron.extensions import portbindings
-from neutron.openstack.common import log
+from neutron.i18n import _LE, _LW
 from neutron.plugins.common import constants as p_const
 from neutron.plugins.ml2 import driver_api as api
+from neutron.plugins.ml2.drivers.mech_sriov import exceptions as exc
 
 
 LOG = log.getLogger(__name__)
+FLAT_VLAN = 0
 
 sriov_opts = [
     cfg.ListOpt('supported_pci_vendor_devs',
-               default=['15b3:1004', '8086:10c9'],
+               default=['15b3:1004', '8086:10ca'],
                help=_("Supported PCI vendor devices, defined by "
                       "vendor_id:product_id according to the PCI ID "
                       "Repository. Default enables support for Intel "
@@ -76,6 +79,7 @@ class SriovNicSwitchMechanismDriver(api.MechanismDriver):
         self.supported_vnic_types = supported_vnic_types
         self.vif_type = vif_type
         self.vif_details = vif_details
+        self.supported_network_types = (p_const.TYPE_VLAN, p_const.TYPE_FLAT)
 
     def initialize(self):
         try:
@@ -83,7 +87,7 @@ class SriovNicSwitchMechanismDriver(api.MechanismDriver):
                         cfg.CONF.ml2_sriov.supported_pci_vendor_devs)
             self.agent_required = cfg.CONF.ml2_sriov.agent_required
         except ValueError:
-            LOG.exception(_("Failed to parse supported PCI vendor devices"))
+            LOG.exception(_LE("Failed to parse supported PCI vendor devices"))
             raise cfg.Error(_("Parsing supported pci_vendor_devs failed"))
 
     def bind_port(self, context):
@@ -109,17 +113,17 @@ class SriovNicSwitchMechanismDriver(api.MechanismDriver):
                     if self.try_to_bind(context, agent):
                         return
                 else:
-                    LOG.warning(_("Attempting to bind with dead agent: %s"),
+                    LOG.warning(_LW("Attempting to bind with dead agent: %s"),
                                 agent)
         else:
             self.try_to_bind(context)
 
     def try_to_bind(self, context, agent=None):
-        for segment in context.network.network_segments:
+        for segment in context.segments_to_bind:
             if self.check_segment(segment, agent):
                 context.set_binding(segment[api.ID],
                                     self.vif_type,
-                                    self.get_vif_details(context, segment),
+                                    self._get_vif_details(segment),
                                     constants.PORT_STATUS_ACTIVE)
                 LOG.debug("Bound using segment: %s", segment)
                 return True
@@ -133,7 +137,7 @@ class SriovNicSwitchMechanismDriver(api.MechanismDriver):
         :returns: True if segment can be bound for agent
         """
         network_type = segment[api.NETWORK_TYPE]
-        if network_type == p_const.TYPE_VLAN:
+        if network_type in self.supported_network_types:
             if agent:
                 mappings = agent['configurations'].get('device_mappings', {})
                 LOG.debug("Checking segment: %(segment)s "
@@ -159,11 +163,17 @@ class SriovNicSwitchMechanismDriver(api.MechanismDriver):
             return True
         return False
 
-    def get_vif_details(self, context, segment):
-        if segment[api.NETWORK_TYPE] == p_const.TYPE_VLAN:
-            vlan_id = str(segment[api.SEGMENTATION_ID])
-            self.vif_details[portbindings.VIF_DETAILS_VLAN] = vlan_id
-        return self.vif_details
+    def _get_vif_details(self, segment):
+        network_type = segment[api.NETWORK_TYPE]
+        if network_type == p_const.TYPE_FLAT:
+            vlan_id = FLAT_VLAN
+        elif network_type == p_const.TYPE_VLAN:
+            vlan_id = segment[api.SEGMENTATION_ID]
+        else:
+            raise exc.SriovUnsupportedNetworkType(net_type=network_type)
+        vif_details = self.vif_details.copy()
+        vif_details[portbindings.VIF_DETAILS_VLAN] = str(vlan_id)
+        return vif_details
 
     def _parse_pci_vendor_config(self, pci_vendor_list):
         parsed_list = []
