@@ -14,7 +14,7 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
 
 from neutron.extensions import portbindings
 
@@ -23,9 +23,6 @@ eswitch_opts = [
                default=portbindings.VIF_TYPE_MLNX_DIRECT,
                help=_("Type of VM network interface: mlnx_direct or "
                       "hostdev")),
-    cfg.BoolOpt('apply_profile_patch',
-                default=False,
-                help=_("Enable server compatibility with old nova")),
 ]
 
 
