@@ -13,17 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo.config import cfg
-from oslo.db import exception as db_exc
+from oslo_config import cfg
+from oslo_db import exception as db_exc
+from oslo_log import log
 from six import moves
 import sqlalchemy as sa
 from sqlalchemy import sql
 
-from neutron.common import exceptions as exc
+from neutron.common import exceptions as n_exc
 from neutron.db import api as db_api
 from neutron.db import model_base
-from neutron.openstack.common.gettextutils import _LE, _LW
-from neutron.openstack.common import log
+from neutron.i18n import _LE, _LW
 from neutron.plugins.common import constants as p_const
 from neutron.plugins.ml2.drivers import type_tunnel
 
@@ -47,14 +47,20 @@ class GreAllocation(model_base.BASEV2):
     gre_id = sa.Column(sa.Integer, nullable=False, primary_key=True,
                        autoincrement=False)
     allocated = sa.Column(sa.Boolean, nullable=False, default=False,
-                          server_default=sql.false())
+                          server_default=sql.false(), index=True)
 
 
 class GreEndpoints(model_base.BASEV2):
     """Represents tunnel endpoint in RPC mode."""
-    __tablename__ = 'ml2_gre_endpoints'
 
+    __tablename__ = 'ml2_gre_endpoints'
+    __table_args__ = (
+        sa.UniqueConstraint('host',
+                            name='unique_ml2_gre_endpoints0host'),
+        model_base.BASEV2.__table_args__
+    )
     ip_address = sa.Column(sa.String(64), primary_key=True)
+    host = sa.Column(sa.String(255), nullable=True)
 
     def __repr__(self):
         return "<GreTunnelEndpoint(%s)>" % self.ip_address
@@ -71,9 +77,9 @@ class GreTypeDriver(type_tunnel.TunnelTypeDriver):
     def initialize(self):
         try:
             self._initialize(cfg.CONF.ml2_type_gre.tunnel_id_ranges)
-        except exc.NetworkTunnelRangeError:
-            LOG.exception(_("Failed to parse tunnel_id_ranges. "
-                            "Service terminated!"))
+        except n_exc.NetworkTunnelRangeError:
+            LOG.exception(_LE("Failed to parse tunnel_id_ranges. "
+                              "Service terminated!"))
             raise SystemExit()
 
     def sync_allocations(self):
@@ -84,7 +90,7 @@ class GreTypeDriver(type_tunnel.TunnelTypeDriver):
             tun_min, tun_max = gre_id_range
             if tun_max + 1 - tun_min > 1000000:
                 LOG.error(_LE("Skipping unreasonable gre ID range "
-                            "%(tun_min)s:%(tun_max)s"),
+                              "%(tun_min)s:%(tun_max)s"),
                           {'tun_min': tun_min, 'tun_max': tun_max})
             else:
                 gre_ids |= set(moves.xrange(tun_min, tun_max + 1))
@@ -125,19 +131,42 @@ class GreTypeDriver(type_tunnel.TunnelTypeDriver):
         LOG.debug("get_gre_endpoints() called")
         session = db_api.get_session()
 
-        with session.begin(subtransactions=True):
-            gre_endpoints = session.query(GreEndpoints)
-            return [{'ip_address': gre_endpoint.ip_address}
-                    for gre_endpoint in gre_endpoints]
+        gre_endpoints = session.query(GreEndpoints)
+        return [{'ip_address': gre_endpoint.ip_address,
+                 'host': gre_endpoint.host}
+                for gre_endpoint in gre_endpoints]
 
-    def add_endpoint(self, ip):
+    def get_endpoint_by_host(self, host):
+        LOG.debug("get_endpoint_by_host() called for host %s", host)
+        session = db_api.get_session()
+        return (session.query(GreEndpoints).
+                filter_by(host=host).first())
+
+    def get_endpoint_by_ip(self, ip):
+        LOG.debug("get_endpoint_by_ip() called for ip %s", ip)
+        session = db_api.get_session()
+        return (session.query(GreEndpoints).
+                filter_by(ip_address=ip).first())
+
+    def add_endpoint(self, ip, host):
         LOG.debug("add_gre_endpoint() called for ip %s", ip)
         session = db_api.get_session()
         try:
-            gre_endpoint = GreEndpoints(ip_address=ip)
+            gre_endpoint = GreEndpoints(ip_address=ip, host=host)
             gre_endpoint.save(session)
         except db_exc.DBDuplicateEntry:
             gre_endpoint = (session.query(GreEndpoints).
                             filter_by(ip_address=ip).one())
-            LOG.warning(_("Gre endpoint with ip %s already exists"), ip)
+            LOG.warning(_LW("Gre endpoint with ip %s already exists"), ip)
         return gre_endpoint
+
+    def delete_endpoint(self, ip):
+        LOG.debug("delete_gre_endpoint() called for ip %s", ip)
+        session = db_api.get_session()
+
+        with session.begin(subtransactions=True):
+            session.query(GreEndpoints).filter_by(ip_address=ip).delete()
+
+    def get_mtu(self, physical_network=None):
+        mtu = super(GreTypeDriver, self).get_mtu(physical_network)
+        return mtu - p_const.GRE_ENCAP_OVERHEAD if mtu else 0
