@@ -15,7 +15,8 @@
 
 import sys
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log
 from six import moves
 import sqlalchemy as sa
 
@@ -24,7 +25,7 @@ from neutron.common import exceptions as exc
 from neutron.common import utils
 from neutron.db import api as db_api
 from neutron.db import model_base
-from neutron.openstack.common import log
+from neutron.i18n import _LE, _LI, _LW
 from neutron.plugins.common import constants as p_const
 from neutron.plugins.common import utils as plugin_utils
 from neutron.plugins.ml2 import driver_api as api
@@ -60,6 +61,10 @@ class VlanAllocation(model_base.BASEV2):
     """
 
     __tablename__ = 'ml2_vlan_allocations'
+    __table_args__ = (
+        sa.Index('ix_ml2_vlan_allocations_physical_network_allocated',
+                 'physical_network', 'allocated'),
+        model_base.BASEV2.__table_args__,)
 
     physical_network = sa.Column(sa.String(64), nullable=False,
                                  primary_key=True)
@@ -68,7 +73,7 @@ class VlanAllocation(model_base.BASEV2):
     allocated = sa.Column(sa.Boolean, nullable=False)
 
 
-class VlanTypeDriver(helpers.TypeDriverHelper):
+class VlanTypeDriver(helpers.SegmentTypeDriver):
     """Manage state for VLAN networks with ML2.
 
     The VlanTypeDriver implements the 'vlan' network_type. VLAN
@@ -87,13 +92,11 @@ class VlanTypeDriver(helpers.TypeDriverHelper):
         try:
             self.network_vlan_ranges = plugin_utils.parse_network_vlan_ranges(
                 cfg.CONF.ml2_type_vlan.network_vlan_ranges)
-            # TODO(rkukura): Validate that each physical_network name
-            # is neither empty nor too long.
         except Exception:
-            LOG.exception(_("Failed to parse network_vlan_ranges. "
-                            "Service terminated!"))
+            LOG.exception(_LE("Failed to parse network_vlan_ranges. "
+                              "Service terminated!"))
             sys.exit(1)
-        LOG.info(_("Network VLAN ranges: %s"), self.network_vlan_ranges)
+        LOG.info(_LI("Network VLAN ranges: %s"), self.network_vlan_ranges)
 
     def _sync_vlan_allocations(self):
         session = db_api.get_session()
@@ -127,9 +130,9 @@ class VlanTypeDriver(helpers.TypeDriverHelper):
                             # it's not allocatable, so check if its allocated
                             if not alloc.allocated:
                                 # it's not, so remove it from table
-                                LOG.debug(_("Removing vlan %(vlan_id)s on "
-                                            "physical network "
-                                            "%(physical_network)s from pool"),
+                                LOG.debug("Removing vlan %(vlan_id)s on "
+                                          "physical network "
+                                          "%(physical_network)s from pool",
                                           {'vlan_id': alloc.vlan_id,
                                            'physical_network':
                                            physical_network})
@@ -148,8 +151,8 @@ class VlanTypeDriver(helpers.TypeDriverHelper):
             for allocs in allocations.itervalues():
                 for alloc in allocs:
                     if not alloc.allocated:
-                        LOG.debug(_("Removing vlan %(vlan_id)s on physical "
-                                    "network %(physical_network)s from pool"),
+                        LOG.debug("Removing vlan %(vlan_id)s on physical "
+                                  "network %(physical_network)s from pool",
                                   {'vlan_id': alloc.vlan_id,
                                    'physical_network':
                                    alloc.physical_network})
@@ -160,7 +163,7 @@ class VlanTypeDriver(helpers.TypeDriverHelper):
 
     def initialize(self):
         self._sync_vlan_allocations()
-        LOG.info(_("VlanTypeDriver initialization complete"))
+        LOG.info(_LI("VlanTypeDriver initialization complete"))
 
     def is_partial_segment(self, segment):
         return segment.get(api.SEGMENTATION_ID) is None
@@ -214,7 +217,8 @@ class VlanTypeDriver(helpers.TypeDriverHelper):
 
         return {api.NETWORK_TYPE: p_const.TYPE_VLAN,
                 api.PHYSICAL_NETWORK: alloc.physical_network,
-                api.SEGMENTATION_ID: alloc.vlan_id}
+                api.SEGMENTATION_ID: alloc.vlan_id,
+                api.MTU: self.get_mtu(alloc.physical_network)}
 
     def allocate_tenant_segment(self, session):
         alloc = self.allocate_partially_specified_segment(session)
@@ -222,7 +226,8 @@ class VlanTypeDriver(helpers.TypeDriverHelper):
             return
         return {api.NETWORK_TYPE: p_const.TYPE_VLAN,
                 api.PHYSICAL_NETWORK: alloc.physical_network,
-                api.SEGMENTATION_ID: alloc.vlan_id}
+                api.SEGMENTATION_ID: alloc.vlan_id,
+                api.MTU: self.get_mtu(alloc.physical_network)}
 
     def release_segment(self, session, segment):
         physical_network = segment[api.PHYSICAL_NETWORK]
@@ -251,7 +256,16 @@ class VlanTypeDriver(helpers.TypeDriverHelper):
                                'physical_network': physical_network})
 
         if not count:
-            LOG.warning(_("No vlan_id %(vlan_id)s found on physical "
-                          "network %(physical_network)s"),
+            LOG.warning(_LW("No vlan_id %(vlan_id)s found on physical "
+                            "network %(physical_network)s"),
                         {'vlan_id': vlan_id,
                          'physical_network': physical_network})
+
+    def get_mtu(self, physical_network):
+        seg_mtu = super(VlanTypeDriver, self).get_mtu()
+        mtu = []
+        if seg_mtu > 0:
+            mtu.append(seg_mtu)
+        if physical_network in self.physnet_mtus:
+            mtu.append(int(self.physnet_mtus[physical_network]))
+        return min(mtu) if mtu else 0
