@@ -13,17 +13,17 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo.config import cfg
-from oslo.db import exception as db_exc
+from oslo_config import cfg
+from oslo_db import exception as db_exc
+from oslo_log import log
 from six import moves
 import sqlalchemy as sa
 from sqlalchemy import sql
 
-from neutron.common import exceptions as exc
+from neutron.common import exceptions as n_exc
 from neutron.db import api as db_api
 from neutron.db import model_base
-from neutron.openstack.common.gettextutils import _LE
-from neutron.openstack.common import log
+from neutron.i18n import _LE, _LW
 from neutron.plugins.common import constants as p_const
 from neutron.plugins.ml2.drivers import type_tunnel
 
@@ -53,15 +53,21 @@ class VxlanAllocation(model_base.BASEV2):
     vxlan_vni = sa.Column(sa.Integer, nullable=False, primary_key=True,
                           autoincrement=False)
     allocated = sa.Column(sa.Boolean, nullable=False, default=False,
-                          server_default=sql.false())
+                          server_default=sql.false(), index=True)
 
 
 class VxlanEndpoints(model_base.BASEV2):
     """Represents tunnel endpoint in RPC mode."""
-    __tablename__ = 'ml2_vxlan_endpoints'
 
+    __tablename__ = 'ml2_vxlan_endpoints'
+    __table_args__ = (
+        sa.UniqueConstraint('host',
+                            name='unique_ml2_vxlan_endpoints0host'),
+        model_base.BASEV2.__table_args__
+    )
     ip_address = sa.Column(sa.String(64), primary_key=True)
     udp_port = sa.Column(sa.Integer, nullable=False)
+    host = sa.Column(sa.String(255), nullable=True)
 
     def __repr__(self):
         return "<VxlanTunnelEndpoint(%s)>" % self.ip_address
@@ -78,9 +84,9 @@ class VxlanTypeDriver(type_tunnel.TunnelTypeDriver):
     def initialize(self):
         try:
             self._initialize(cfg.CONF.ml2_type_vxlan.vni_ranges)
-        except exc.NetworkTunnelRangeError:
-            LOG.exception(_("Failed to parse vni_ranges. "
-                            "Service terminated!"))
+        except n_exc.NetworkTunnelRangeError:
+            LOG.exception(_LE("Failed to parse vni_ranges. "
+                              "Service terminated!"))
             raise SystemExit()
 
     def sync_allocations(self):
@@ -114,9 +120,10 @@ class VxlanTypeDriver(type_tunnel.TunnelTypeDriver):
             chunked_vnis = (vnis_to_remove[i:i + bulk_size] for i in
                             range(0, len(vnis_to_remove), bulk_size))
             for vni_list in chunked_vnis:
-                session.query(VxlanAllocation).filter(
-                    VxlanAllocation.vxlan_vni.in_(vni_list)).delete(
-                        synchronize_session=False)
+                if vni_list:
+                    session.query(VxlanAllocation).filter(
+                        VxlanAllocation.vxlan_vni.in_(vni_list)).delete(
+                            synchronize_session=False)
             # collect vnis that need to be added
             vnis = list(vxlan_vnis - existing_vnis)
             chunked_vnis = (vnis[i:i + bulk_size] for i in
@@ -129,24 +136,48 @@ class VxlanTypeDriver(type_tunnel.TunnelTypeDriver):
     def get_endpoints(self):
         """Get every vxlan endpoints from database."""
 
-        LOG.debug(_("get_vxlan_endpoints() called"))
+        LOG.debug("get_vxlan_endpoints() called")
         session = db_api.get_session()
 
-        with session.begin(subtransactions=True):
-            vxlan_endpoints = session.query(VxlanEndpoints)
-            return [{'ip_address': vxlan_endpoint.ip_address,
-                     'udp_port': vxlan_endpoint.udp_port}
-                    for vxlan_endpoint in vxlan_endpoints]
+        vxlan_endpoints = session.query(VxlanEndpoints)
+        return [{'ip_address': vxlan_endpoint.ip_address,
+                 'udp_port': vxlan_endpoint.udp_port,
+                 'host': vxlan_endpoint.host}
+                for vxlan_endpoint in vxlan_endpoints]
 
-    def add_endpoint(self, ip, udp_port=VXLAN_UDP_PORT):
-        LOG.debug(_("add_vxlan_endpoint() called for ip %s"), ip)
+    def get_endpoint_by_host(self, host):
+        LOG.debug("get_endpoint_by_host() called for host %s", host)
+        session = db_api.get_session()
+        return (session.query(VxlanEndpoints).
+                filter_by(host=host).first())
+
+    def get_endpoint_by_ip(self, ip):
+        LOG.debug("get_endpoint_by_ip() called for ip %s", ip)
+        session = db_api.get_session()
+        return (session.query(VxlanEndpoints).
+                filter_by(ip_address=ip).first())
+
+    def add_endpoint(self, ip, host, udp_port=VXLAN_UDP_PORT):
+        LOG.debug("add_vxlan_endpoint() called for ip %s", ip)
         session = db_api.get_session()
         try:
             vxlan_endpoint = VxlanEndpoints(ip_address=ip,
-                                            udp_port=udp_port)
+                                            udp_port=udp_port,
+                                            host=host)
             vxlan_endpoint.save(session)
         except db_exc.DBDuplicateEntry:
             vxlan_endpoint = (session.query(VxlanEndpoints).
                               filter_by(ip_address=ip).one())
-            LOG.warning(_("Vxlan endpoint with ip %s already exists"), ip)
+            LOG.warning(_LW("Vxlan endpoint with ip %s already exists"), ip)
         return vxlan_endpoint
+
+    def delete_endpoint(self, ip):
+        LOG.debug("delete_vxlan_endpoint() called for ip %s", ip)
+        session = db_api.get_session()
+
+        with session.begin(subtransactions=True):
+            session.query(VxlanEndpoints).filter_by(ip_address=ip).delete()
+
+    def get_mtu(self, physical_network=None):
+        mtu = super(VxlanTypeDriver, self).get_mtu()
+        return mtu - p_const.VXLAN_ENCAP_OVERHEAD if mtu else 0
