@@ -13,20 +13,23 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+from oslo_log import log
+import oslo_messaging
 from sqlalchemy.orm import exc
 
 from neutron.agent import securitygroups_rpc as sg_rpc
 from neutron.api.rpc.handlers import dvr_rpc
+from neutron.callbacks import events
+from neutron.callbacks import registry
+from neutron.callbacks import resources
 from neutron.common import constants as q_const
 from neutron.common import exceptions
 from neutron.common import rpc as n_rpc
 from neutron.common import topics
-from neutron.common import utils
 from neutron.extensions import portbindings
 from neutron.extensions import portsecurity as psec
+from neutron.i18n import _LW
 from neutron import manager
-from neutron.openstack.common import log
-from neutron.plugins.common import constants as service_constants
 from neutron.plugins.ml2 import driver_api as api
 from neutron.plugins.ml2.drivers import type_tunnel
 # REVISIT(kmestery): Allow the type and mechanism drivers to supply the
@@ -35,10 +38,8 @@ from neutron.plugins.ml2.drivers import type_tunnel
 LOG = log.getLogger(__name__)
 
 
-class RpcCallbacks(n_rpc.RpcCallback,
-                   type_tunnel.TunnelRpcCallbackMixin):
+class RpcCallbacks(type_tunnel.TunnelRpcCallbackMixin):
 
-    RPC_API_VERSION = '1.3'
     # history
     #   1.0 Initial version (from openvswitch/linuxbridge)
     #   1.1 Support Security Group RPC
@@ -46,6 +47,8 @@ class RpcCallbacks(n_rpc.RpcCallback,
     #   1.3 get_device_details rpc signature upgrade to obtain 'host' and
     #       return value to include fixed_ips and device_owner for
     #       the device port
+    #   1.4 tunnel_sync rpc signature upgrade to obtain 'host'
+    target = oslo_messaging.Target(version='1.4')
 
     def __init__(self, notifier, type_manager):
         self.setup_tunnel_callback_mixin(notifier, type_manager)
@@ -56,6 +59,9 @@ class RpcCallbacks(n_rpc.RpcCallback,
         agent_id = kwargs.get('agent_id')
         device = kwargs.get('device')
         host = kwargs.get('host')
+        # cached networks used for reducing number of network db calls
+        # for server internal usage only
+        cached_networks = kwargs.get('cached_networks')
         LOG.debug("Device %(device)s details requested by agent "
                   "%(agent_id)s with host %(host)s",
                   {'device': device, 'agent_id': agent_id, 'host': host})
@@ -64,20 +70,26 @@ class RpcCallbacks(n_rpc.RpcCallback,
         port_id = plugin._device_to_port_id(device)
         port_context = plugin.get_bound_port_context(rpc_context,
                                                      port_id,
-                                                     host)
+                                                     host,
+                                                     cached_networks)
         if not port_context:
-            LOG.warning(_("Device %(device)s requested by agent "
-                          "%(agent_id)s not found in database"),
+            LOG.warning(_LW("Device %(device)s requested by agent "
+                            "%(agent_id)s not found in database"),
                         {'device': device, 'agent_id': agent_id})
             return {'device': device}
 
-        segment = port_context.bound_segment
+        segment = port_context.bottom_bound_segment
         port = port_context.current
+        # caching information about networks for future use
+        if cached_networks is not None:
+            if port['network_id'] not in cached_networks:
+                cached_networks[port['network_id']] = (
+                    port_context.network.current)
 
         if not segment:
-            LOG.warning(_("Device %(device)s requested by agent "
-                          "%(agent_id)s on network %(network_id)s not "
-                          "bound, vif_type: %(vif_type)s"),
+            LOG.warning(_LW("Device %(device)s requested by agent "
+                            "%(agent_id)s on network %(network_id)s not "
+                            "bound, vif_type: %(vif_type)s"),
                         {'device': device,
                          'agent_id': agent_id,
                          'network_id': port['network_id'],
@@ -106,14 +118,17 @@ class RpcCallbacks(n_rpc.RpcCallback,
                  'allowed_address_pairs': port['allowed_address_pairs'],
                  'port_security_enabled': port.get(psec.PORTSECURITY, True),
                  'profile': port[portbindings.PROFILE]}
-        LOG.debug(_("Returning: %s"), entry)
+        LOG.debug("Returning: %s", entry)
         return entry
 
     def get_devices_details_list(self, rpc_context, **kwargs):
+        # cached networks used for reducing number of network db calls
+        cached_networks = {}
         return [
             self.get_device_details(
                 rpc_context,
                 device=device,
+                cached_networks=cached_networks,
                 **kwargs
             )
             for device in kwargs.pop('devices', [])
@@ -125,16 +140,16 @@ class RpcCallbacks(n_rpc.RpcCallback,
         agent_id = kwargs.get('agent_id')
         device = kwargs.get('device')
         host = kwargs.get('host')
-        LOG.debug(_("Device %(device)s no longer exists at agent "
-                    "%(agent_id)s"),
+        LOG.debug("Device %(device)s no longer exists at agent "
+                  "%(agent_id)s",
                   {'device': device, 'agent_id': agent_id})
         plugin = manager.NeutronManager.get_plugin()
         port_id = plugin._device_to_port_id(device)
         port_exists = True
         if (host and not plugin.port_bound_to_host(rpc_context,
                                                    port_id, host)):
-            LOG.debug(_("Device %(device)s not bound to the"
-                        " agent host %(host)s"),
+            LOG.debug("Device %(device)s not bound to the"
+                      " agent host %(host)s",
                       {'device': device, 'host': host})
             return {'device': device,
                     'exists': port_exists}
@@ -155,33 +170,38 @@ class RpcCallbacks(n_rpc.RpcCallback,
         agent_id = kwargs.get('agent_id')
         device = kwargs.get('device')
         host = kwargs.get('host')
-        LOG.debug(_("Device %(device)s up at agent %(agent_id)s"),
+        LOG.debug("Device %(device)s up at agent %(agent_id)s",
                   {'device': device, 'agent_id': agent_id})
         plugin = manager.NeutronManager.get_plugin()
         port_id = plugin._device_to_port_id(device)
         if (host and not plugin.port_bound_to_host(rpc_context,
                                                    port_id, host)):
-            LOG.debug(_("Device %(device)s not bound to the"
-                        " agent host %(host)s"),
+            LOG.debug("Device %(device)s not bound to the"
+                      " agent host %(host)s",
                       {'device': device, 'host': host})
             return
 
         port_id = plugin.update_port_status(rpc_context, port_id,
                                             q_const.PORT_STATUS_ACTIVE,
                                             host)
-        l3plugin = manager.NeutronManager.get_service_plugins().get(
-            service_constants.L3_ROUTER_NAT)
-        if (l3plugin and
-            utils.is_extension_supported(l3plugin,
-                                         q_const.L3_DISTRIBUTED_EXT_ALIAS)):
-            try:
-                l3plugin.dvr_vmarp_table_update(rpc_context, port_id, "add")
-            except exceptions.PortNotFound:
-                LOG.debug('Port %s not found during ARP update', port_id)
+        try:
+            # NOTE(armax): it's best to remove all objects from the
+            # session, before we try to retrieve the new port object
+            rpc_context.session.expunge_all()
+            port = plugin._get_port(rpc_context, port_id)
+        except exceptions.PortNotFound:
+            LOG.debug('Port %s not found during update', port_id)
+        else:
+            kwargs = {
+                'context': rpc_context,
+                'port': port,
+                'update_device_up': True
+            }
+            registry.notify(
+                resources.PORT, events.AFTER_UPDATE, plugin, **kwargs)
 
 
-class AgentNotifierApi(n_rpc.RpcProxy,
-                       dvr_rpc.DVRAgentRpcApiMixin,
+class AgentNotifierApi(dvr_rpc.DVRAgentRpcApiMixin,
                        sg_rpc.SecurityGroupAgentRpcApiMixin,
                        type_tunnel.TunnelAgentRpcApiMixin):
     """Agent side of the openvswitch rpc API.
@@ -193,30 +213,35 @@ class AgentNotifierApi(n_rpc.RpcProxy,
 
     """
 
-    BASE_RPC_API_VERSION = '1.1'
-
     def __init__(self, topic):
-        super(AgentNotifierApi, self).__init__(
-            topic=topic, default_version=self.BASE_RPC_API_VERSION)
+        self.topic = topic
         self.topic_network_delete = topics.get_topic_name(topic,
                                                           topics.NETWORK,
                                                           topics.DELETE)
         self.topic_port_update = topics.get_topic_name(topic,
                                                        topics.PORT,
                                                        topics.UPDATE)
+        self.topic_port_delete = topics.get_topic_name(topic,
+                                                       topics.PORT,
+                                                       topics.DELETE)
+
+        target = oslo_messaging.Target(topic=topic, version='1.0')
+        self.client = n_rpc.get_client(target)
 
     def network_delete(self, context, network_id):
-        self.fanout_cast(context,
-                         self.make_msg('network_delete',
-                                       network_id=network_id),
-                         topic=self.topic_network_delete)
+        cctxt = self.client.prepare(topic=self.topic_network_delete,
+                                    fanout=True)
+        cctxt.cast(context, 'network_delete', network_id=network_id)
 
     def port_update(self, context, port, network_type, segmentation_id,
                     physical_network):
-        self.fanout_cast(context,
-                         self.make_msg('port_update',
-                                       port=port,
-                                       network_type=network_type,
-                                       segmentation_id=segmentation_id,
-                                       physical_network=physical_network),
-                         topic=self.topic_port_update)
+        cctxt = self.client.prepare(topic=self.topic_port_update,
+                                    fanout=True)
+        cctxt.cast(context, 'port_update', port=port,
+                   network_type=network_type, segmentation_id=segmentation_id,
+                   physical_network=physical_network)
+
+    def port_delete(self, context, port_id):
+        cctxt = self.client.prepare(topic=self.topic_port_delete,
+                                    fanout=True)
+        cctxt.cast(context, 'port_delete', port_id=port_id)
