@@ -17,8 +17,8 @@
 from sqlalchemy import Boolean, Column, ForeignKey, Integer, String
 from sqlalchemy.schema import UniqueConstraint
 
+from neutron.db import model_base
 from neutron.db import models_v2
-from neutron.db.models_v2 import model_base
 from sqlalchemy import orm
 
 
