@@ -21,17 +21,13 @@
 import sys
 
 import eventlet
-eventlet.monkey_patch()
-
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
 
 from neutron.common import config
+from neutron.i18n import _LI
 from neutron import service
 
-from neutron.openstack.common import gettextutils
-from neutron.openstack.common import log as logging
-gettextutils.install('neutron', lazy=True)
-
 LOG = logging.getLogger(__name__)
 
 
@@ -51,7 +47,8 @@ def main():
         try:
             neutron_rpc = service.serve_rpc()
         except NotImplementedError:
-            LOG.info(_("RPC was already started in parent process by plugin."))
+            LOG.info(_LI("RPC was already started in parent process by "
+                         "plugin."))
         else:
             rpc_thread = pool.spawn(neutron_rpc.wait)
 
@@ -64,7 +61,3 @@ def main():
         pass
     except RuntimeError as e:
         sys.exit(_("ERROR: %s") % e)
-
-
-if __name__ == "__main__":
-    main()
