@@ -13,14 +13,18 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo.config import cfg
+from oslo_config import cfg
+from oslo_log import log as logging
+import stevedore
 
 from neutron.common import exceptions as n_exc
-from neutron.openstack.common import log as logging
+from neutron.common import repos
+from neutron.i18n import _LW
 from neutron.plugins.common import constants
 
 LOG = logging.getLogger(__name__)
 
+SERVICE_PROVIDERS = 'neutron.service_providers'
 
 serviceprovider_opts = [
     cfg.MultiStrOpt('service_provider', default=[],
@@ -37,6 +41,30 @@ def normalize_provider_name(name):
     return name.lower()
 
 
+def get_provider_driver_class(driver, namespace=SERVICE_PROVIDERS):
+    """Return path to provider driver class
+
+    In order to keep backward compatibility with configs < Kilo, we need to
+    translate driver class paths after advanced services split. This is done by
+    defining old class path as entry point in neutron package.
+    """
+    try:
+        driver_manager = stevedore.driver.DriverManager(
+            namespace, driver).driver
+    except ImportError:
+        return driver
+    except RuntimeError:
+        return driver
+    new_driver = "%s.%s" % (driver_manager.__module__,
+                            driver_manager.__name__)
+    LOG.warning(_LW(
+        "The configured driver %(driver)s has been moved, automatically "
+        "using %(new_driver)s instead. Please update your config files, "
+        "as this automatic fixup will be removed in a future release."),
+        {'driver': driver, 'new_driver': new_driver})
+    return new_driver
+
+
 def parse_service_provider_opt():
     """Parse service definition opts and returns result."""
     def validate_name(name):
@@ -44,7 +72,28 @@ def parse_service_provider_opt():
             raise n_exc.Invalid(
                 _("Provider name is limited by 255 characters: %s") % name)
 
-    svc_providers_opt = cfg.CONF.service_providers.service_provider
+    # TODO(dougwig) - phase out the neutron.conf location for service
+    # providers a cycle or two after Kilo.
+
+    # Look in neutron.conf for service providers first (legacy mode)
+    try:
+        svc_providers_opt = cfg.CONF.service_providers.service_provider
+    except cfg.NoSuchOptError:
+        svc_providers_opt = []
+
+    # Look in neutron-*aas.conf files for service provider configs
+    if svc_providers_opt:
+        LOG.warning(_LW("Reading service_providers from legacy location in "
+                        "neutron.conf, and ignoring values in "
+                        "neutron_*aas.conf files; this override will be "
+                        "going away soon."))
+    else:
+        neutron_mods = repos.NeutronModules()
+        for x in neutron_mods.installed_list():
+            svc_providers_opt += neutron_mods.service_providers(x)
+
+    LOG.debug("Service providers = %s", svc_providers_opt)
+
     res = []
     for prov_def in svc_providers_opt:
         split = prov_def.split(':')
@@ -71,6 +120,7 @@ def parse_service_provider_opt():
                     'allowed': constants.ALLOWED_SERVICES})
             LOG.error(msg)
             raise n_exc.Invalid(msg)
+        driver = get_provider_driver_class(driver)
         res.append({'service_type': svc_type,
                     'name': name,
                     'driver': driver,
