@@ -13,11 +13,10 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import six
-from tempest.lib.common.utils import data_utils
-from tempest import test
+from tempest_lib.common.utils import data_utils
 
 from neutron.tests.api import base
+from neutron.tests.tempest import test
 
 
 class QuotasTest(base.BaseAdminNetworkTest):
@@ -35,7 +34,7 @@ class QuotasTest(base.BaseAdminNetworkTest):
     It is also assumed that the per-tenant quota extension API is configured
     in /etc/neutron/neutron.conf as follows:
 
-        quota_driver = neutron.db.driver.DbQuotaDriver
+        quota_driver = neutron.db.quota_db.DbQuotaDriver
     """
 
     @classmethod
@@ -44,26 +43,23 @@ class QuotasTest(base.BaseAdminNetworkTest):
         if not test.is_extension_enabled('quotas', 'network'):
             msg = "quotas extension not enabled."
             raise cls.skipException(msg)
+        cls.identity_admin_client = cls.os_adm.identity_client
 
-    @test.attr(type='gate')
-    @test.idempotent_id('2390f766-836d-40ef-9aeb-e810d78207fb')
-    def test_quotas(self):
+    def _check_quotas(self, new_quotas):
         # Add a tenant to conduct the test
         test_tenant = data_utils.rand_name('test_tenant_')
         test_description = data_utils.rand_name('desc_')
         tenant = self.identity_admin_client.create_tenant(
             name=test_tenant,
-            description=test_description)['tenant']
+            description=test_description)
         tenant_id = tenant['id']
         self.addCleanup(self.identity_admin_client.delete_tenant, tenant_id)
 
-        new_quotas = {'network': 0, 'security_group': 0}
-
         # Change quotas for tenant
         quota_set = self.admin_client.update_quotas(tenant_id,
                                                     **new_quotas)
         self.addCleanup(self.admin_client.reset_quotas, tenant_id)
-        for key, value in six.iteritems(new_quotas):
+        for key, value in new_quotas.iteritems():
             self.assertEqual(value, quota_set[key])
 
         # Confirm our tenant is listed among tenants with non default quotas
@@ -77,7 +73,7 @@ class QuotasTest(base.BaseAdminNetworkTest):
         # Confirm from API quotas were changed as requested for tenant
         quota_set = self.admin_client.show_quotas(tenant_id)
         quota_set = quota_set['quota']
-        for key, value in six.iteritems(new_quotas):
+        for key, value in new_quotas.iteritems():
             self.assertEqual(value, quota_set[key])
 
         # Reset quotas to default and confirm
@@ -85,3 +81,17 @@ class QuotasTest(base.BaseAdminNetworkTest):
         non_default_quotas = self.admin_client.list_quotas()
         for q in non_default_quotas['quotas']:
             self.assertNotEqual(tenant_id, q['tenant_id'])
+
+    @test.attr(type='gate')
+    @test.idempotent_id('2390f766-836d-40ef-9aeb-e810d78207fb')
+    def test_quotas(self):
+        new_quotas = {'network': 0, 'security_group': 0}
+        self._check_quotas(new_quotas)
+
+    @test.idempotent_id('a7add2b1-691e-44d6-875f-697d9685f091')
+    @test.requires_ext(extension='lbaas', service='network')
+    @test.attr(type='gate')
+    def test_lbaas_quotas(self):
+        new_quotas = {'vip': 1, 'pool': 2,
+                      'member': 3, 'health_monitor': 4}
+        self._check_quotas(new_quotas)
