@@ -13,16 +13,13 @@
 #    under the License.
 #
 
-import functools
-
 import fixtures
 
 from neutron.agent.linux import ip_lib
-from neutron.agent.linux import utils
 from neutron.tests.common import net_helpers
 
 
-class FakeMachineBase(fixtures.Fixture):
+class FakeMachine(fixtures.Fixture):
     """Create a fake machine.
 
     :ivar bridge: bridge on which the fake machine is bound
@@ -39,89 +36,36 @@ class FakeMachineBase(fixtures.Fixture):
     :type port: IPDevice
     """
 
-    def __init__(self):
-        self.port = None
+    def __init__(self, bridge, ip_cidr, gateway_ip=None):
+        super(FakeMachine, self).__init__()
+        self.bridge = bridge
+        self.ip_cidr = ip_cidr
+        self.ip = self.ip_cidr.partition('/')[0]
+        self.gateway_ip = gateway_ip
 
-    def _setUp(self):
+    def setUp(self):
+        super(FakeMachine, self).setUp()
         ns_fixture = self.useFixture(
             net_helpers.NamespaceFixture())
         self.namespace = ns_fixture.name
 
+        self.port = self.useFixture(
+            net_helpers.PortFixture.get(self.bridge, self.namespace)).port
+        self.port.addr.add(self.ip_cidr)
+
+        if self.gateway_ip:
+            net_helpers.set_namespace_gateway(self.port, self.gateway_ip)
+
     def execute(self, *args, **kwargs):
         ns_ip_wrapper = ip_lib.IPWrapper(self.namespace)
         return ns_ip_wrapper.netns.execute(*args, **kwargs)
 
-    def ping_predicate(self, dst_ip):
-        try:
-            self.assert_ping(dst_ip)
-        except RuntimeError:
-            return False
-        return True
-
-    def block_until_ping(self, dst_ip):
-        predicate = functools.partial(self.ping_predicate, dst_ip)
-        utils.wait_until_true(predicate)
-
     def assert_ping(self, dst_ip):
         net_helpers.assert_ping(self.namespace, dst_ip)
 
     def assert_no_ping(self, dst_ip):
         net_helpers.assert_no_ping(self.namespace, dst_ip)
 
-    @property
-    def ip(self):
-        raise NotImplementedError()
-
-    @property
-    def ip_cidr(self):
-        raise NotImplementedError()
-
-    @property
-    def mac_address(self):
-        return self.port.link.address
-
-
-class FakeMachine(FakeMachineBase):
-
-    def __init__(self, bridge, ip_cidr, gateway_ip=None):
-        super(FakeMachine, self).__init__()
-        self.bridge = bridge
-        self._ip_cidr = ip_cidr
-        self.gateway_ip = gateway_ip
-
-    def _setUp(self):
-        super(FakeMachine, self)._setUp()
-
-        self.port = self.useFixture(
-            net_helpers.PortFixture.get(self.bridge, self.namespace)).port
-        self.port.addr.add(self._ip_cidr)
-
-        if self.gateway_ip:
-            net_helpers.set_namespace_gateway(self.port, self.gateway_ip)
-
-    @property
-    def ip(self):
-        return self._ip_cidr.partition('/')[0]
-
-    @property
-    def ip_cidr(self):
-        return self._ip_cidr
-
-    @ip_cidr.setter
-    def ip_cidr(self, ip_cidr):
-        self.port.addr.add(ip_cidr)
-        self.port.addr.delete(self._ip_cidr)
-        self._ip_cidr = ip_cidr
-
-    @FakeMachineBase.mac_address.setter
-    def mac_address(self, mac_address):
-        self.port.link.set_down()
-        self.port.link.set_address(mac_address)
-        self.port.link.set_up()
-
-    def set_default_gateway(self, default_gw):
-        self.port.route.add_gateway(default_gw)
-
 
 class PeerMachines(fixtures.Fixture):
     """Create 'amount' peered machines on an ip_cidr.
@@ -142,9 +86,9 @@ class PeerMachines(fixtures.Fixture):
         self.gateway_ip = gateway_ip
         self.amount = amount
 
-    def _setUp(self):
+    def setUp(self):
+        super(PeerMachines, self).setUp()
         self.machines = []
-
         for index in range(self.amount):
             ip_cidr = net_helpers.increment_ip_cidr(self.ip_cidr, index)
             self.machines.append(
