@@ -13,15 +13,13 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from unittest import mock
-
-from oslo_config import cfg
-from oslo_utils import uuidutils
+import mock
 
 from neutron.agent.l3 import dvr_snat_ns
 from neutron.agent.l3 import namespace_manager
 from neutron.agent.l3 import namespaces
 from neutron.agent.linux import ip_lib
+from neutron.openstack.common import uuidutils
 from neutron.tests.functional import base
 
 _uuid = uuidutils.generate_uuid
@@ -31,10 +29,11 @@ class NamespaceManagerTestFramework(base.BaseSudoTestCase):
 
     def setUp(self):
         super(NamespaceManagerTestFramework, self).setUp()
-        self.agent_conf = cfg.CONF
+        self.agent_conf = mock.MagicMock()
+        self.agent_conf.router_delete_namespaces = True
         self.metadata_driver_mock = mock.Mock()
         self.namespace_manager = namespace_manager.NamespaceManager(
-            self.agent_conf, driver=None,
+            self.agent_conf, driver=None, clean_stale=True,
             metadata_driver=self.metadata_driver_mock)
 
     def _create_namespace(self, router_id, ns_class):
@@ -49,12 +48,13 @@ class NamespaceManagerTestFramework(base.BaseSudoTestCase):
             namespace.delete()
         except RuntimeError as e:
             # If the namespace didn't exist when delete was attempted, mission
-            # accomplished. Otherwise, re-raise the exception
-            if 'No such file or directory' not in str(e):
+            # acomplished. Otherwise, re-raise the exception
+            if 'No such file or directory' not in e.message:
                 raise e
 
     def _namespace_exists(self, namespace):
-        return ip_lib.network_namespace_exists(namespace)
+        ip = ip_lib.IPWrapper(namespace=namespace)
+        return ip.netns.exists(namespace)
 
 
 class NamespaceManagerTestCase(NamespaceManagerTestFramework):
@@ -86,6 +86,6 @@ class NamespaceManagerTestCase(NamespaceManagerTestFramework):
             (self.metadata_driver_mock.destroy_monitored_metadata_proxy.
              assert_called_once_with(mock.ANY,
                                      router_id_to_delete,
-                                     self.agent_conf,
-                                     ns_name))
+                                     ns_name,
+                                     self.agent_conf))
             self.assertFalse(self._namespace_exists(ns_name))
