@@ -23,8 +23,12 @@ Tests in this module will be skipped unless:
 """
 
 import eventlet
+from oslo_config import cfg
 
 from neutron.agent.linux import ovsdb_monitor
+from neutron.agent.linux import utils
+from neutron.tests import base as tests_base
+from neutron.tests.common import net_helpers
 from neutron.tests.functional.agent.linux import base as linux_base
 from neutron.tests.functional import base as functional_base
 
@@ -34,23 +38,24 @@ class BaseMonitorTest(linux_base.BaseOVSLinuxTestCase):
     def setUp(self):
         super(BaseMonitorTest, self).setUp()
 
-        rootwrap_not_configured = (self.root_helper ==
+        rootwrap_not_configured = (cfg.CONF.AGENT.root_helper ==
                                    functional_base.SUDO_CMD)
         if rootwrap_not_configured:
             # The monitor tests require a nested invocation that has
             # to be emulated by double sudo if rootwrap is not
             # configured.
-            self.root_helper = '%s %s' % (self.root_helper, self.root_helper)
+            self.config(group='AGENT',
+                        root_helper=" ".join([functional_base.SUDO_CMD] * 2))
 
         self._check_test_requirements()
-        self.bridge = self.create_ovs_bridge()
+        # ovsdb-client monitor needs to have a bridge to make any output
+        self.useFixture(net_helpers.OVSBridgeFixture())
 
     def _check_test_requirements(self):
-        self.check_sudo_enabled()
         self.check_command(['ovsdb-client', 'list-dbs'],
                            'Exit code: 1',
                            'password-less sudo not granted for ovsdb-client',
-                           root_helper=self.root_helper)
+                           run_as_root=True)
 
 
 class TestOvsdbMonitor(BaseMonitorTest):
@@ -58,8 +63,7 @@ class TestOvsdbMonitor(BaseMonitorTest):
     def setUp(self):
         super(TestOvsdbMonitor, self).setUp()
 
-        self.monitor = ovsdb_monitor.OvsdbMonitor('Bridge',
-                                                  root_helper=self.root_helper)
+        self.monitor = ovsdb_monitor.OvsdbMonitor('Bridge')
         self.addCleanup(self.monitor.stop)
         self.monitor.start()
 
@@ -74,18 +78,17 @@ class TestOvsdbMonitor(BaseMonitorTest):
             eventlet.sleep(0.01)
 
     def test_killed_monitor_respawns(self):
-        with self.assert_max_execution_time():
-            self.monitor.respawn_interval = 0
-            old_pid = self.monitor._process.pid
-            output1 = self.collect_initial_output()
-            pid = self.monitor._get_pid_to_kill()
-            self.monitor._kill_process(pid)
-            self.monitor._reset_queues()
-            while (self.monitor._process.pid == old_pid):
-                eventlet.sleep(0.01)
-            output2 = self.collect_initial_output()
-            # Initial output should appear twice
-            self.assertEqual(output1, output2)
+        self.monitor.respawn_interval = 0
+        old_pid = self.monitor._process.pid
+        output1 = self.collect_initial_output()
+        pid = utils.get_root_helper_child_pid(old_pid, run_as_root=True)
+        self.monitor._kill_process(pid)
+        self.monitor._reset_queues()
+        while (self.monitor._process.pid == old_pid):
+            eventlet.sleep(0.01)
+        output2 = self.collect_initial_output()
+        # Initial output should appear twice
+        self.assertEqual(output1, output2)
 
 
 class TestSimpleInterfaceMonitor(BaseMonitorTest):
@@ -93,18 +96,19 @@ class TestSimpleInterfaceMonitor(BaseMonitorTest):
     def setUp(self):
         super(TestSimpleInterfaceMonitor, self).setUp()
 
-        self.monitor = ovsdb_monitor.SimpleInterfaceMonitor(
-            root_helper=self.root_helper)
+        self.monitor = ovsdb_monitor.SimpleInterfaceMonitor()
         self.addCleanup(self.monitor.stop)
-        self.monitor.start(block=True, timeout=60)
+        # In case a global test timeout isn't set or disabled, use a
+        # value that will ensure the monitor has time to start.
+        timeout = max(tests_base.get_test_timeout(), 60)
+        self.monitor.start(block=True, timeout=timeout)
 
     def test_has_updates(self):
         self.assertTrue(self.monitor.has_updates,
                         'Initial call should always be true')
         self.assertFalse(self.monitor.has_updates,
                          'has_updates without port addition should be False')
-        self.create_resource('test-port-', self.bridge.add_port)
-        with self.assert_max_execution_time():
-            # has_updates after port addition should become True
-            while not self.monitor.has_updates:
-                eventlet.sleep(0.01)
+        self.useFixture(net_helpers.OVSPortFixture())
+        # has_updates after port addition should become True
+        while not self.monitor.has_updates:
+            eventlet.sleep(0.01)
