@@ -12,6 +12,8 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
+import contextlib
+
 import eventlet.event
 import eventlet.queue
 import eventlet.timeout
@@ -23,9 +25,6 @@ from neutron.agent.linux import utils
 from neutron.tests import base
 
 
-_marker = ()
-
-
 class TestAsyncProcess(base.BaseTestCase):
 
     def setUp(self):
@@ -60,7 +59,7 @@ class TestAsyncProcess(base.BaseTestCase):
         with mock.patch.object(self.proc, '_kill') as kill:
             self.proc._handle_process_error()
 
-        kill.assert_has_calls(mock.call(respawning=False))
+        kill.assert_has_calls([mock.call(respawning=False)])
 
     def test__handle_process_error_kills_without_respawn(self):
         self.proc.respawn_interval = 1
@@ -69,8 +68,8 @@ class TestAsyncProcess(base.BaseTestCase):
                 with mock.patch('eventlet.sleep') as sleep:
                     self.proc._handle_process_error()
 
-        kill.assert_has_calls(mock.call(respawning=True))
-        sleep.assert_has_calls(mock.call(self.proc.respawn_interval))
+        kill.assert_has_calls([mock.call(respawning=True)])
+        sleep.assert_has_calls([mock.call(self.proc.respawn_interval)])
         spawn.assert_called_once_with()
 
     def _test__watch_process(self, callback, kill_event):
@@ -129,13 +128,14 @@ class TestAsyncProcess(base.BaseTestCase):
         mock_start.assert_called_once_with()
 
     def test__iter_queue_returns_empty_list_for_empty_queue(self):
-        result = list(self.proc._iter_queue(eventlet.queue.LightQueue()))
+        result = list(self.proc._iter_queue(eventlet.queue.LightQueue(),
+                                            False))
         self.assertEqual(result, [])
 
     def test__iter_queue_returns_queued_data(self):
         queue = eventlet.queue.LightQueue()
         queue.put('foo')
-        result = list(self.proc._iter_queue(queue))
+        result = list(self.proc._iter_queue(queue, False))
         self.assertEqual(result, ['foo'])
 
     def _test_iter_output_calls_iter_queue_on_output_queue(self, output_type):
@@ -147,7 +147,7 @@ class TestAsyncProcess(base.BaseTestCase):
 
         self.assertEqual(value, expected_value)
         queue = getattr(self.proc, '_%s_lines' % output_type, None)
-        mock_iter_queue.assert_called_with(queue)
+        mock_iter_queue.assert_called_with(queue, False)
 
     def test_iter_stdout(self):
         self._test_iter_output_calls_iter_queue_on_output_queue('stdout')
@@ -156,12 +156,17 @@ class TestAsyncProcess(base.BaseTestCase):
         self._test_iter_output_calls_iter_queue_on_output_queue('stderr')
 
     def _test__kill(self, respawning, pid=None):
-        with mock.patch.object(self.proc, '_kill_event') as mock_kill_event:
-            with mock.patch.object(self.proc, '_get_pid_to_kill',
-                                   return_value=pid):
-                with mock.patch.object(self.proc,
-                                       '_kill_process') as mock_kill_process:
-                    self.proc._kill(respawning)
+        with contextlib.nested(
+                mock.patch.object(self.proc, '_kill_event'),
+                mock.patch.object(utils, 'get_root_helper_child_pid',
+                                  return_value=pid),
+                mock.patch.object(self.proc, '_kill_process'),
+                mock.patch.object(self.proc, '_process')) as (
+                    mock_kill_event,
+                    mock_get_child_pid,
+                    mock_kill_process,
+                    mock_process):
+            self.proc._kill(respawning)
 
             if respawning:
                 self.assertIsNotNone(self.proc._kill_event)
@@ -181,42 +186,8 @@ class TestAsyncProcess(base.BaseTestCase):
     def test__kill_targets_process_for_pid(self):
         self._test__kill(False, pid='1')
 
-    def _test__get_pid_to_kill(self, expected=_marker,
-                               root_helper=None, pids=None):
-        def _find_child_pids(x):
-            if not pids:
-                return []
-            pids.pop(0)
-            return pids
-
-        if root_helper:
-            self.proc.root_helper = root_helper
-
-        with mock.patch.object(self.proc, '_process') as mock_process:
-            with mock.patch.object(mock_process, 'pid') as mock_pid:
-                with mock.patch.object(utils, 'find_child_pids',
-                                       side_effect=_find_child_pids):
-                    actual = self.proc._get_pid_to_kill()
-        if expected is _marker:
-            expected = mock_pid
-        self.assertEqual(expected, actual)
-
-    def test__get_pid_to_kill_returns_process_pid_without_root_helper(self):
-        self._test__get_pid_to_kill()
-
-    def test__get_pid_to_kill_returns_child_pid_with_root_helper(self):
-        self._test__get_pid_to_kill(expected='2', pids=['1', '2'],
-                                    root_helper='a')
-
-    def test__get_pid_to_kill_returns_last_child_pid_with_root_Helper(self):
-        self._test__get_pid_to_kill(expected='3', pids=['1', '2', '3'],
-                                    root_helper='a')
-
-    def test__get_pid_to_kill_returns_none_with_root_helper(self):
-        self._test__get_pid_to_kill(expected=None, root_helper='a')
-
     def _test__kill_process(self, pid, expected, exception_message=None):
-        self.proc.root_helper = 'foo'
+        self.proc.run_as_root = True
         if exception_message:
             exc = RuntimeError(exception_message)
         else:
@@ -227,7 +198,7 @@ class TestAsyncProcess(base.BaseTestCase):
 
         self.assertEqual(expected, actual)
         mock_execute.assert_called_with(['kill', '-9', pid],
-                                        root_helper=self.proc.root_helper)
+                                        run_as_root=self.proc.run_as_root)
 
     def test__kill_process_returns_true_for_valid_pid(self):
         self._test__kill_process('1', True)
