@@ -13,47 +13,26 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import logging
-from logging import handlers
+
+import contextlib
 import os
 import sys
-from unittest import mock
 
-from neutron_lib import exceptions
-from neutron_lib import fixture as lib_fixtures
+import mock
 import testtools
 
 from neutron.agent.linux import daemon
+from neutron.common import exceptions
 from neutron.tests import base
 
 FAKE_FD = 8
 
 
-class FakeEntry:
+class FakeEntry(object):
     def __init__(self, name, value):
         setattr(self, name, value)
 
 
-class TestUnwatchLog(base.BaseTestCase):
-    def setUp(self):
-        super().setUp()
-        self.temp_file = self.get_temp_file_path('unwatch_log_temp_file')
-
-    def test_unwatch_log(self):
-        stream_handler = logging.StreamHandler()
-        logger = logging.Logger('fake')
-        logger.addHandler(stream_handler)
-        logger.addHandler(handlers.WatchedFileHandler(self.temp_file))
-
-        with mock.patch('logging.getLogger', return_value=logger):
-            daemon.unwatch_log()
-            self.assertEqual(2, len(logger.handlers))
-            logger.handlers.remove(stream_handler)
-            observed = logger.handlers[0]
-            self.assertEqual(logging.FileHandler, type(observed))
-            self.assertEqual(self.temp_file, observed.baseFilename)
-
-
 class TestPrivileges(base.BaseTestCase):
     def test_setuid_with_name(self):
         with mock.patch('pwd.getpwnam', return_value=FakeEntry('pw_uid', 123)):
@@ -91,32 +70,33 @@ class TestPrivileges(base.BaseTestCase):
                                   daemon.setgid, '321')
                 log_critical.assert_called_once_with(mock.ANY)
 
-    @mock.patch.object(os, 'setgroups')
-    @mock.patch.object(daemon, 'setgid')
-    @mock.patch.object(daemon, 'setuid')
-    def test_drop_no_privileges(self, mock_setuid, mock_setgid,
-                                mock_setgroups):
-        daemon.drop_privileges()
-        for cursor in (mock_setuid, mock_setgid, mock_setgroups):
-            self.assertFalse(cursor.called)
+    def test_drop_no_privileges(self):
+        with contextlib.nested(
+                mock.patch.object(os, 'setgroups'),
+                mock.patch.object(daemon, 'setgid'),
+                mock.patch.object(daemon, 'setuid')) as mocks:
+            daemon.drop_privileges()
+            for cursor in mocks:
+                self.assertFalse(cursor.called)
 
-    @mock.patch.object(os, 'geteuid', return_value=0)
-    @mock.patch.object(os, 'setgroups')
-    @mock.patch.object(daemon, 'setgid')
-    @mock.patch.object(daemon, 'setuid')
-    def _test_drop_privileges(self, setuid, setgid, setgroups,
-                              geteuid, user=None, group=None):
-        daemon.drop_privileges(user=user, group=group)
-        if user:
-            setuid.assert_called_once_with(user)
-        else:
-            self.assertFalse(setuid.called)
-        if group:
-            setgroups.assert_called_once_with([])
-            setgid.assert_called_once_with(group)
-        else:
-            self.assertFalse(setgroups.called)
-            self.assertFalse(setgid.called)
+    def _test_drop_privileges(self, user=None, group=None):
+        with contextlib.nested(
+                mock.patch.object(os, 'geteuid', return_value=0),
+                mock.patch.object(os, 'setgroups'),
+                mock.patch.object(daemon, 'setgid'),
+                mock.patch.object(daemon, 'setuid')) as (
+                    geteuid, setgroups, setgid, setuid):
+            daemon.drop_privileges(user=user, group=group)
+            if user:
+                setuid.assert_called_once_with(user)
+            else:
+                self.assertFalse(setuid.called)
+            if group:
+                setgroups.assert_called_once_with([])
+                setgid.assert_called_once_with(group)
+            else:
+                self.assertFalse(setgroups.called)
+                self.assertFalse(setgid.called)
 
     def test_drop_user_privileges(self):
         self._test_drop_privileges(user='user')
@@ -140,7 +120,7 @@ class TestPrivileges(base.BaseTestCase):
 
 class TestPidfile(base.BaseTestCase):
     def setUp(self):
-        super().setUp()
+        super(TestPidfile, self).setUp()
         self.os_p = mock.patch.object(daemon, 'os')
         self.os = self.os_p.start()
         self.os.open.return_value = FAKE_FD
@@ -153,7 +133,7 @@ class TestPidfile(base.BaseTestCase):
         self.os.O_CREAT = os.O_CREAT
         self.os.O_RDWR = os.O_RDWR
 
-        daemon.Pidfile('thefile', sys.executable)
+        daemon.Pidfile('thefile', 'python')
         self.os.open.assert_called_once_with('thefile', os.O_CREAT | os.O_RDWR)
         self.fcntl.flock.assert_called_once_with(FAKE_FD, self.fcntl.LOCK_EX |
                                                  self.fcntl.LOCK_NB)
@@ -163,14 +143,14 @@ class TestPidfile(base.BaseTestCase):
 
         with mock.patch.object(daemon.sys, 'stderr'):
             with testtools.ExpectedException(SystemExit):
-                daemon.Pidfile('thefile', sys.executable)
+                daemon.Pidfile('thefile', 'python')
                 sys.assert_has_calls([
                     mock.call.stderr.write(mock.ANY),
                     mock.call.exit(1)]
                 )
 
     def test_unlock(self):
-        p = daemon.Pidfile('thefile', sys.executable)
+        p = daemon.Pidfile('thefile', 'python')
         p.unlock()
         self.fcntl.flock.assert_has_calls([
             mock.call(FAKE_FD, self.fcntl.LOCK_EX | self.fcntl.LOCK_NB),
@@ -178,62 +158,63 @@ class TestPidfile(base.BaseTestCase):
         )
 
     def test_write(self):
-        p = daemon.Pidfile('thefile', sys.executable)
+        p = daemon.Pidfile('thefile', 'python')
         p.write(34)
 
         self.os.assert_has_calls([
             mock.call.ftruncate(FAKE_FD, 0),
-            mock.call.write(FAKE_FD, b'34'),
+            mock.call.write(FAKE_FD, '34'),
             mock.call.fsync(FAKE_FD)]
         )
 
     def test_read(self):
         self.os.read.return_value = '34'
-        p = daemon.Pidfile('thefile', sys.executable)
+        p = daemon.Pidfile('thefile', 'python')
         self.assertEqual(34, p.read())
 
     def test_is_running(self):
-        mock_open = self.useFixture(
-            lib_fixtures.OpenFixture('/proc/34/cmdline',
-                                     sys.executable)).mock_open
-        p = daemon.Pidfile('thefile', sys.executable)
+        with mock.patch('__builtin__.open') as mock_open:
+            p = daemon.Pidfile('thefile', 'python')
+            mock_open.return_value.__enter__ = lambda s: s
+            mock_open.return_value.__exit__ = mock.Mock()
+            mock_open.return_value.readline.return_value = 'python'
 
-        with mock.patch.object(p, 'read') as read:
-            read.return_value = 34
-            self.assertTrue(p.is_running())
+            with mock.patch.object(p, 'read') as read:
+                read.return_value = 34
+                self.assertTrue(p.is_running())
 
-        mock_open.assert_called_once_with('/proc/34/cmdline')
+            mock_open.assert_called_once_with('/proc/34/cmdline', 'r')
 
     def test_is_running_uuid_true(self):
-        mock_open = self.useFixture(
-            lib_fixtures.OpenFixture(
-                '/proc/34/cmdline', '{} 1234'.format(
-                    sys.executable))).mock_open
-        p = daemon.Pidfile('thefile', sys.executable, uuid='1234')
+        with mock.patch('__builtin__.open') as mock_open:
+            p = daemon.Pidfile('thefile', 'python', uuid='1234')
+            mock_open.return_value.__enter__ = lambda s: s
+            mock_open.return_value.__exit__ = mock.Mock()
+            mock_open.return_value.readline.return_value = 'python 1234'
 
-        with mock.patch.object(p, 'read') as read:
-            read.return_value = 34
-            self.assertTrue(p.is_running())
+            with mock.patch.object(p, 'read') as read:
+                read.return_value = 34
+                self.assertTrue(p.is_running())
 
-        mock_open.assert_called_once_with('/proc/34/cmdline')
+            mock_open.assert_called_once_with('/proc/34/cmdline', 'r')
 
     def test_is_running_uuid_false(self):
-        mock_open = self.useFixture(
-            lib_fixtures.OpenFixture(
-                '/proc/34/cmdline', '{} 1234'.format(
-                    sys.executable))).mock_open
-        p = daemon.Pidfile('thefile', sys.executable, uuid='6789')
+        with mock.patch('__builtin__.open') as mock_open:
+            p = daemon.Pidfile('thefile', 'python', uuid='6789')
+            mock_open.return_value.__enter__ = lambda s: s
+            mock_open.return_value.__exit__ = mock.Mock()
+            mock_open.return_value.readline.return_value = 'python 1234'
 
-        with mock.patch.object(p, 'read') as read:
-            read.return_value = 34
-            self.assertFalse(p.is_running())
+            with mock.patch.object(p, 'read') as read:
+                read.return_value = 34
+                self.assertFalse(p.is_running())
 
-        mock_open.assert_called_once_with('/proc/34/cmdline')
+            mock_open.assert_called_once_with('/proc/34/cmdline', 'r')
 
 
 class TestDaemon(base.BaseTestCase):
     def setUp(self):
-        super().setUp()
+        super(TestDaemon, self).setUp()
         self.os_p = mock.patch.object(daemon, 'os')
         self.os = self.os_p.start()
 
@@ -242,18 +223,13 @@ class TestDaemon(base.BaseTestCase):
 
     def test_init(self):
         d = daemon.Daemon('pidfile')
-        self.assertEqual(d.procname, sys.executable)
-
-    def test_init_nopidfile(self):
-        d = daemon.Daemon(pidfile=None)
-        self.assertEqual(d.procname, sys.executable)
-        self.assertFalse(self.pidfile.called)
+        self.assertEqual(d.procname, 'python')
 
     def test_fork_parent(self):
         self.os.fork.return_value = 1
-        d = daemon.Daemon('pidfile')
-        d._fork()
-        self.os._exit.assert_called_once_with(mock.ANY)
+        with testtools.ExpectedException(SystemExit):
+            d = daemon.Daemon('pidfile')
+            d._fork()
 
     def test_fork_child(self):
         self.os.fork.return_value = 0
@@ -261,15 +237,13 @@ class TestDaemon(base.BaseTestCase):
         self.assertIsNone(d._fork())
 
     def test_fork_error(self):
-        self.os.fork.side_effect = OSError(1)
+        self.os.fork.side_effect = lambda: OSError(1)
         with mock.patch.object(daemon.sys, 'stderr'):
             with testtools.ExpectedException(SystemExit):
                 d = daemon.Daemon('pidfile', 'stdin')
                 d._fork()
 
     def test_daemonize(self):
-        self.os.devnull = '/dev/null'
-
         d = daemon.Daemon('pidfile')
         with mock.patch.object(d, '_fork') as fork:
             with mock.patch.object(daemon, 'atexit') as atexit:
