@@ -26,10 +26,8 @@ class TestL2populationRpcCallBackTunnelMixin(
     l2population_rpc_base.TestL2populationRpcCallBackTunnelMixinBase):
 
     def test_get_agent_ports_no_data(self):
-        for lvm, agent_ports in self.fakeagent.get_agent_ports(
-            self.fdb_entries1, {}):
-            self.assertIsNone(lvm)
-            self.assertEqual({}, agent_ports)
+        self.assertFalse(
+            list(self.fakeagent.get_agent_ports(self.fdb_entries1, {})))
 
     def test_get_agent_ports_non_existence_key_in_lvm(self):
         results = {}
@@ -39,10 +37,10 @@ class TestL2populationRpcCallBackTunnelMixin(
             results[lvm] = agent_ports
         expected = {
             self.lvm1: {
-                self.ports[0].ip: [[self.lvms[0].mac, self.lvms[0].ip]],
+                self.ports[0].ip: [(self.lvms[0].mac, self.lvms[0].ip)],
                 self.local_ip: []},
             self.lvm3: {
-                self.ports[2].ip: [[self.lvms[2].mac, self.lvms[2].ip]],
+                self.ports[2].ip: [(self.lvms[2].mac, self.lvms[2].ip)],
                 self.local_ip: []},
         }
         self.assertEqual(expected, results)
@@ -55,11 +53,11 @@ class TestL2populationRpcCallBackTunnelMixin(
             results[lvm] = agent_ports
         expected = {
             self.lvm1: {
-                self.ports[0].ip: [[self.lvms[0].mac, self.lvms[0].ip]],
+                self.ports[0].ip: [(self.lvms[0].mac, self.lvms[0].ip)],
                 self.local_ip: []},
             self.lvm2: {},
             self.lvm3: {
-                self.ports[2].ip: [[self.lvms[2].mac, self.lvms[2].ip]],
+                self.ports[2].ip: [(self.lvms[2].mac, self.lvms[2].ip)],
                 self.local_ip: []},
         }
         self.assertEqual(expected, results)
@@ -70,13 +68,14 @@ class TestL2populationRpcCallBackTunnelMixin(
             mock.patch.object(self.fakeagent, 'add_fdb_flow'),
         ) as (mock_setup_tunnel_port, mock_add_fdb_flow):
             self.fakeagent.fdb_add_tun('context', self.fakebr, self.lvm1,
-                                       self.agent_ports, self.ofports)
+                                       self.agent_ports,
+                                       self._tunnel_port_lookup)
         expected = [
-            mock.call(self.fakebr, [self.lvms[0].mac, self.lvms[0].ip],
+            mock.call(self.fakebr, (self.lvms[0].mac, self.lvms[0].ip),
                       self.ports[0].ip, self.lvm1, self.ports[0].ofport),
-            mock.call(self.fakebr, [self.lvms[1].mac, self.lvms[1].ip],
+            mock.call(self.fakebr, (self.lvms[1].mac, self.lvms[1].ip),
                       self.ports[1].ip, self.lvm1, self.ports[1].ofport),
-            mock.call(self.fakebr, [self.lvms[2].mac, self.lvms[2].ip],
+            mock.call(self.fakebr, (self.lvms[2].mac, self.lvms[2].ip),
                       self.ports[2].ip, self.lvm1, self.ports[2].ofport),
         ]
         self.assertEqual(sorted(expected),
@@ -91,15 +90,16 @@ class TestL2populationRpcCallBackTunnelMixin(
             mock.patch.object(self.fakeagent, 'add_fdb_flow'),
         ) as (mock_setup_tunnel_port, mock_add_fdb_flow):
             self.fakeagent.fdb_add_tun('context', self.fakebr, self.lvm1,
-                                       self.agent_ports, self.ofports)
+                                       self.agent_ports,
+                                       self._tunnel_port_lookup)
         mock_setup_tunnel_port.assert_called_once_with(
             self.fakebr, self.ports[1].ip, self.lvm1.network_type)
         expected = [
-            mock.call(self.fakebr, [self.lvms[0].mac, self.lvms[0].ip],
+            mock.call(self.fakebr, (self.lvms[0].mac, self.lvms[0].ip),
                       self.ports[0].ip, self.lvm1, self.ports[0].ofport),
-            mock.call(self.fakebr, [self.lvms[1].mac, self.lvms[1].ip],
+            mock.call(self.fakebr, (self.lvms[1].mac, self.lvms[1].ip),
                       self.ports[1].ip, self.lvm1, ofport),
-            mock.call(self.fakebr, [self.lvms[2].mac, self.lvms[2].ip],
+            mock.call(self.fakebr, (self.lvms[2].mac, self.lvms[2].ip),
                       self.ports[2].ip, self.lvm1, self.ports[2].ofport),
         ]
         self.assertEqual(sorted(expected),
@@ -113,13 +113,14 @@ class TestL2populationRpcCallBackTunnelMixin(
             mock.patch.object(self.fakeagent, 'add_fdb_flow'),
         ) as (mock_setup_tunnel_port, mock_add_fdb_flow):
             self.fakeagent.fdb_add_tun('context', self.fakebr, self.lvm1,
-                                       self.agent_ports, self.ofports)
+                                       self.agent_ports,
+                                       self._tunnel_port_lookup)
         mock_setup_tunnel_port.assert_called_once_with(
             self.fakebr, self.ports[1].ip, self.lvm1.network_type)
         expected = [
-            mock.call(self.fakebr, [self.lvms[0].mac, self.lvms[0].ip],
+            mock.call(self.fakebr, (self.lvms[0].mac, self.lvms[0].ip),
                       self.ports[0].ip, self.lvm1, self.ports[0].ofport),
-            mock.call(self.fakebr, [self.lvms[2].mac, self.lvms[2].ip],
+            mock.call(self.fakebr, (self.lvms[2].mac, self.lvms[2].ip),
                       self.ports[2].ip, self.lvm1, self.ports[2].ofport),
         ]
         self.assertEqual(sorted(expected),
@@ -129,13 +130,14 @@ class TestL2populationRpcCallBackTunnelMixin(
         with mock.patch.object(
             self.fakeagent, 'del_fdb_flow') as mock_del_fdb_flow:
             self.fakeagent.fdb_remove_tun('context', self.fakebr, self.lvm1,
-                                          self.agent_ports, self.ofports)
+                                          self.agent_ports,
+                                          self._tunnel_port_lookup)
         expected = [
-            mock.call(self.fakebr, [self.lvms[0].mac, self.lvms[0].ip],
+            mock.call(self.fakebr, (self.lvms[0].mac, self.lvms[0].ip),
                       self.ports[0].ip, self.lvm1, self.ports[0].ofport),
-            mock.call(self.fakebr, [self.lvms[1].mac, self.lvms[1].ip],
+            mock.call(self.fakebr, (self.lvms[1].mac, self.lvms[1].ip),
                       self.ports[1].ip, self.lvm1, self.ports[1].ofport),
-            mock.call(self.fakebr, [self.lvms[2].mac, self.lvms[2].ip],
+            mock.call(self.fakebr, (self.lvms[2].mac, self.lvms[2].ip),
                       self.ports[2].ip, self.lvm1, self.ports[2].ofport),
         ]
         self.assertEqual(sorted(expected),
@@ -148,14 +150,15 @@ class TestL2populationRpcCallBackTunnelMixin(
             mock.patch.object(self.fakeagent, 'cleanup_tunnel_port'),
         ) as (mock_del_fdb_flow, mock_cleanup_tunnel_port):
             self.fakeagent.fdb_remove_tun('context', self.fakebr, self.lvm1,
-                                          self.agent_ports, self.ofports)
+                                          self.agent_ports,
+                                          self._tunnel_port_lookup)
         expected = [
-            mock.call(self.fakebr, [self.lvms[0].mac, self.lvms[0].ip],
+            mock.call(self.fakebr, (self.lvms[0].mac, self.lvms[0].ip),
                       self.ports[0].ip, self.lvm1, self.ports[0].ofport),
             mock.call(self.fakebr,
-                      [n_const.FLOODING_ENTRY[0], n_const.FLOODING_ENTRY[1]],
+                      (n_const.FLOODING_ENTRY[0], n_const.FLOODING_ENTRY[1]),
                       self.ports[1].ip, self.lvm1, self.ports[1].ofport),
-            mock.call(self.fakebr, [self.lvms[2].mac, self.lvms[2].ip],
+            mock.call(self.fakebr, (self.lvms[2].mac, self.lvms[2].ip),
                       self.ports[2].ip, self.lvm1, self.ports[2].ofport),
         ]
         self.assertEqual(sorted(expected),
@@ -168,11 +171,12 @@ class TestL2populationRpcCallBackTunnelMixin(
         with mock.patch.object(
             self.fakeagent, 'del_fdb_flow') as mock_del_fdb_flow:
             self.fakeagent.fdb_remove_tun('context', self.fakebr, self.lvm1,
-                                          self.agent_ports, self.ofports)
+                                          self.agent_ports,
+                                          self._tunnel_port_lookup)
         expected = [
-            mock.call(self.fakebr, [self.lvms[0].mac, self.lvms[0].ip],
+            mock.call(self.fakebr, (self.lvms[0].mac, self.lvms[0].ip),
                       self.ports[0].ip, self.lvm1, self.ports[0].ofport),
-            mock.call(self.fakebr, [self.lvms[2].mac, self.lvms[2].ip],
+            mock.call(self.fakebr, (self.lvms[2].mac, self.lvms[2].ip),
                       self.ports[2].ip, self.lvm1, self.ports[2].ofport),
         ]
         self.assertEqual(sorted(expected),
@@ -223,8 +227,8 @@ class TestL2populationRpcCallBackTunnelMixin(
         upd_fdb_entry_val = {
             self.lvms[0].net: {
                 self.local_ip: {
-                    'before': [[self.lvms[0].mac, self.lvms[0].ip]],
-                    'after': [[self.lvms[1].mac, self.lvms[1].ip]],
+                    'before': [(self.lvms[0].mac, self.lvms[0].ip)],
+                    'after': [(self.lvms[1].mac, self.lvms[1].ip)],
                 },
             },
         }
@@ -234,3 +238,17 @@ class TestL2populationRpcCallBackTunnelMixin(
                                       upd_fdb_entry_val, self.local_ip,
                                       self.local_vlan_map1)
         self.assertFalse(m_setup_entry_for_arp_reply.call_count)
+
+    def test_fdb_chg_ip_tun_empty_before_after(self):
+        upd_fdb_entry_val = {
+            self.lvms[0].net: {
+                self.local_ip: {},
+            },
+        }
+        m_setup_entry_for_arp_reply = mock.Mock()
+        self.fakeagent.setup_entry_for_arp_reply = m_setup_entry_for_arp_reply
+        # passing non-local ip
+        self.fakeagent.fdb_chg_ip_tun('context', self.fakebr,
+                                      upd_fdb_entry_val, "8.8.8.8",
+                                      self.local_vlan_map1)
+        self.assertFalse(m_setup_entry_for_arp_reply.call_count)
