@@ -13,28 +13,32 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from neutron_lib.api.definitions import external_net as enet_apidef
-from neutron_lib.api.definitions import extraroute as xroute_apidef
-from neutron_lib.api.definitions import l3 as l3_apidef
-from neutron_lib import constants
-from neutron_lib.utils import helpers
+import contextlib
+
 from oslo_config import cfg
-from oslo_utils import uuidutils
+from oslo_log import log as logging
 from webob import exc
 
+from neutron.common import constants
 from neutron.db import extraroute_db
+from neutron.extensions import extraroute
 from neutron.extensions import l3
+from neutron.openstack.common import uuidutils
 from neutron.tests.unit.api.v2 import test_base
-from neutron.tests.unit.extensions import test_l3
+from neutron.tests.unit.extensions import test_l3 as test_l3
 
 
+LOG = logging.getLogger(__name__)
+
 _uuid = uuidutils.generate_uuid
 _get_path = test_base._get_path
 
 
-class ExtraRouteTestExtensionManager:
+class ExtraRouteTestExtensionManager(object):
 
     def get_resources(self):
+        l3.RESOURCE_ATTRIBUTE_MAP['routers'].update(
+            extraroute.EXTENDED_ATTRIBUTES_2_0['routers'])
         return l3.L3.get_resources()
 
     def get_actions(self):
@@ -47,29 +51,23 @@ class ExtraRouteTestExtensionManager:
 # This plugin class is for tests with plugin that integrates L3.
 class TestExtraRouteIntPlugin(test_l3.TestL3NatIntPlugin,
                               extraroute_db.ExtraRoute_db_mixin):
-    supported_extension_aliases = [enet_apidef.ALIAS, l3_apidef.ALIAS,
-                                   xroute_apidef.ALIAS]
+    supported_extension_aliases = ["external-net", "router", "extraroute"]
 
 
 # A fake l3 service plugin class with extra route capability for
 # plugins that delegate away L3 routing functionality
 class TestExtraRouteL3NatServicePlugin(test_l3.TestL3NatServicePlugin,
                                        extraroute_db.ExtraRoute_db_mixin):
-    supported_extension_aliases = [l3_apidef.ALIAS, xroute_apidef.ALIAS]
+    supported_extension_aliases = ["router", "extraroute"]
 
 
-class ExtraRouteDBTestCaseBase:
-    def _routes_update_prepare(
-            self, router_id, subnet_id,
-            port_id, routes, skip_add=False, tenant_id=None, as_admin=False):
+class ExtraRouteDBTestCaseBase(object):
+    def _routes_update_prepare(self, router_id, subnet_id,
+                               port_id, routes, skip_add=False):
         if not skip_add:
-            self._router_interface_action(
-                'add', router_id, subnet_id, port_id, tenant_id=tenant_id,
-                as_admin=as_admin)
-        tenant_id = tenant_id or self._tenant_id
-        self._update('routers', router_id, {'router': {'routes': routes}},
-                     request_tenant_id=tenant_id, as_admin=as_admin)
-        return self._show('routers', router_id, tenant_id=tenant_id)
+            self._router_interface_action('add', router_id, subnet_id, port_id)
+        self._update('routers', router_id, {'router': {'routes': routes}})
+        return self._show('routers', router_id)
 
     def _routes_update_cleanup(self, port_id, subnet_id, router_id, routes):
         self._update('routers', router_id, {'router': {'routes': routes}})
@@ -79,45 +77,14 @@ class ExtraRouteDBTestCaseBase:
         routes = [{'destination': '135.207.0.0/16', 'nexthop': '10.0.1.3'}]
         with self.router() as r:
             with self.subnet(cidr='10.0.1.0/24') as s:
-                fixed_ip_data = [{'ip_address': '10.0.1.2'}]
-                with self.port(subnet=s, fixed_ips=fixed_ip_data) as p:
+                with self.port(subnet=s) as p:
                     body = self._routes_update_prepare(r['router']['id'],
                                                        None, p['port']['id'],
                                                        routes)
-                    self.assertEqual(routes, body['router']['routes'])
+                    self.assertEqual(body['router']['routes'], routes)
                     self._routes_update_cleanup(p['port']['id'],
                                                 None, r['router']['id'], [])
 
-    def test_route_update_with_external_route(self):
-        my_tenant = 'tenant1'
-        with self.subnet(cidr='10.0.1.0/24', tenant_id='notme') as ext_subnet,\
-                self.port(subnet=ext_subnet,
-                          tenant_id='notme') as nexthop_port:
-            nexthop_ip = nexthop_port['port']['fixed_ips'][0]['ip_address']
-            routes = [{'destination': '135.207.0.0/16',
-                       'nexthop': nexthop_ip}]
-            self._set_net_external(ext_subnet['subnet']['network_id'])
-            ext_info = {'network_id': ext_subnet['subnet']['network_id']}
-            with self.router(
-                    external_gateway_info=ext_info, tenant_id=my_tenant) as r:
-                body = self._routes_update_prepare(
-                    r['router']['id'], None, None, routes, skip_add=True,
-                    tenant_id=my_tenant)
-                self.assertEqual(routes, body['router']['routes'])
-
-    def test_route_update_with_route_via_another_tenant_subnet(self):
-        my_tenant = 'tenant1'
-        with self.subnet(cidr='10.0.1.0/24', tenant_id='notme') as subnet,\
-                self.port(subnet=subnet, tenant_id='notme') as nexthop_port:
-            nexthop_ip = nexthop_port['port']['fixed_ips'][0]['ip_address']
-            routes = [{'destination': '135.207.0.0/16',
-                       'nexthop': nexthop_ip}]
-            with self.router(tenant_id=my_tenant) as r:
-                body = self._routes_update_prepare(
-                    r['router']['id'], subnet['subnet']['id'], None, routes,
-                    tenant_id=my_tenant, as_admin=True)
-                self.assertEqual(routes, body['router']['routes'])
-
     def test_route_clear_routes_with_None(self):
         routes = [{'destination': '135.207.0.0/16',
                    'nexthop': '10.0.1.3'},
@@ -127,13 +94,12 @@ class ExtraRouteDBTestCaseBase:
                    'nexthop': '10.0.1.5'}]
         with self.router() as r:
             with self.subnet(cidr='10.0.1.0/24') as s:
-                fixed_ip_data = [{'ip_address': '10.0.1.2'}]
-                with self.port(subnet=s, fixed_ips=fixed_ip_data) as p:
+                with self.port(subnet=s) as p:
                     self._routes_update_prepare(r['router']['id'],
                                                 None, p['port']['id'], routes)
                     body = self._update('routers', r['router']['id'],
                                         {'router': {'routes': None}})
-                    self.assertEqual([], body['router']['routes'])
+                    self.assertEqual(body['router']['routes'], [])
                     self._routes_update_cleanup(p['port']['id'],
                                                 None, r['router']['id'], [])
 
@@ -142,12 +108,11 @@ class ExtraRouteDBTestCaseBase:
                    'nexthop': '10.0.1.3'}]
         with self.router() as r:
             with self.subnet(cidr='10.0.1.0/24') as s:
-                fixed_ip_data = [{'ip_address': '10.0.1.2'}]
-                with self.port(subnet=s, fixed_ips=fixed_ip_data) as p:
+                with self.port(subnet=s) as p:
                     body = self._routes_update_prepare(r['router']['id'],
                                                        None, p['port']['id'],
                                                        routes)
-                    self.assertEqual(routes, body['router']['routes'])
+                    self.assertEqual(body['router']['routes'], routes)
                     self._router_interface_action(
                         'remove',
                         r['router']['id'],
@@ -167,39 +132,36 @@ class ExtraRouteDBTestCaseBase:
                    'nexthop': '10.0.1.5'}]
         with self.router() as r:
             with self.subnet(cidr='10.0.1.0/24') as s:
-                fixed_ip_data = [{'ip_address': '10.0.1.2'}]
-                with self.port(subnet=s, fixed_ips=fixed_ip_data) as p:
+                with self.port(subnet=s) as p:
                     body = self._routes_update_prepare(r['router']['id'],
                                                        None, p['port']['id'],
                                                        routes)
-                    self.assertEqual(
-                        sorted(body['router']['routes'],
-                               key=helpers.safe_sort_key),
-                        sorted(routes, key=helpers.safe_sort_key))
+                    self.assertEqual(sorted(body['router']['routes']),
+                                     sorted(routes))
                     self._routes_update_cleanup(p['port']['id'],
                                                 None, r['router']['id'], [])
 
     def test_routes_update_for_multiple_routers(self):
-        with self.router() as r1,\
-                self.router() as r2,\
-                self.subnet(cidr='10.0.0.0/24') as s:
-            with self.port(subnet=s) as p1,\
-                    self.port(subnet=s) as p2:
-                p1_ip = p1['port']['fixed_ips'][0]['ip_address']
-                p2_ip = p2['port']['fixed_ips'][0]['ip_address']
-                routes1 = [{'destination': '135.207.0.0/16',
-                            'nexthop': p2_ip}]
-                routes2 = [{'destination': '12.0.0.0/8',
-                            'nexthop': p1_ip}]
+        routes1 = [{'destination': '135.207.0.0/16',
+                   'nexthop': '10.0.0.3'}]
+        routes2 = [{'destination': '12.0.0.0/8',
+                   'nexthop': '10.0.0.4'}]
+        with contextlib.nested(
+                self.router(),
+                self.router(),
+                self.subnet(cidr='10.0.0.0/24')) as (r1, r2, s):
+            with contextlib.nested(
+                    self.port(subnet=s),
+                    self.port(subnet=s)) as (p1, p2):
                 body = self._routes_update_prepare(r1['router']['id'],
                                                    None, p1['port']['id'],
                                                    routes1)
-                self.assertEqual(routes1, body['router']['routes'])
+                self.assertEqual(body['router']['routes'], routes1)
 
                 body = self._routes_update_prepare(r2['router']['id'],
                                                    None, p2['port']['id'],
                                                    routes2)
-                self.assertEqual(routes2, body['router']['routes'])
+                self.assertEqual(body['router']['routes'], routes2)
 
                 self._routes_update_cleanup(p1['port']['id'],
                                             None, r1['router']['id'], [])
@@ -219,23 +181,18 @@ class ExtraRouteDBTestCaseBase:
                         'nexthop': '10.0.1.5'}]
         with self.router() as r:
             with self.subnet(cidr='10.0.1.0/24') as s:
-                fixed_ip_data = [{'ip_address': '10.0.1.2'}]
-                with self.port(subnet=s, fixed_ips=fixed_ip_data) as p:
+                with self.port(subnet=s) as p:
                     body = self._routes_update_prepare(r['router']['id'],
                                                        None, p['port']['id'],
                                                        routes_orig)
-                    self.assertEqual(
-                        sorted(body['router']['routes'],
-                               key=helpers.safe_sort_key),
-                        sorted(routes_orig, key=helpers.safe_sort_key))
+                    self.assertEqual(sorted(body['router']['routes']),
+                                     sorted(routes_orig))
                     body = self._routes_update_prepare(r['router']['id'],
                                                        None, p['port']['id'],
                                                        routes_left,
                                                        skip_add=True)
-                    self.assertEqual(
-                        sorted(body['router']['routes'],
-                               key=helpers.safe_sort_key),
-                        sorted(routes_left, key=helpers.safe_sort_key))
+                    self.assertEqual(sorted(body['router']['routes']),
+                                     sorted(routes_left))
                     self._routes_update_cleanup(p['port']['id'],
                                                 None, r['router']['id'], [])
 
@@ -380,14 +337,6 @@ class ExtraRouteDBTestCaseBase:
                                              routes}},
                                  expected_code=exc.HTTPBadRequest.code)
 
-                    routes = [{'destination': '1.1.1.1/24',
-                               'nexthop': '10.0.1.3'}]
-
-                    self._update('routers', r['router']['id'],
-                                 {'router': {'routes':
-                                             routes}},
-                                 expected_code=exc.HTTPBadRequest.code)
-
                     # clean-up
                     self._router_interface_action('remove',
                                                   r['router']['id'],
@@ -457,45 +406,48 @@ class ExtraRouteDBTestCaseBase:
                     tenant_id=r['router']['tenant_id'],
                     device_owner=constants.DEVICE_OWNER_ROUTER_GW)
                 port_list = self.deserialize('json', port_res)
-                self.assertEqual(1, len(port_list['ports']))
+                self.assertEqual(len(port_list['ports']), 1)
 
-                with self.port(subnet=s) as p:
-                    next_hop = p['port']['fixed_ips'][0]['ip_address']
-                    routes = [{'destination': '135.207.0.0/16',
-                               'nexthop': next_hop}]
-                    body = self._update('routers', r['router']['id'],
-                                        {'router': {'routes':
-                                                    routes}})
+                routes = [{'destination': '135.207.0.0/16',
+                           'nexthop': '10.0.1.3'}]
 
-                    body = self._show('routers', r['router']['id'])
-                    self.assertEqual(routes, body['router']['routes'])
+                body = self._update('routers', r['router']['id'],
+                                    {'router': {'routes':
+                                                routes}})
 
-                    self._remove_external_gateway_from_router(
-                        r['router']['id'],
-                        s['subnet']['network_id'])
-                    body = self._show('routers', r['router']['id'])
-                    gw_info = body['router']['external_gateway_info']
-                    self.assertIsNone(gw_info)
+                body = self._show('routers', r['router']['id'])
+                self.assertEqual(body['router']['routes'],
+                                 routes)
+
+                self._remove_external_gateway_from_router(
+                    r['router']['id'],
+                    s['subnet']['network_id'])
+                body = self._show('routers', r['router']['id'])
+                gw_info = body['router']['external_gateway_info']
+                self.assertIsNone(gw_info)
 
     def test_router_list_with_sort(self):
-        with self.router(name='router1') as router1,\
-                self.router(name='router2') as router2,\
-                self.router(name='router3') as router3:
+        with contextlib.nested(self.router(name='router1'),
+                               self.router(name='router2'),
+                               self.router(name='router3')
+                               ) as (router1, router2, router3):
             self._test_list_with_sort('router', (router3, router2, router1),
                                       [('name', 'desc')])
 
     def test_router_list_with_pagination(self):
-        with self.router(name='router1') as router1,\
-                self.router(name='router2') as router2,\
-                self.router(name='router3') as router3:
+        with contextlib.nested(self.router(name='router1'),
+                               self.router(name='router2'),
+                               self.router(name='router3')
+                               ) as (router1, router2, router3):
             self._test_list_with_pagination('router',
                                             (router1, router2, router3),
                                             ('name', 'asc'), 2, 2)
 
     def test_router_list_with_pagination_reverse(self):
-        with self.router(name='router1') as router1,\
-                self.router(name='router2') as router2,\
-                self.router(name='router3') as router3:
+        with contextlib.nested(self.router(name='router1'),
+                               self.router(name='router2'),
+                               self.router(name='router3')
+                               ) as (router1, router2, router3):
             self._test_list_with_pagination_reverse('router',
                                                     (router1, router2,
                                                      router3),
@@ -509,6 +461,8 @@ class ExtraRouteDBIntTestCase(test_l3.L3NatDBIntTestCase,
         if not plugin:
             plugin = ('neutron.tests.unit.extensions.test_extraroute.'
                       'TestExtraRouteIntPlugin')
+        # for these tests we need to enable overlapping ips
+        cfg.CONF.set_default('allow_overlapping_ips', True)
         cfg.CONF.set_default('max_routes', 3)
         ext_mgr = ExtraRouteTestExtensionManager()
         super(test_l3.L3BaseForIntTests, self).setUp(plugin=plugin,
@@ -526,6 +480,8 @@ class ExtraRouteDBSepTestCase(test_l3.L3NatDBSepTestCase,
                      'TestExtraRouteL3NatServicePlugin')
         service_plugins = {'l3_plugin_name': l3_plugin}
 
+        # for these tests we need to enable overlapping ips
+        cfg.CONF.set_default('allow_overlapping_ips', True)
         cfg.CONF.set_default('max_routes', 3)
         ext_mgr = ExtraRouteTestExtensionManager()
         super(test_l3.L3BaseForSepTests, self).setUp(
