@@ -13,12 +13,9 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-from oslo_config import cfg
-from oslo_config import fixture as config_fixture
-
-from neutron_lib.api.definitions import portbindings
-from neutron_lib.plugins.ml2 import api
 
+from neutron.extensions import portbindings
+from neutron.plugins.ml2 import driver_api as api
 from neutron.tests import base
 
 NETWORK_ID = "fake_network"
@@ -44,28 +41,23 @@ class FakeNetworkContext(api.NetworkContext):
 
 class FakePortContext(api.PortContext):
     def __init__(self, agent_type, agents, segments,
-                 vnic_type=portbindings.VNIC_NORMAL,
-                 original=None, profile=None):
+                 vnic_type=portbindings.VNIC_NORMAL):
         self._agent_type = agent_type
         self._agents = agents
         self._network_context = FakeNetworkContext(segments)
         self._bound_vnic_type = vnic_type
-        self._bound_profile = profile
         self._bound_segment_id = None
         self._bound_vif_type = None
         self._bound_vif_details = None
-        self._original = original
-        self._binding_levels = []
 
     @property
     def current(self):
         return {'id': PORT_ID,
-                portbindings.VNIC_TYPE: self._bound_vnic_type,
-                portbindings.PROFILE: self._bound_profile}
+                'binding:vnic_type': self._bound_vnic_type}
 
     @property
     def original(self):
-        return self._original
+        return None
 
     @property
     def status(self):
@@ -79,24 +71,13 @@ class FakePortContext(api.PortContext):
     def network(self):
         return self._network_context
 
-    def _prepare_to_bind(self, segments_to_bind):
-        self._segments_to_bind = segments_to_bind
-        self._new_bound_segment = None
-        self._next_segments_to_bind = None
-
-    def _push_binding_level(self, binding_level):
-        self._binding_levels.append(binding_level)
-
-    def _pop_binding_level(self):
-        return self._binding_levels.pop()
-
     @property
     def binding_levels(self):
-        if self._binding_levels:
+        if self._bound_segment:
             return [{
-                api.BOUND_DRIVER: level.driver,
-                api.BOUND_SEGMENT: self._expand_segment(level.segment_id)
-            } for level in self._binding_levels]
+                api.BOUND_DRIVER: 'fake_driver',
+                api.BOUND_SEGMENT: self._expand_segment(self._bound_segment)
+            }]
 
     @property
     def original_binding_levels(self):
@@ -104,8 +85,7 @@ class FakePortContext(api.PortContext):
 
     @property
     def top_bound_segment(self):
-        if self._binding_levels:
-            return self._expand_segment(self._binding_levels[0].segment_id)
+        return self._expand_segment(self._bound_segment)
 
     @property
     def original_top_bound_segment(self):
@@ -113,8 +93,7 @@ class FakePortContext(api.PortContext):
 
     @property
     def bottom_bound_segment(self):
-        if self._binding_levels:
-            return self._expand_segment(self._binding_levels[-1].segment_id)
+        return self._expand_segment(self._bound_segment)
 
     @property
     def original_bottom_bound_segment(self):
@@ -133,22 +112,6 @@ class FakePortContext(api.PortContext):
     def original_host(self):
         return None
 
-    @property
-    def vif_type(self):
-        return portbindings.UNBOUND
-
-    @property
-    def original_vif_type(self):
-        return portbindings.UNBOUND
-
-    @property
-    def vif_details(self):
-        return None
-
-    @property
-    def original_vif_details(self):
-        return None
-
     @property
     def segments_to_bind(self):
         return self._network_context.network_segments
@@ -174,31 +137,6 @@ class FakePortContext(api.PortContext):
         pass
 
 
-class MechDriverConfFixture(config_fixture.Config):
-
-    def __init__(self, conf=cfg.CONF, blacklist_cfg=None,
-                 registration_func=None):
-        """ConfigFixture for vnic_type_blacklist
-
-        :param conf: The driver configuration object
-        :param blacklist_cfg: A dictionary in the form
-                              {'group': {'opt': 'value'}}, i.e.:
-                              {'OVS_DRIVER': {'vnic_type_blacklist':
-                                              ['foo']}}
-        :param registration_func: The method which do the config group's
-                                  registration.
-        """
-        super(MechDriverConfFixture, self).__init__(conf)
-        self.blacklist_cfg = blacklist_cfg
-        self.registration_func = registration_func
-
-    def setUp(self):
-        super(MechDriverConfFixture, self).setUp()
-        self.registration_func(self.conf)
-        for group, option in self.blacklist_cfg.items():
-            self.config(group=group, **option)
-
-
 class AgentMechanismBaseTestCase(base.BaseTestCase):
     # The following must be overridden for the specific mechanism
     # driver being tested:
@@ -208,7 +146,6 @@ class AgentMechanismBaseTestCase(base.BaseTestCase):
     AGENTS = None
     AGENTS_DEAD = None
     AGENTS_BAD = None
-    VNIC_TYPE = portbindings.VNIC_NORMAL
 
     def _check_unbound(self, context):
         self.assertIsNone(context._bound_segment_id)
@@ -235,120 +172,88 @@ class AgentMechanismBaseTestCase(base.BaseTestCase):
 
 class AgentMechanismGenericTestCase(AgentMechanismBaseTestCase):
     UNKNOWN_TYPE_SEGMENTS = [{api.ID: 'unknown_segment_id',
-                              api.NETWORK_TYPE: 'no_such_type',
-                              api.NETWORK_ID: 'fake_network_id'}]
+                              api.NETWORK_TYPE: 'no_such_type'}]
 
     def test_unknown_type(self):
         context = FakePortContext(self.AGENT_TYPE,
                                   self.AGENTS,
-                                  self.UNKNOWN_TYPE_SEGMENTS,
-                                  vnic_type=self.VNIC_TYPE)
+                                  self.UNKNOWN_TYPE_SEGMENTS)
         self.driver.bind_port(context)
         self._check_unbound(context)
 
-    def test_driver_not_responsible_for_ports_allocation(self):
-        agents = [
-            {'configurations': {'rp_bandwidths': {'eth0': {}}},
-             'host': 'host'},
-        ]
-        profile = {}
-        segments = []
-        port_ctx = FakePortContext(
-            self.AGENT_TYPE,
-            agents,
-            segments,
-            vnic_type=portbindings.VNIC_DIRECT,
-            profile=profile)
-        self.assertFalse(
-            self.driver.responsible_for_ports_allocation(port_ctx))
-
 
 class AgentMechanismLocalTestCase(AgentMechanismBaseTestCase):
     LOCAL_SEGMENTS = [{api.ID: 'unknown_segment_id',
-                       api.NETWORK_TYPE: 'no_such_type',
-                       api.NETWORK_ID: 'fake_network_id'},
+                       api.NETWORK_TYPE: 'no_such_type'},
                       {api.ID: 'local_segment_id',
-                       api.NETWORK_TYPE: 'local',
-                       api.NETWORK_ID: 'fake_network_id'}]
+                       api.NETWORK_TYPE: 'local'}]
 
     def test_type_local(self):
         context = FakePortContext(self.AGENT_TYPE,
                                   self.AGENTS,
-                                  self.LOCAL_SEGMENTS,
-                                  vnic_type=self.VNIC_TYPE)
+                                  self.LOCAL_SEGMENTS)
         self.driver.bind_port(context)
         self._check_bound(context, self.LOCAL_SEGMENTS[1])
 
     def test_type_local_dead(self):
         context = FakePortContext(self.AGENT_TYPE,
                                   self.AGENTS_DEAD,
-                                  self.LOCAL_SEGMENTS,
-                                  vnic_type=self.VNIC_TYPE)
+                                  self.LOCAL_SEGMENTS)
         self.driver.bind_port(context)
         self._check_unbound(context)
 
 
 class AgentMechanismFlatTestCase(AgentMechanismBaseTestCase):
     FLAT_SEGMENTS = [{api.ID: 'unknown_segment_id',
-                      api.NETWORK_TYPE: 'no_such_type',
-                      api.NETWORK_ID: 'fake_network_id'},
+                      api.NETWORK_TYPE: 'no_such_type'},
                      {api.ID: 'flat_segment_id',
                       api.NETWORK_TYPE: 'flat',
-                      api.PHYSICAL_NETWORK: 'fake_physical_network',
-                      api.NETWORK_ID: 'fake_network_id'}]
+                      api.PHYSICAL_NETWORK: 'fake_physical_network'}]
 
     def test_type_flat(self):
         context = FakePortContext(self.AGENT_TYPE,
                                   self.AGENTS,
-                                  self.FLAT_SEGMENTS,
-                                  vnic_type=self.VNIC_TYPE)
+                                  self.FLAT_SEGMENTS)
         self.driver.bind_port(context)
         self._check_bound(context, self.FLAT_SEGMENTS[1])
 
     def test_type_flat_bad(self):
         context = FakePortContext(self.AGENT_TYPE,
                                   self.AGENTS_BAD,
-                                  self.FLAT_SEGMENTS,
-                                  vnic_type=self.VNIC_TYPE)
+                                  self.FLAT_SEGMENTS)
         self.driver.bind_port(context)
         self._check_unbound(context)
 
 
 class AgentMechanismVlanTestCase(AgentMechanismBaseTestCase):
     VLAN_SEGMENTS = [{api.ID: 'unknown_segment_id',
-                      api.NETWORK_TYPE: 'no_such_type',
-                      api.NETWORK_ID: 'fake_network_id'},
+                      api.NETWORK_TYPE: 'no_such_type'},
                      {api.ID: 'vlan_segment_id',
                       api.NETWORK_TYPE: 'vlan',
                       api.PHYSICAL_NETWORK: 'fake_physical_network',
-                      api.SEGMENTATION_ID: 1234,
-                      api.NETWORK_ID: 'fake_network_id'}]
+                      api.SEGMENTATION_ID: 1234}]
 
     def test_type_vlan(self):
         context = FakePortContext(self.AGENT_TYPE,
                                   self.AGENTS,
-                                  self.VLAN_SEGMENTS,
-                                  vnic_type=self.VNIC_TYPE)
+                                  self.VLAN_SEGMENTS)
         self.driver.bind_port(context)
         self._check_bound(context, self.VLAN_SEGMENTS[1])
 
     def test_type_vlan_bad(self):
         context = FakePortContext(self.AGENT_TYPE,
                                   self.AGENTS_BAD,
-                                  self.VLAN_SEGMENTS,
-                                  vnic_type=self.VNIC_TYPE)
+                                  self.VLAN_SEGMENTS)
         self.driver.bind_port(context)
         self._check_unbound(context)
 
 
 class AgentMechanismGreTestCase(AgentMechanismBaseTestCase):
     GRE_SEGMENTS = [{api.ID: 'unknown_segment_id',
-                     api.NETWORK_TYPE: 'no_such_type',
-                     api.NETWORK_ID: 'fake_network_id'},
+                     api.NETWORK_TYPE: 'no_such_type'},
                     {api.ID: 'gre_segment_id',
                      api.NETWORK_TYPE: 'gre',
-                     api.SEGMENTATION_ID: 1234,
-                     api.NETWORK_ID: 'fake_network_id'}]
+                     api.SEGMENTATION_ID: 1234}]
 
     def test_type_gre(self):
         context = FakePortContext(self.AGENT_TYPE,
