@@ -13,27 +13,14 @@
 #    License for the specific language governing permissions and limitations
 #    under the License.
 
-import uuid
-
-from neutron_lib.api.definitions import portbindings
-from neutron_lib.api.definitions import provider_net as pnet
-from neutron_lib import constants as const
-from neutron_lib.plugins.ml2 import api
-
-from neutron.plugins.ml2.drivers import mech_agent
-
-
-VIF_TYPE_TEST = 'vif_type_test'
+from neutron.common import constants as const
+from neutron.extensions import portbindings
+from neutron.plugins.ml2 import driver_api as api
 
 
 class TestMechanismDriver(api.MechanismDriver):
     """Test mechanism driver for testing mechanism driver api."""
 
-    def __init__(self, *args, **kwargs):
-        super(TestMechanismDriver, self).__init__(*args, **kwargs)
-        self._supported_vnic_types = ('test_mechanism_driver_vnic_type', )
-        self._supported_extensions = set([])
-
     def initialize(self):
         self.bound_ports = set()
 
@@ -46,6 +33,7 @@ class TestMechanismDriver(api.MechanismDriver):
             assert(context.current['id'] == context.original['id'])
         else:
             assert(not context.original)
+        assert(context.network_segments)
 
     def create_network_precommit(self, context):
         self._check_network_context(context, False)
@@ -74,9 +62,6 @@ class TestMechanismDriver(api.MechanismDriver):
             assert(context.current['id'] == context.original['id'])
         else:
             assert(not context.original)
-        network_context = context.network
-        assert(isinstance(network_context, api.NetworkContext))
-        self._check_network_context(network_context, False)
 
     def create_subnet_precommit(self, context):
         self._check_subnet_context(context, False)
@@ -98,15 +83,16 @@ class TestMechanismDriver(api.MechanismDriver):
 
     def _check_port_context(self, context, original_expected):
         assert(isinstance(context, api.PortContext))
+        assert(isinstance(context.current, dict))
+        assert(context.current['id'] is not None)
 
-        self._check_port_info(context.current, context.host,
-                              context.vif_type, context.vif_details,
-                              context.binding_levels)
+        vif_type = context.current.get(portbindings.VIF_TYPE)
+        assert(vif_type is not None)
 
-        if context.vif_type in (portbindings.VIF_TYPE_UNBOUND,
-                                portbindings.VIF_TYPE_BINDING_FAILED):
+        if vif_type in (portbindings.VIF_TYPE_UNBOUND,
+                        portbindings.VIF_TYPE_BINDING_FAILED):
             if (context.segments_to_bind and
-                    context.segments_to_bind[0][api.NETWORK_TYPE] == 'vlan'):
+                context.segments_to_bind[0][api.NETWORK_TYPE] == 'vlan'):
                 # Partially bound.
                 self._check_bound(context.binding_levels,
                                   context.top_bound_segment,
@@ -115,25 +101,20 @@ class TestMechanismDriver(api.MechanismDriver):
                 self._check_unbound(context.binding_levels,
                                     context.top_bound_segment,
                                     context.bottom_bound_segment)
-            assert((context.current['id'], context.host)
-                   not in self.bound_ports)
+            assert(context.current['id'] not in self.bound_ports)
         else:
             self._check_bound(context.binding_levels,
                               context.top_bound_segment,
                               context.bottom_bound_segment)
-            assert((context.current['id'], context.host) in self.bound_ports)
+            assert(context.current['id'] in self.bound_ports)
 
         if original_expected:
-            self._check_port_info(context.original, context.original_host,
-                                  context.original_vif_type,
-                                  context.original_vif_details,
-                                  context.binding_levels)
-
+            assert(isinstance(context.original, dict))
             assert(context.current['id'] == context.original['id'])
-
-            if (context.original_vif_type in
-                (portbindings.VIF_TYPE_UNBOUND,
-                 portbindings.VIF_TYPE_BINDING_FAILED)):
+            vif_type = context.original.get(portbindings.VIF_TYPE)
+            assert(vif_type is not None)
+            if vif_type in (portbindings.VIF_TYPE_UNBOUND,
+                            portbindings.VIF_TYPE_BINDING_FAILED):
                 self._check_unbound(context.original_binding_levels,
                                     context.original_top_bound_segment,
                                     context.original_bottom_bound_segment)
@@ -143,10 +124,6 @@ class TestMechanismDriver(api.MechanismDriver):
                                   context.original_bottom_bound_segment)
         else:
             assert(context.original is None)
-            assert(context.original_host is None)
-            assert(context.original_vif_type is None)
-            assert(context.original_vif_details is None)
-            assert(context.original_status is None)
             self._check_unbound(context.original_binding_levels,
                                 context.original_top_bound_segment,
                                 context.original_bottom_bound_segment)
@@ -155,35 +132,6 @@ class TestMechanismDriver(api.MechanismDriver):
         assert(isinstance(network_context, api.NetworkContext))
         self._check_network_context(network_context, False)
 
-    def _check_port_info(self, port, host, vif_type, vif_details,
-                         binding_levels):
-        assert(isinstance(port, dict))
-        assert(port['id'] is not None)
-        assert(vif_type in (portbindings.VIF_TYPE_UNBOUND,
-                            portbindings.VIF_TYPE_BINDING_FAILED,
-                            portbindings.VIF_TYPE_DISTRIBUTED,
-                            portbindings.VIF_TYPE_OVS,
-                            portbindings.VIF_TYPE_BRIDGE))
-        bound_drivers = port[portbindings.VIF_DETAILS].pop(
-            portbindings.VIF_DETAILS_BOUND_DRIVERS, None)
-        if port['device_owner'] == const.DEVICE_OWNER_DVR_INTERFACE:
-            assert(port[portbindings.HOST_ID] == '')
-            assert(port[portbindings.VIF_TYPE] ==
-                   portbindings.VIF_TYPE_DISTRIBUTED)
-            assert(port[portbindings.VIF_DETAILS] == {})
-        else:
-            assert(port[portbindings.HOST_ID] == host)
-            assert(port[portbindings.VIF_TYPE] !=
-                   portbindings.VIF_TYPE_DISTRIBUTED)
-            assert(port[portbindings.VIF_TYPE] == vif_type)
-            assert(isinstance(vif_details, dict))
-
-            assert(port[portbindings.VIF_DETAILS] == vif_details)
-        if bound_drivers and binding_levels:
-            bd_reference = {str(idx): bl['bound_driver'] for
-                            idx, bl in enumerate(binding_levels)}
-            assert(bd_reference == bound_drivers)
-
     def _check_unbound(self, levels, top_segment, bottom_segment):
         assert(levels is None)
         assert(top_segment is None)
@@ -209,11 +157,9 @@ class TestMechanismDriver(api.MechanismDriver):
         self._check_port_context(context, False)
 
     def update_port_precommit(self, context):
-        if ((context.original_top_bound_segment and
-             not context.top_bound_segment) or
-                (context.host == "host-fail")):
-            self.bound_ports.remove((context.original['id'],
-                                     context.original_host))
+        if (context.original_top_bound_segment and
+            not context.top_bound_segment):
+            self.bound_ports.remove(context.original['id'])
         self._check_port_context(context, True)
 
     def update_port_postcommit(self, context):
@@ -234,16 +180,16 @@ class TestMechanismDriver(api.MechanismDriver):
         if host == "host-ovs-no_filter":
             context.set_binding(segment_id, portbindings.VIF_TYPE_OVS,
                                 {portbindings.CAP_PORT_FILTER: False})
-            self.bound_ports.add((context.current['id'], host))
+            self.bound_ports.add(context.current['id'])
         elif host == "host-bridge-filter":
             context.set_binding(segment_id, portbindings.VIF_TYPE_BRIDGE,
                                 {portbindings.CAP_PORT_FILTER: True})
-            self.bound_ports.add((context.current['id'], host))
+            self.bound_ports.add(context.current['id'])
         elif host == "host-ovs-filter-active":
             context.set_binding(segment_id, portbindings.VIF_TYPE_OVS,
                                 {portbindings.CAP_PORT_FILTER: True},
                                 status=const.PORT_STATUS_ACTIVE)
-            self.bound_ports.add((context.current['id'], host))
+            self.bound_ports.add(context.current['id'])
         elif host == "host-hierarchical":
             segment_type = segment[api.NETWORK_TYPE]
             if segment_type == 'local':
@@ -256,65 +202,4 @@ class TestMechanismDriver(api.MechanismDriver):
                 context.set_binding(segment_id,
                                     portbindings.VIF_TYPE_OVS,
                                     {portbindings.CAP_PORT_FILTER: False})
-                self.bound_ports.add((context.current['id'], host))
-        elif host == "host-fail":
-            context.set_binding(None,
-                                portbindings.VIF_TYPE_BINDING_FAILED,
-                                {portbindings.CAP_PORT_FILTER: False})
-            self.bound_ports.add((context.current['id'], host))
-
-    def filter_hosts_with_segment_access(
-            self, context, segments, candidate_hosts, agent_getter):
-        return set()
-
-    @property
-    def resource_provider_uuid5_namespace(self):
-        return uuid.UUID('7f0ce65c-1f13-11e9-8921-3c6aa7b21d17')
-
-    @property
-    def supported_vnic_types(self):
-        return self._supported_vnic_types
-
-    def get_standard_device_mappings(self, agent):
-        return {}
-
-    def supported_extensions(self, extensions):
-        if self._supported_extensions:
-            return extensions & self._supported_extensions
-        return extensions
-
-
-class TestMechanismDriverWithAgent(mech_agent.AgentMechanismDriverBase,
-                                   TestMechanismDriver):
-    """Test mechanism driver with agent for testing mechanism driver api."""
-
-    def __init__(self):
-        super(TestMechanismDriverWithAgent, self).__init__(
-            'test_agent_type', [portbindings.VNIC_NORMAL])
-        self.bound_ports = set()
-        self._agent_type = 'test_mechanism_driver_agent'
-
-    def get_supported_vif_type(self, agent):
-        return VIF_TYPE_TEST
-
-    def get_vif_type(self, context, agent, segment):
-        return VIF_TYPE_TEST
-
-    @staticmethod
-    def provider_network_attribute_updates_supported():
-        return [pnet.SEGMENTATION_ID]
-
-    def try_to_bind_segment_for_agent(self, context, segment, agent):
-        pass
-
-    @property
-    def agent_type(self):
-        return self._agent_type
-
-    @agent_type.setter
-    def agent_type(self, agent_type):
-        self._agent_type = agent_type
-
-    @TestMechanismDriver.supported_vnic_types.setter
-    def supported_vnic_types(self, vnic_types):
-        self._supported_vnic_types = vnic_types
+                self.bound_ports.add(context.current['id'])
