@@ -950,6 +950,81 @@ class L3DvrSchedulerTestCase(testlib_api.SqlTestCase):
         self.adminContext = q_context.get_admin_context()
         self.dut = L3DvrScheduler()
 
+    def test__notify_l3_agent_update_port_no_removing_routers(self):
+        port_id = 'fake-port'
+        kwargs = {
+            'context': self.adminContext,
+            'port': None,
+            'original_port': {
+                'id': port_id,
+                'binding:host_id': 'vm-host',
+                'device_id': 'vm-id',
+                'device_owner': 'compute:None',
+                'mac_address': '02:04:05:17:18:19'
+            },
+            'mac_address_updated': True
+        }
+
+        plugin = manager.NeutronManager.get_plugin()
+        l3plugin = mock.Mock()
+        l3plugin.supported_extension_aliases = [
+            'router', constants.L3_AGENT_SCHEDULER_EXT_ALIAS,
+            constants.L3_DISTRIBUTED_EXT_ALIAS
+        ]
+
+        with mock.patch.object(manager.NeutronManager,
+                               'get_service_plugins',
+                               return_value={'L3_ROUTER_NAT': l3plugin}):
+            l3_dvrscheduler_db._notify_l3_agent_port_update(
+                'port', 'after_update', plugin, **kwargs)
+
+            self.assertFalse(l3plugin.dvr_vmarp_table_update.called)
+            self.assertFalse(l3plugin.dvr_update_router_addvm.called)
+            self.assertFalse(l3plugin.remove_router_from_l3_agent.called)
+            self.assertFalse(l3plugin.dvr_deletens_if_no_port.called)
+
+    def test__notify_l3_agent_update_port_removing_routers(self):
+        port_id = 'fake-port'
+        kwargs = {
+            'context': self.adminContext,
+            'port': {
+                'id': port_id,
+                'binding:host_id': None,
+                'device_id': '',
+                'device_owner': ''
+            },
+            'mac_address_updated': False,
+            'original_port': {
+                'id': port_id,
+                'binding:host_id': 'vm-host',
+                'device_id': 'vm-id',
+                'device_owner': 'compute:None'
+            }
+        }
+
+        plugin = manager.NeutronManager.get_plugin()
+        l3plugin = mock.Mock()
+        l3plugin.supported_extension_aliases = [
+            'router', constants.L3_AGENT_SCHEDULER_EXT_ALIAS,
+            constants.L3_DISTRIBUTED_EXT_ALIAS
+        ]
+        with mock.patch.object(manager.NeutronManager,
+                               'get_service_plugins',
+                               return_value={'L3_ROUTER_NAT': l3plugin}),\
+                mock.patch.object(l3plugin, 'dvr_deletens_if_no_port',
+                                  return_value=[{'agent_id': 'foo_agent',
+                                             'router_id': 'foo_id'}]):
+            l3_dvrscheduler_db._notify_l3_agent_port_update(
+                'port', 'after_update', plugin, **kwargs)
+
+            self.assertEqual(1, l3plugin.dvr_vmarp_table_update.call_count)
+            l3plugin.dvr_vmarp_table_update.assert_called_once_with(
+                self.adminContext, mock.ANY, 'del')
+
+            self.assertFalse(l3plugin.dvr_update_router_addvm.called)
+            l3plugin.remove_router_from_l3_agent.assert_called_once_with(
+                self.adminContext, 'foo_agent', 'foo_id')
+
     def test__notify_port_delete(self):
         plugin = manager.NeutronManager.get_plugin()
         l3plugin = mock.Mock()
@@ -1108,13 +1183,13 @@ class L3DvrSchedulerTestCase(testlib_api.SqlTestCase):
                                                     'my-subnet-id')
             self.assertTrue(result)
 
-    def test_dvr_serviced_vip_port_exists_on_subnet(self):
+    def _test_dvr_serviced_vip_port_exists_on_subnet(self, device_owner):
         vip_port = {
                 'id': 'lbaas-vip-port1',
                 'device_id': 'vip-pool-id',
                 'status': 'ACTIVE',
                 'binding:host_id': 'thisHost',
-                'device_owner': constants.DEVICE_OWNER_LOADBALANCER,
+                'device_owner': device_owner,
                 'fixed_ips': [
                     {
                         'subnet_id': 'my-subnet-id',
@@ -1124,6 +1199,14 @@ class L3DvrSchedulerTestCase(testlib_api.SqlTestCase):
         }
         self._test_dvr_serviced_port_exists_on_subnet(port=vip_port)
 
+    def test_dvr_serviced_lbaas_vip_port_exists_on_subnet(self):
+        self._test_dvr_serviced_vip_port_exists_on_subnet(
+                        device_owner=constants.DEVICE_OWNER_LOADBALANCER)
+
+    def test_dvr_serviced_lbaasv2_vip_port_exists_on_subnet(self):
+        self._test_dvr_serviced_vip_port_exists_on_subnet(
+                        device_owner=constants.DEVICE_OWNER_LOADBALANCERV2)
+
     def _create_port(self, port_name, tenant_id, host, subnet_id, ip_address,
                      status='ACTIVE',
                      device_owner='compute:nova'):
