@@ -24,24 +24,22 @@ import socket
 import ssl
 import sys
 import time
-from xml.etree import ElementTree as etree
-from xml.parsers import expat
 
 import eventlet.wsgi
-eventlet.patcher.monkey_patch(all=False, socket=True, thread=True)
-from oslo.config import cfg
+from oslo_config import cfg
+import oslo_i18n
+from oslo_log import log as logging
+from oslo_log import loggers
+from oslo_serialization import jsonutils
+from oslo_utils import excutils
 import routes.middleware
 import webob.dec
 import webob.exc
 
-from neutron.common import constants
 from neutron.common import exceptions as exception
 from neutron import context
 from neutron.db import api
-from neutron.openstack.common import excutils
-from neutron.openstack.common import gettextutils
-from neutron.openstack.common import jsonutils
-from neutron.openstack.common import log as logging
+from neutron.i18n import _LE, _LI
 from neutron.openstack.common import service as common_service
 from neutron.openstack.common import systemd
 
@@ -72,6 +70,18 @@ socket_opts = [
     cfg.StrOpt('ssl_key_file',
                help=_("Private key file to use when starting "
                       "the server securely")),
+    cfg.BoolOpt('wsgi_keep_alive',
+                default=True,
+                help=_("Determines if connections are allowed to be held "
+                     "open by clients after a request is fulfilled. A value "
+                     "of False will ensure that the socket connection will "
+                     "be explicitly closed once a response has been sent to "
+                     "the client.")),
+    cfg.IntOpt('client_socket_timeout', default=900,
+               help=_("Timeout for client connections socket operations. "
+                    "If an incoming connection is idle for this number of "
+                    "seconds it will be closed. A value of '0' means "
+                    "wait forever.")),
 ]
 
 CONF = cfg.CONF
@@ -88,10 +98,6 @@ class WorkerService(object):
         self._server = None
 
     def start(self):
-        # We may have just forked from parent process.  A quick disposal of the
-        # existing sql connections avoids producting 500 errors later when they
-        # are discovered to be broken.
-        api.get_engine().pool.dispose()
         self._server = self._service.pool.spawn(self._service._run,
                                                 self._application,
                                                 self._service._socket)
@@ -109,12 +115,17 @@ class WorkerService(object):
 class Server(object):
     """Server class to manage multiple WSGI sockets and applications."""
 
-    def __init__(self, name, threads=1000):
+    def __init__(self, name, num_threads=1000):
         # Raise the default from 8192 to accommodate large tokens
         eventlet.wsgi.MAX_HEADER_LINE = CONF.max_header_line
-        self.pool = eventlet.GreenPool(threads)
+        self.num_threads = num_threads
+        # Pool for a greenthread in which wsgi server will be running
+        self.pool = eventlet.GreenPool(1)
         self.name = name
         self._server = None
+        # A value of 0 is converted to None because None is what causes the
+        # wsgi server to wait forever.
+        self.client_socket_timeout = CONF.client_socket_timeout or None
 
     def _get_socket(self, host, port, backlog):
         bind_addr = (host, port)
@@ -129,7 +140,7 @@ class Server(object):
             family = info[0]
             bind_addr = info[-1]
         except Exception:
-            LOG.exception(_("Unable to listen on %(host)s:%(port)s"),
+            LOG.exception(_LE("Unable to listen on %(host)s:%(port)s"),
                           {'host': host, 'port': port})
             sys.exit(1)
 
@@ -216,6 +227,11 @@ class Server(object):
             service.start()
             systemd.notify_once()
         else:
+            # dispose the whole pool before os.fork, otherwise there will
+            # be shared DB connections in child processes which may cause
+            # DB errors.
+            if CONF.database.connection:
+                api.get_engine().pool.dispose()
             # The API service runs in a number of child processes.
             # Minimize the cost of checking for child exit by extending the
             # wait interval past the default of 0.01s.
@@ -242,8 +258,11 @@ class Server(object):
 
     def _run(self, application, socket):
         """Start a WSGI server in a new green thread."""
-        eventlet.wsgi.server(socket, application, custom_pool=self.pool,
-                             log=logging.WritableLogger(LOG))
+        eventlet.wsgi.server(socket, application,
+                             max_size=self.num_threads,
+                             log=loggers.WritableLogger(LOG),
+                             keepalive=CONF.wsgi_keep_alive,
+                             socket_timeout=self.client_socket_timeout)
 
 
 class Middleware(object):
@@ -313,7 +332,7 @@ class Request(webob.Request):
         """Determine the most acceptable content-type.
 
         Based on:
-            1) URI extension (.json/.xml)
+            1) URI extension (.json)
             2) Content-type header
             3) Accept* headers
         """
@@ -321,23 +340,23 @@ class Request(webob.Request):
         parts = self.path.rsplit('.', 1)
         if len(parts) > 1:
             _format = parts[1]
-            if _format in ['json', 'xml']:
+            if _format in ['json']:
                 return 'application/{0}'.format(_format)
 
         #Then look up content header
         type_from_header = self.get_content_type()
         if type_from_header:
             return type_from_header
-        ctypes = ['application/json', 'application/xml']
+        ctypes = ['application/json']
 
         #Finally search in Accept-* headers
         bm = self.accept.best_match(ctypes)
         return bm or 'application/json'
 
     def get_content_type(self):
-        allowed_types = ("application/xml", "application/json")
+        allowed_types = ("application/json")
         if "Content-Type" not in self.headers:
-            LOG.debug(_("Missing Content-Type"))
+            LOG.debug("Missing Content-Type")
             return None
         _type = self.content_type
         if _type in allowed_types:
@@ -352,7 +371,7 @@ class Request(webob.Request):
         """
         if not self.accept_language:
             return None
-        all_languages = gettextutils.get_available_languages('neutron')
+        all_languages = oslo_i18n.get_available_languages('neutron')
         return self.accept_language.best_match(all_languages)
 
     @property
@@ -394,154 +413,6 @@ class JSONDictSerializer(DictSerializer):
         return jsonutils.dumps(data, default=sanitizer)
 
 
-class XMLDictSerializer(DictSerializer):
-
-    def __init__(self, metadata=None, xmlns=None):
-        """Object initialization.
-
-        :param metadata: information needed to deserialize xml into
-                         a dictionary.
-        :param xmlns: XML namespace to include with serialized xml
-        """
-        super(XMLDictSerializer, self).__init__()
-        self.metadata = metadata or {}
-        if not xmlns:
-            xmlns = self.metadata.get('xmlns')
-        if not xmlns:
-            xmlns = constants.XML_NS_V20
-        self.xmlns = xmlns
-
-    def default(self, data):
-        """Return data as XML string.
-
-        :param data: expect data to contain a single key as XML root, or
-                     contain another '*_links' key as atom links. Other
-                     case will use 'VIRTUAL_ROOT_KEY' as XML root.
-        """
-        try:
-            links = None
-            has_atom = False
-            if data is None:
-                root_key = constants.VIRTUAL_ROOT_KEY
-                root_value = None
-            else:
-                link_keys = [k for k in data.iterkeys() or []
-                             if k.endswith('_links')]
-                if link_keys:
-                    links = data.pop(link_keys[0], None)
-                    has_atom = True
-                root_key = (len(data) == 1 and
-                            data.keys()[0] or constants.VIRTUAL_ROOT_KEY)
-                root_value = data.get(root_key, data)
-            doc = etree.Element("_temp_root")
-            used_prefixes = []
-            self._to_xml_node(doc, self.metadata, root_key,
-                              root_value, used_prefixes)
-            if links:
-                self._create_link_nodes(list(doc)[0], links)
-            return self.to_xml_string(list(doc)[0], used_prefixes, has_atom)
-        except AttributeError as e:
-            LOG.exception(str(e))
-            return ''
-
-    def __call__(self, data):
-        # Provides a migration path to a cleaner WSGI layer, this
-        # "default" stuff and extreme extensibility isn't being used
-        # like originally intended
-        return self.default(data)
-
-    def to_xml_string(self, node, used_prefixes, has_atom=False):
-        self._add_xmlns(node, used_prefixes, has_atom)
-        return etree.tostring(node, encoding='UTF-8')
-
-    #NOTE (ameade): the has_atom should be removed after all of the
-    # xml serializers and view builders have been updated to the current
-    # spec that required all responses include the xmlns:atom, the has_atom
-    # flag is to prevent current tests from breaking
-    def _add_xmlns(self, node, used_prefixes, has_atom=False):
-        node.set('xmlns', self.xmlns)
-        node.set(constants.TYPE_XMLNS, self.xmlns)
-        if has_atom:
-            node.set(constants.ATOM_XMLNS, constants.ATOM_NAMESPACE)
-        node.set(constants.XSI_NIL_ATTR, constants.XSI_NAMESPACE)
-        ext_ns = self.metadata.get(constants.EXT_NS, {})
-        ext_ns_bc = self.metadata.get(constants.EXT_NS_COMP, {})
-        for prefix in used_prefixes:
-            if prefix in ext_ns:
-                node.set('xmlns:' + prefix, ext_ns[prefix])
-            if prefix in ext_ns_bc:
-                node.set('xmlns:' + prefix, ext_ns_bc[prefix])
-
-    def _to_xml_node(self, parent, metadata, nodename, data, used_prefixes):
-        """Recursive method to convert data members to XML nodes."""
-        result = etree.SubElement(parent, nodename)
-        if ":" in nodename:
-            used_prefixes.append(nodename.split(":", 1)[0])
-        #TODO(bcwaldon): accomplish this without a type-check
-        if isinstance(data, list):
-            if not data:
-                result.set(
-                    constants.TYPE_ATTR,
-                    constants.TYPE_LIST)
-                return result
-            singular = metadata.get('plurals', {}).get(nodename, None)
-            if singular is None:
-                if nodename.endswith('s'):
-                    singular = nodename[:-1]
-                else:
-                    singular = 'item'
-            for item in data:
-                self._to_xml_node(result, metadata, singular, item,
-                                  used_prefixes)
-        #TODO(bcwaldon): accomplish this without a type-check
-        elif isinstance(data, dict):
-            if not data:
-                result.set(
-                    constants.TYPE_ATTR,
-                    constants.TYPE_DICT)
-                return result
-            attrs = metadata.get('attributes', {}).get(nodename, {})
-            for k, v in data.items():
-                if k in attrs:
-                    result.set(k, str(v))
-                else:
-                    self._to_xml_node(result, metadata, k, v,
-                                      used_prefixes)
-        elif data is None:
-            result.set(constants.XSI_ATTR, 'true')
-        else:
-            if isinstance(data, bool):
-                result.set(
-                    constants.TYPE_ATTR,
-                    constants.TYPE_BOOL)
-            elif isinstance(data, int):
-                result.set(
-                    constants.TYPE_ATTR,
-                    constants.TYPE_INT)
-            elif isinstance(data, long):
-                result.set(
-                    constants.TYPE_ATTR,
-                    constants.TYPE_LONG)
-            elif isinstance(data, float):
-                result.set(
-                    constants.TYPE_ATTR,
-                    constants.TYPE_FLOAT)
-            LOG.debug(_("Data %(data)s type is %(type)s"),
-                      {'data': data,
-                       'type': type(data)})
-            if isinstance(data, str):
-                result.text = unicode(data, 'utf-8')
-            else:
-                result.text = unicode(data)
-        return result
-
-    def _create_link_nodes(self, xml_doc, links):
-        for link in links:
-            link_node = etree.SubElement(xml_doc, 'atom:link')
-            link_node.set('rel', link['rel'])
-            link_node.set('href', link['href'])
-
-
 class ResponseHeaderSerializer(ActionDispatcher):
     """Default response headers serialization."""
 
@@ -557,7 +428,6 @@ class ResponseSerializer(object):
 
     def __init__(self, body_serializers=None, headers_serializer=None):
         self.body_serializers = {
-            'application/xml': XMLDictSerializer(),
             'application/json': JSONDictSerializer(),
         }
         self.body_serializers.update(body_serializers or {})
@@ -616,156 +486,6 @@ class JSONDeserializer(TextDeserializer):
         return {'body': self._from_json(datastring)}
 
 
-class ProtectedXMLParser(etree.XMLParser):
-    def __init__(self, *args, **kwargs):
-        etree.XMLParser.__init__(self, *args, **kwargs)
-        self._parser.StartDoctypeDeclHandler = self.start_doctype_decl
-
-    def start_doctype_decl(self, name, sysid, pubid, internal):
-        raise ValueError(_("Inline DTD forbidden"))
-
-    def doctype(self, name, pubid, system):
-        raise ValueError(_("Inline DTD forbidden"))
-
-
-class XMLDeserializer(TextDeserializer):
-
-    def __init__(self, metadata=None):
-        """Object initialization.
-
-        :param metadata: information needed to deserialize xml into
-                         a dictionary.
-        """
-        super(XMLDeserializer, self).__init__()
-        self.metadata = metadata or {}
-        xmlns = self.metadata.get('xmlns')
-        if not xmlns:
-            xmlns = constants.XML_NS_V20
-        self.xmlns = xmlns
-
-    def _get_key(self, tag):
-        tags = tag.split("}", 1)
-        if len(tags) == 2:
-            ns = tags[0][1:]
-            bare_tag = tags[1]
-            ext_ns = self.metadata.get(constants.EXT_NS, {})
-            if ns == self.xmlns:
-                return bare_tag
-            for prefix, _ns in ext_ns.items():
-                if ns == _ns:
-                    return prefix + ":" + bare_tag
-            ext_ns_bc = self.metadata.get(constants.EXT_NS_COMP, {})
-            for prefix, _ns in ext_ns_bc.items():
-                if ns == _ns:
-                    return prefix + ":" + bare_tag
-        else:
-            return tag
-
-    def _get_links(self, root_tag, node):
-        link_nodes = node.findall(constants.ATOM_LINK_NOTATION)
-        root_tag = self._get_key(node.tag)
-        link_key = "%s_links" % root_tag
-        link_list = []
-        for link in link_nodes:
-            link_list.append({'rel': link.get('rel'),
-                              'href': link.get('href')})
-            # Remove link node in order to avoid link node process as
-            # an item in _from_xml_node
-            node.remove(link)
-        return link_list and {link_key: link_list} or {}
-
-    def _parseXML(self, text):
-        parser = ProtectedXMLParser()
-        parser.feed(text)
-        return parser.close()
-
-    def _from_xml(self, datastring):
-        if datastring is None:
-            return None
-        plurals = set(self.metadata.get('plurals', {}))
-        try:
-            node = self._parseXML(datastring)
-            root_tag = self._get_key(node.tag)
-            # Deserialize link node was needed by unit test for verifying
-            # the request's response
-            links = self._get_links(root_tag, node)
-            result = self._from_xml_node(node, plurals)
-            # root_tag = constants.VIRTUAL_ROOT_KEY and links is not None
-            # is not possible because of the way data are serialized.
-            if root_tag == constants.VIRTUAL_ROOT_KEY:
-                return result
-            return dict({root_tag: result}, **links)
-        except Exception as e:
-            with excutils.save_and_reraise_exception():
-                parseError = False
-                # Python2.7
-                if (hasattr(etree, 'ParseError') and
-                    isinstance(e, getattr(etree, 'ParseError'))):
-                    parseError = True
-                # Python2.6
-                elif isinstance(e, expat.ExpatError):
-                    parseError = True
-                if parseError:
-                    msg = _("Cannot understand XML")
-                    raise exception.MalformedRequestBody(reason=msg)
-
-    def _from_xml_node(self, node, listnames):
-        """Convert a minidom node to a simple Python type.
-
-        :param listnames: list of XML node names whose subnodes should
-                          be considered list items.
-
-        """
-        attrNil = node.get(str(etree.QName(constants.XSI_NAMESPACE, "nil")))
-        attrType = node.get(str(etree.QName(
-            self.metadata.get('xmlns'), "type")))
-        if (attrNil and attrNil.lower() == 'true'):
-            return None
-        elif not len(node) and not node.text:
-            if (attrType and attrType == constants.TYPE_DICT):
-                return {}
-            elif (attrType and attrType == constants.TYPE_LIST):
-                return []
-            else:
-                return ''
-        elif (len(node) == 0 and node.text):
-            converters = {constants.TYPE_BOOL:
-                          lambda x: x.lower() == 'true',
-                          constants.TYPE_INT:
-                          lambda x: int(x),
-                          constants.TYPE_LONG:
-                          lambda x: long(x),
-                          constants.TYPE_FLOAT:
-                          lambda x: float(x)}
-            if attrType and attrType in converters:
-                return converters[attrType](node.text)
-            else:
-                return node.text
-        elif self._get_key(node.tag) in listnames:
-            return [self._from_xml_node(n, listnames) for n in node]
-        else:
-            result = dict()
-            for attr in node.keys():
-                if (attr == 'xmlns' or
-                    attr.startswith('xmlns:') or
-                    attr == constants.XSI_ATTR or
-                    attr == constants.TYPE_ATTR):
-                    continue
-                result[self._get_key(attr)] = node.get(attr)
-            children = list(node)
-            for child in children:
-                result[self._get_key(child.tag)] = self._from_xml_node(
-                    child, listnames)
-            return result
-
-    def default(self, datastring):
-        return {'body': self._from_xml(datastring)}
-
-    def __call__(self, datastring):
-        # Adding a migration path to allow us to remove unncessary classes
-        return self.default(datastring)
-
-
 class RequestHeadersDeserializer(ActionDispatcher):
     """Default request headers deserializer."""
 
@@ -781,7 +501,6 @@ class RequestDeserializer(object):
 
     def __init__(self, body_deserializers=None, headers_deserializer=None):
         self.body_deserializers = {
-            'application/xml': XMLDeserializer(),
             'application/json': JSONDeserializer(),
         }
         self.body_deserializers.update(body_deserializers or {})
@@ -815,23 +534,23 @@ class RequestDeserializer(object):
         try:
             content_type = request.best_match_content_type()
         except exception.InvalidContentType:
-            LOG.debug(_("Unrecognized Content-Type provided in request"))
+            LOG.debug("Unrecognized Content-Type provided in request")
             return {}
 
         if content_type is None:
-            LOG.debug(_("No Content-Type provided in request"))
+            LOG.debug("No Content-Type provided in request")
             return {}
 
         if not len(request.body) > 0:
-            LOG.debug(_("Empty body provided in request"))
+            LOG.debug("Empty body provided in request")
             return {}
 
         try:
             deserializer = self.get_body_deserializer(content_type)
         except exception.InvalidContentType:
             with excutils.save_and_reraise_exception():
-                LOG.debug(_("Unable to deserialize body as provided "
-                            "Content-Type"))
+                LOG.debug("Unable to deserialize body as provided "
+                          "Content-Type")
 
         return deserializer.deserialize(request.body, action)
 
@@ -967,11 +686,6 @@ class Debug(Middleware):
 class Router(object):
     """WSGI middleware that maps incoming requests to WSGI apps."""
 
-    @classmethod
-    def factory(cls, global_config, **local_config):
-        """Return an instance of the WSGI Router class."""
-        return cls()
-
     def __init__(self, mapper):
         """Create a router for the given routes.Mapper.
 
@@ -1020,7 +734,7 @@ class Router(object):
         if not match:
             language = req.best_match_language()
             msg = _('The resource could not be found.')
-            msg = gettextutils.translate(msg, language)
+            msg = oslo_i18n.translate(msg, language)
             return webob.exc.HTTPNotFound(explanation=msg)
         app = match['controller']
         return app
@@ -1057,43 +771,34 @@ class Resource(Application):
         self.deserializer = deserializer or RequestDeserializer()
         self.serializer = serializer or ResponseSerializer()
         self._fault_body_function = fault_body_function
-        # use serializer's xmlns for populating Fault generator xmlns
-        xml_serializer = self.serializer.body_serializers['application/xml']
-        if hasattr(xml_serializer, 'xmlns'):
-            self._xmlns = xml_serializer.xmlns
 
     @webob.dec.wsgify(RequestClass=Request)
     def __call__(self, request):
         """WSGI method that controls (de)serialization and method dispatch."""
 
-        LOG.info(_("%(method)s %(url)s"), {"method": request.method,
-                                           "url": request.url})
+        LOG.info(_LI("%(method)s %(url)s"),
+                 {"method": request.method, "url": request.url})
 
         try:
             action, args, accept = self.deserializer.deserialize(request)
         except exception.InvalidContentType:
             msg = _("Unsupported Content-Type")
-            LOG.exception(_("InvalidContentType: %s"), msg)
-            return Fault(webob.exc.HTTPBadRequest(explanation=msg),
-                         self._xmlns)
+            LOG.exception(_LE("InvalidContentType: %s"), msg)
+            return Fault(webob.exc.HTTPBadRequest(explanation=msg))
         except exception.MalformedRequestBody:
             msg = _("Malformed request body")
-            LOG.exception(_("MalformedRequestBody: %s"), msg)
-            return Fault(webob.exc.HTTPBadRequest(explanation=msg),
-                         self._xmlns)
+            LOG.exception(_LE("MalformedRequestBody: %s"), msg)
+            return Fault(webob.exc.HTTPBadRequest(explanation=msg))
 
         try:
             action_result = self.dispatch(request, action, args)
         except webob.exc.HTTPException as ex:
-            LOG.info(_("HTTP exception thrown: %s"), unicode(ex))
-            action_result = Fault(ex,
-                                  self._xmlns,
-                                  self._fault_body_function)
+            LOG.info(_LI("HTTP exception thrown: %s"), ex)
+            action_result = Fault(ex, self._fault_body_function)
         except Exception:
-            LOG.exception(_("Internal error"))
+            LOG.exception(_LE("Internal error"))
             # Do not include the traceback to avoid returning it to clients.
             action_result = Fault(webob.exc.HTTPServerError(),
-                                  self._xmlns,
                                   self._fault_body_function)
 
         if isinstance(action_result, dict) or action_result is None:
@@ -1104,13 +809,11 @@ class Resource(Application):
             response = action_result
 
         try:
-            msg_dict = dict(url=request.url, status=response.status_int)
-            msg = _("%(url)s returned with HTTP %(status)d") % msg_dict
+            LOG.info(_LI("%(url)s returned with HTTP %(status)d"),
+                     dict(url=request.url, status=response.status_int))
         except AttributeError as e:
-            msg_dict = dict(url=request.url, exception=e)
-            msg = _("%(url)s returned a fault: %(exception)s") % msg_dict
-
-        LOG.info(msg)
+            LOG.info(_LI("%(url)s returned a fault: %(exception)s"),
+                     dict(url=request.url, exception=e))
 
         return response
 
@@ -1124,8 +827,7 @@ class Resource(Application):
             return controller_method(request=request, **action_args)
         except TypeError as exc:
             LOG.exception(exc)
-            return Fault(webob.exc.HTTPBadRequest(),
-                         self._xmlns)
+            return Fault(webob.exc.HTTPBadRequest())
 
 
 def _default_body_function(wrapped_exc):
@@ -1142,11 +844,10 @@ def _default_body_function(wrapped_exc):
 class Fault(webob.exc.HTTPException):
     """Generates an HTTP response from a webob HTTP exception."""
 
-    def __init__(self, exception, xmlns=None, body_function=None):
+    def __init__(self, exception, body_function=None):
         """Creates a Fault for the given webob.exc.exception."""
         self.wrapped_exc = exception
         self.status_int = self.wrapped_exc.status_int
-        self._xmlns = xmlns
         self._body_function = body_function or _default_body_function
 
     @webob.dec.wsgify(RequestClass=Request)
@@ -1154,10 +855,8 @@ class Fault(webob.exc.HTTPException):
         """Generate a WSGI response based on the exception passed to ctor."""
         # Replace the body with fault details.
         fault_data, metadata = self._body_function(self.wrapped_exc)
-        xml_serializer = XMLDictSerializer(metadata, self._xmlns)
         content_type = req.best_match_content_type()
         serializer = {
-            'application/xml': xml_serializer,
             'application/json': JSONDictSerializer(),
         }[content_type]
 
@@ -1200,20 +899,18 @@ class Controller(object):
             else:
                 status = 200
                 content_type = req.best_match_content_type()
-                default_xmlns = self.get_default_xmlns(req)
-                body = self._serialize(result, content_type, default_xmlns)
+                body = self._serialize(result, content_type)
 
             response = webob.Response(status=status,
                                       content_type=content_type,
                                       body=body)
-            msg_dict = dict(url=req.url, status=response.status_int)
-            msg = _("%(url)s returned with HTTP %(status)d") % msg_dict
-            LOG.debug(msg)
+            LOG.debug("%(url)s returned with HTTP %(status)d",
+                      dict(url=req.url, status=response.status_int))
             return response
         else:
             return result
 
-    def _serialize(self, data, content_type, default_xmlns):
+    def _serialize(self, data, content_type):
         """Serialize the given dict to the provided content_type.
 
         Uses self._serialization_metadata if it exists, which is a dict mapping
@@ -1222,7 +919,7 @@ class Controller(object):
         """
         _metadata = getattr(type(self), '_serialization_metadata', {})
 
-        serializer = Serializer(_metadata, default_xmlns)
+        serializer = Serializer(_metadata)
         try:
             return serializer.serialize(data, content_type)
         except exception.InvalidContentType:
@@ -1240,17 +937,13 @@ class Controller(object):
         serializer = Serializer(_metadata)
         return serializer.deserialize(data, content_type)['body']
 
-    def get_default_xmlns(self, req):
-        """Provide the XML namespace to use if none is otherwise specified."""
-        return None
-
 
 # NOTE(salvatore-orlando): this class will go once the
 # extension API framework is updated
 class Serializer(object):
     """Serializes and deserializes dictionaries to certain MIME types."""
 
-    def __init__(self, metadata=None, default_xmlns=None):
+    def __init__(self, metadata=None):
         """Create a serializer based on the given WSGI environment.
 
         'metadata' is an optional dict mapping MIME types to information
@@ -1258,12 +951,10 @@ class Serializer(object):
 
         """
         self.metadata = metadata or {}
-        self.default_xmlns = default_xmlns
 
     def _get_serialize_handler(self, content_type):
         handlers = {
             'application/json': JSONDictSerializer(),
-            'application/xml': XMLDictSerializer(self.metadata),
         }
 
         try:
@@ -1290,7 +981,6 @@ class Serializer(object):
     def get_deserialize_handler(self, content_type):
         handlers = {
             'application/json': JSONDeserializer(),
-            'application/xml': XMLDeserializer(self.metadata),
         }
 
         try:
